/****************************************************************************
** Meta object code from reading C++ file 'tokodonapplication.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/tokodonapplication.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tokodonapplication.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18TokodonApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto TokodonApplication::qt_create_metaobjectdata<qt_meta_tag_ZN18TokodonApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TokodonApplication",
        "QML.Element",
        "auto",
        "accountManagerChanged",
        "",
        "configureAccount",
        "AbstractAccount*",
        "account",
        "addAccount",
        "openHomeTimeline",
        "openNotifications",
        "openFollowRequests",
        "openLocalTimeline",
        "openGlobalTimeline",
        "openConversations",
        "openFavorites",
        "openBookmarks",
        "openExplore",
        "openFollowing",
        "openSearch",
        "openServerInformation",
        "openLists",
        "openProfile",
        "openAccountSwitcher",
        "searchFor",
        "query",
        "reloadCurrentPage",
        "openCollections",
        "uncheckMainActions",
        "accountManager",
        "AccountManager*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accountManagerChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configureAccount'
        QtMocHelpers::SignalData<void(AbstractAccount *)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'addAccount'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openHomeTimeline'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openNotifications'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openFollowRequests'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openLocalTimeline'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openGlobalTimeline'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openConversations'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openFavorites'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openBookmarks'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openExplore'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openFollowing'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openSearch'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openServerInformation'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openLists'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openProfile'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openAccountSwitcher'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchFor'
        QtMocHelpers::SignalData<void(const QString &)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Signal 'reloadCurrentPage'
        QtMocHelpers::SignalData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openCollections'
        QtMocHelpers::SignalData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'uncheckMainActions'
        QtMocHelpers::MethodData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'accountManager'
        QtMocHelpers::PropertyData<AccountManager*>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TokodonApplication, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TokodonApplication::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractKirigamiApplication::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TokodonApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TokodonApplicationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18TokodonApplicationE_t>.metaTypes,
    nullptr
} };

void TokodonApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TokodonApplication *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accountManagerChanged(); break;
        case 1: _t->configureAccount((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1]))); break;
        case 2: _t->addAccount(); break;
        case 3: _t->openHomeTimeline(); break;
        case 4: _t->openNotifications(); break;
        case 5: _t->openFollowRequests(); break;
        case 6: _t->openLocalTimeline(); break;
        case 7: _t->openGlobalTimeline(); break;
        case 8: _t->openConversations(); break;
        case 9: _t->openFavorites(); break;
        case 10: _t->openBookmarks(); break;
        case 11: _t->openExplore(); break;
        case 12: _t->openFollowing(); break;
        case 13: _t->openSearch(); break;
        case 14: _t->openServerInformation(); break;
        case 15: _t->openLists(); break;
        case 16: _t->openProfile(); break;
        case 17: _t->openAccountSwitcher(); break;
        case 18: _t->searchFor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->reloadCurrentPage(); break;
        case 20: _t->openCollections(); break;
        case 21: _t->uncheckMainActions(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::accountManagerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)(AbstractAccount * )>(_a, &TokodonApplication::configureAccount, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::addAccount, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openHomeTimeline, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openNotifications, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openFollowRequests, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openLocalTimeline, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openGlobalTimeline, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openConversations, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openFavorites, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openBookmarks, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openExplore, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openFollowing, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openSearch, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openServerInformation, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openLists, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openProfile, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openAccountSwitcher, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)(const QString & )>(_a, &TokodonApplication::searchFor, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::reloadCurrentPage, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (TokodonApplication::*)()>(_a, &TokodonApplication::openCollections, 20))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AccountManager* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<AccountManager**>(_v) = _t->accountManager(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAccountManager(*reinterpret_cast<AccountManager**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TokodonApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TokodonApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TokodonApplicationE_t>.strings))
        return static_cast<void*>(this);
    return AbstractKirigamiApplication::qt_metacast(_clname);
}

int TokodonApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractKirigamiApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void TokodonApplication::accountManagerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TokodonApplication::configureAccount(AbstractAccount * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TokodonApplication::addAccount()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TokodonApplication::openHomeTimeline()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TokodonApplication::openNotifications()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TokodonApplication::openFollowRequests()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TokodonApplication::openLocalTimeline()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TokodonApplication::openGlobalTimeline()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void TokodonApplication::openConversations()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void TokodonApplication::openFavorites()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void TokodonApplication::openBookmarks()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void TokodonApplication::openExplore()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void TokodonApplication::openFollowing()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void TokodonApplication::openSearch()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void TokodonApplication::openServerInformation()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void TokodonApplication::openLists()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void TokodonApplication::openProfile()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void TokodonApplication::openAccountSwitcher()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void TokodonApplication::searchFor(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void TokodonApplication::reloadCurrentPage()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void TokodonApplication::openCollections()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
QT_WARNING_POP
