/****************************************************************************
** Meta object code from reading C++ file 'config.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../config.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'config.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6ConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto Config::qt_create_metaobjectdata<qt_meta_tag_ZN6ConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Config",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "ShowPostStatsChanged",
        "",
        "ShowLinkPreviewChanged",
        "PopOutByDefaultChanged",
        "ContinueReadingChanged",
        "AutoUpdateChanged",
        "CropMediaChanged",
        "AutoPlayGifChanged",
        "LastUsedAccountChanged",
        "ColorSchemeChanged",
        "defaultFontChanged",
        "PromptedNotificationPermissionChanged",
        "AskBeforeBoostingChanged",
        "ProxyTypeChanged",
        "ProxyHostChanged",
        "ProxyPortChanged",
        "ProxyUserChanged",
        "ProxyPasswordChanged",
        "TimeoutChanged",
        "showPostStats",
        "isShowPostStatsImmutable",
        "defaultShowPostStatsValue",
        "showLinkPreview",
        "isShowLinkPreviewImmutable",
        "defaultShowLinkPreviewValue",
        "popOutByDefault",
        "isPopOutByDefaultImmutable",
        "defaultPopOutByDefaultValue",
        "continueReading",
        "isContinueReadingImmutable",
        "defaultContinueReadingValue",
        "autoUpdate",
        "isAutoUpdateImmutable",
        "defaultAutoUpdateValue",
        "cropMedia",
        "isCropMediaImmutable",
        "defaultCropMediaValue",
        "autoPlayGif",
        "isAutoPlayGifImmutable",
        "defaultAutoPlayGifValue",
        "lastUsedAccount",
        "isLastUsedAccountImmutable",
        "colorScheme",
        "isColorSchemeImmutable",
        "defaultFont",
        "QFont",
        "isDefaultFontImmutable",
        "defaultDefaultFontValue",
        "promptedNotificationPermission",
        "isPromptedNotificationPermissionImmutable",
        "defaultPromptedNotificationPermissionValue",
        "askBeforeBoosting",
        "isAskBeforeBoostingImmutable",
        "defaultAskBeforeBoostingValue",
        "proxyType",
        "isProxyTypeImmutable",
        "defaultProxyTypeValue",
        "proxyHost",
        "isProxyHostImmutable",
        "defaultProxyHostValue",
        "proxyPort",
        "isProxyPortImmutable",
        "defaultProxyPortValue",
        "proxyUser",
        "isProxyUserImmutable",
        "proxyPassword",
        "isProxyPasswordImmutable",
        "timeout",
        "isTimeoutImmutable",
        "defaultTimeoutValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ShowPostStatsChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowLinkPreviewChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PopOutByDefaultChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ContinueReadingChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoUpdateChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CropMediaChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoPlayGifChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LastUsedAccountChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ColorSchemeChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultFontChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PromptedNotificationPermissionChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AskBeforeBoostingChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProxyTypeChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProxyHostChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProxyPortChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProxyUserChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProxyPasswordChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TimeoutChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'showPostStats'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isShowPostStatsImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowPostStatsValue'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showLinkPreview'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isShowLinkPreviewImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowLinkPreviewValue'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'popOutByDefault'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isPopOutByDefaultImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPopOutByDefaultValue'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'continueReading'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isContinueReadingImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultContinueReadingValue'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoUpdate'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isAutoUpdateImmutable'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoUpdateValue'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cropMedia'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isCropMediaImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCropMediaValue'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoPlayGif'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isAutoPlayGifImmutable'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoPlayGifValue'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastUsedAccount'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isLastUsedAccountImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'colorScheme'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isColorSchemeImmutable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFont'
        QtMocHelpers::PropertyData<QFont>(49, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'isDefaultFontImmutable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultFontValue'
        QtMocHelpers::PropertyData<QFont>(52, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'promptedNotificationPermission'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isPromptedNotificationPermissionImmutable'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPromptedNotificationPermissionValue'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'askBeforeBoosting'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isAskBeforeBoostingImmutable'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAskBeforeBoostingValue'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyType'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isProxyTypeImmutable'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxyTypeValue'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyHost'
        QtMocHelpers::PropertyData<QString>(62, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isProxyHostImmutable'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxyHostValue'
        QtMocHelpers::PropertyData<QString>(64, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyPort'
        QtMocHelpers::PropertyData<int>(65, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isProxyPortImmutable'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxyPortValue'
        QtMocHelpers::PropertyData<int>(67, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyUser'
        QtMocHelpers::PropertyData<QString>(68, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isProxyUserImmutable'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyPassword'
        QtMocHelpers::PropertyData<QString>(70, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isProxyPasswordImmutable'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'timeout'
        QtMocHelpers::PropertyData<int>(72, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTimeoutValue'
        QtMocHelpers::PropertyData<int>(74, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Config, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Config::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6ConfigE_t>.metaTypes,
    nullptr
} };

void Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Config *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ShowPostStatsChanged(); break;
        case 1: _t->ShowLinkPreviewChanged(); break;
        case 2: _t->PopOutByDefaultChanged(); break;
        case 3: _t->ContinueReadingChanged(); break;
        case 4: _t->AutoUpdateChanged(); break;
        case 5: _t->CropMediaChanged(); break;
        case 6: _t->AutoPlayGifChanged(); break;
        case 7: _t->LastUsedAccountChanged(); break;
        case 8: _t->ColorSchemeChanged(); break;
        case 9: _t->defaultFontChanged(); break;
        case 10: _t->PromptedNotificationPermissionChanged(); break;
        case 11: _t->AskBeforeBoostingChanged(); break;
        case 12: _t->ProxyTypeChanged(); break;
        case 13: _t->ProxyHostChanged(); break;
        case 14: _t->ProxyPortChanged(); break;
        case 15: _t->ProxyUserChanged(); break;
        case 16: _t->ProxyPasswordChanged(); break;
        case 17: _t->TimeoutChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ShowPostStatsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ShowLinkPreviewChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::PopOutByDefaultChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ContinueReadingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::AutoUpdateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::CropMediaChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::AutoPlayGifChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::LastUsedAccountChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ColorSchemeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::defaultFontChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::PromptedNotificationPermissionChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::AskBeforeBoostingChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ProxyTypeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ProxyHostChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ProxyPortChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ProxyUserChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ProxyPasswordChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::TimeoutChanged, 17))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->showPostStats(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isShowPostStatsImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultShowPostStatsValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->showLinkPreview(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isShowLinkPreviewImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultShowLinkPreviewValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->popOutByDefault(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isPopOutByDefaultImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultPopOutByDefaultValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->continueReading(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isContinueReadingImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultContinueReadingValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->autoUpdate(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isAutoUpdateImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultAutoUpdateValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->cropMedia(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isCropMediaImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultCropMediaValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->autoPlayGif(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isAutoPlayGifImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultAutoPlayGifValue(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->lastUsedAccount(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isLastUsedAccountImmutable(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->colorScheme(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->isColorSchemeImmutable(); break;
        case 25: *reinterpret_cast<QFont*>(_v) = _t->defaultFont(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->isDefaultFontImmutable(); break;
        case 27: *reinterpret_cast<QFont*>(_v) = _t->defaultDefaultFontValue(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->promptedNotificationPermission(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->isPromptedNotificationPermissionImmutable(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->defaultPromptedNotificationPermissionValue(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->askBeforeBoosting(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->isAskBeforeBoostingImmutable(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->defaultAskBeforeBoostingValue(); break;
        case 34: *reinterpret_cast<int*>(_v) = _t->proxyType(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->isProxyTypeImmutable(); break;
        case 36: *reinterpret_cast<int*>(_v) = _t->defaultProxyTypeValue(); break;
        case 37: *reinterpret_cast<QString*>(_v) = _t->proxyHost(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->isProxyHostImmutable(); break;
        case 39: *reinterpret_cast<QString*>(_v) = _t->defaultProxyHostValue(); break;
        case 40: *reinterpret_cast<int*>(_v) = _t->proxyPort(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->isProxyPortImmutable(); break;
        case 42: *reinterpret_cast<int*>(_v) = _t->defaultProxyPortValue(); break;
        case 43: *reinterpret_cast<QString*>(_v) = _t->proxyUser(); break;
        case 44: *reinterpret_cast<bool*>(_v) = _t->isProxyUserImmutable(); break;
        case 45: *reinterpret_cast<QString*>(_v) = _t->proxyPassword(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isProxyPasswordImmutable(); break;
        case 47: *reinterpret_cast<int*>(_v) = _t->timeout(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->isTimeoutImmutable(); break;
        case 49: *reinterpret_cast<int*>(_v) = _t->defaultTimeoutValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShowPostStats(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setShowLinkPreview(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setPopOutByDefault(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setContinueReading(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setAutoUpdate(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setCropMedia(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setAutoPlayGif(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setLastUsedAccount(*reinterpret_cast<QString*>(_v)); break;
        case 23: _t->setColorScheme(*reinterpret_cast<QString*>(_v)); break;
        case 25: _t->setDefaultFont(*reinterpret_cast<QFont*>(_v)); break;
        case 28: _t->setPromptedNotificationPermission(*reinterpret_cast<bool*>(_v)); break;
        case 31: _t->setAskBeforeBoosting(*reinterpret_cast<bool*>(_v)); break;
        case 34: _t->setProxyType(*reinterpret_cast<int*>(_v)); break;
        case 37: _t->setProxyHost(*reinterpret_cast<QString*>(_v)); break;
        case 40: _t->setProxyPort(*reinterpret_cast<int*>(_v)); break;
        case 43: _t->setProxyUser(*reinterpret_cast<QString*>(_v)); break;
        case 45: _t->setProxyPassword(*reinterpret_cast<QString*>(_v)); break;
        case 47: _t->setTimeout(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 50;
    }
    return _id;
}

// SIGNAL 0
void Config::ShowPostStatsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Config::ShowLinkPreviewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Config::PopOutByDefaultChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Config::ContinueReadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Config::AutoUpdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Config::CropMediaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Config::AutoPlayGifChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Config::LastUsedAccountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Config::ColorSchemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Config::defaultFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Config::PromptedNotificationPermissionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Config::AskBeforeBoostingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Config::ProxyTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Config::ProxyHostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Config::ProxyPortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Config::ProxyUserChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Config::ProxyPasswordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Config::TimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
