/****************************************************************************
** Meta object code from reading C++ file 'maintimelinemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/timeline/maintimelinemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'maintimelinemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17MainTimelineModelE_t {};
} // unnamed namespace

template <> constexpr inline auto MainTimelineModel::qt_create_metaobjectdata<qt_meta_tag_ZN17MainTimelineModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainTimelineModel",
        "QML.Element",
        "auto",
        "listIdChanged",
        "",
        "hasPreviousChanged",
        "userHasTakenReadActionChanged",
        "urlChanged",
        "refresh",
        "fetchPrevious",
        "updateReadMarker",
        "postId",
        "nameChanged",
        "name",
        "listId",
        "hasPrevious",
        "lastReadTime",
        "userHasTakenReadAction",
        "url"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'listIdChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasPreviousChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userHasTakenReadActionChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'fetchPrevious'
        QtMocHelpers::MethodData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'updateReadMarker'
        QtMocHelpers::MethodData<void(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 12),
        // property 'listId'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'hasPrevious'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'lastReadTime'
        QtMocHelpers::PropertyData<QDateTime>(16, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 1),
        // property 'userHasTakenReadAction'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'url'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MainTimelineModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MainTimelineModel::staticMetaObject = { {
    QMetaObject::SuperData::link<TimelineModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MainTimelineModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MainTimelineModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17MainTimelineModelE_t>.metaTypes,
    nullptr
} };

void MainTimelineModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainTimelineModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->listIdChanged(); break;
        case 1: _t->hasPreviousChanged(); break;
        case 2: _t->userHasTakenReadActionChanged(); break;
        case 3: _t->urlChanged(); break;
        case 4: _t->refresh(); break;
        case 5: _t->fetchPrevious(); break;
        case 6: _t->updateReadMarker((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainTimelineModel::*)()>(_a, &MainTimelineModel::listIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainTimelineModel::*)()>(_a, &MainTimelineModel::hasPreviousChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainTimelineModel::*)()>(_a, &MainTimelineModel::userHasTakenReadActionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainTimelineModel::*)()>(_a, &MainTimelineModel::urlChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->listId(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasPrevious(); break;
        case 3: *reinterpret_cast<QDateTime*>(_v) = _t->lastReadTime(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->userHasTakenReadAction(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->url(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setListId(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setUrl(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MainTimelineModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainTimelineModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MainTimelineModelE_t>.strings))
        return static_cast<void*>(this);
    return TimelineModel::qt_metacast(_clname);
}

int MainTimelineModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TimelineModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void MainTimelineModel::listIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MainTimelineModel::hasPreviousChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MainTimelineModel::userHasTakenReadActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MainTimelineModel::urlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace CheckNotifySignalValidity_ZN17MainTimelineModelE {
template<typename T> using has_nullary_nameChanged = decltype(std::declval<T>().nameChanged());
template<typename T> using has_unary_nameChanged = decltype(std::declval<T>().nameChanged(std::declval<QString>()));
static_assert(qxp::is_detected_v<has_nullary_nameChanged, MainTimelineModel> || qxp::is_detected_v<has_unary_nameChanged, MainTimelineModel>,
              "NOTIFY signal nameChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
