// This file is generated by kconfig_compiler_kf6 from accountconfig.kcfg.
// All changes you do to this file will be lost.

#include "accountconfig.h"

AccountConfig::AccountConfig( const QString & groupname, QObject *parent )
  : KConfigSkeleton( KSharedConfig::openStateConfig(QStringLiteral( "tokodonstaterc") ) )
  , mParamgroupname(groupname)
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&AccountConfig::itemChanged);

  setCurrentGroup( QStringLiteral( "%1" ).arg( mParamgroupname ) );

  KConfigCompilerSignallingItem  *itemToken;
  KConfigSkeleton::ItemString  *innerItemToken;
  innerItemToken = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Token" ), mToken );
  itemToken = new KConfigCompilerSignallingItem(innerItemToken, this, notifyFunction, signalTokenChanged);
  addItem( itemToken, QStringLiteral( "Token" ) );
  KConfigCompilerSignallingItem  *itemClientId;
  KConfigSkeleton::ItemString  *innerItemClientId;
  innerItemClientId = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ClientId" ), mClientId );
  itemClientId = new KConfigCompilerSignallingItem(innerItemClientId, this, notifyFunction, signalClientIdChanged);
  addItem( itemClientId, QStringLiteral( "ClientId" ) );
  KConfigCompilerSignallingItem  *itemInstanceUri;
  KConfigSkeleton::ItemString  *innerItemInstanceUri;
  innerItemInstanceUri = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "InstanceUri" ), mInstanceUri );
  itemInstanceUri = new KConfigCompilerSignallingItem(innerItemInstanceUri, this, notifyFunction, signalInstanceUriChanged);
  addItem( itemInstanceUri, QStringLiteral( "InstanceUri" ) );
  KConfigCompilerSignallingItem  *itemName;
  KConfigSkeleton::ItemString  *innerItemName;
  innerItemName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Name" ), mName );
  itemName = new KConfigCompilerSignallingItem(innerItemName, this, notifyFunction, signalNameChanged);
  addItem( itemName, QStringLiteral( "Name" ) );
  KConfigCompilerSignallingItem  *itemLastUsedEmojis;
  KConfigSkeleton::ItemStringList  *innerItemLastUsedEmojis;
  innerItemLastUsedEmojis = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "lastUsedEmojis" ), mLastUsedEmojis );
  itemLastUsedEmojis = new KConfigCompilerSignallingItem(innerItemLastUsedEmojis, this, notifyFunction, signalLastUsedEmojisChanged);
  addItem( itemLastUsedEmojis, QStringLiteral( "lastUsedEmojis" ) );
  KConfigCompilerSignallingItem  *itemEnableNotifications;
  KConfigSkeleton::ItemBool  *innerItemEnableNotifications;
  innerItemEnableNotifications = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnableNotifications" ), mEnableNotifications, true );
  itemEnableNotifications = new KConfigCompilerSignallingItem(innerItemEnableNotifications, this, notifyFunction, signalEnableNotificationsChanged);
  addItem( itemEnableNotifications, QStringLiteral( "EnableNotifications" ) );
  KConfigCompilerSignallingItem  *itemNotifyMention;
  KConfigSkeleton::ItemBool  *innerItemNotifyMention;
  innerItemNotifyMention = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyMention" ), mNotifyMention, true );
  itemNotifyMention = new KConfigCompilerSignallingItem(innerItemNotifyMention, this, notifyFunction, signalNotifyMentionChanged);
  addItem( itemNotifyMention, QStringLiteral( "NotifyMention" ) );
  KConfigCompilerSignallingItem  *itemNotifyQuote;
  KConfigSkeleton::ItemBool  *innerItemNotifyQuote;
  innerItemNotifyQuote = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyQuote" ), mNotifyQuote, true );
  itemNotifyQuote = new KConfigCompilerSignallingItem(innerItemNotifyQuote, this, notifyFunction, signalNotifyQuoteChanged);
  addItem( itemNotifyQuote, QStringLiteral( "NotifyQuote" ) );
  KConfigCompilerSignallingItem  *itemNotifyStatus;
  KConfigSkeleton::ItemBool  *innerItemNotifyStatus;
  innerItemNotifyStatus = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyStatus" ), mNotifyStatus, true );
  itemNotifyStatus = new KConfigCompilerSignallingItem(innerItemNotifyStatus, this, notifyFunction, signalNotifyStatusChanged);
  addItem( itemNotifyStatus, QStringLiteral( "NotifyStatus" ) );
  KConfigCompilerSignallingItem  *itemNotifyBoost;
  KConfigSkeleton::ItemBool  *innerItemNotifyBoost;
  innerItemNotifyBoost = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyBoost" ), mNotifyBoost, true );
  itemNotifyBoost = new KConfigCompilerSignallingItem(innerItemNotifyBoost, this, notifyFunction, signalNotifyBoostChanged);
  addItem( itemNotifyBoost, QStringLiteral( "NotifyBoost" ) );
  KConfigCompilerSignallingItem  *itemNotifyFollow;
  KConfigSkeleton::ItemBool  *innerItemNotifyFollow;
  innerItemNotifyFollow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyFollow" ), mNotifyFollow, true );
  itemNotifyFollow = new KConfigCompilerSignallingItem(innerItemNotifyFollow, this, notifyFunction, signalNotifyFollowChanged);
  addItem( itemNotifyFollow, QStringLiteral( "NotifyFollow" ) );
  KConfigCompilerSignallingItem  *itemNotifyFollowRequest;
  KConfigSkeleton::ItemBool  *innerItemNotifyFollowRequest;
  innerItemNotifyFollowRequest = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyFollowRequest" ), mNotifyFollowRequest, true );
  itemNotifyFollowRequest = new KConfigCompilerSignallingItem(innerItemNotifyFollowRequest, this, notifyFunction, signalNotifyFollowRequestChanged);
  addItem( itemNotifyFollowRequest, QStringLiteral( "NotifyFollowRequest" ) );
  KConfigCompilerSignallingItem  *itemNotifyFavorite;
  KConfigSkeleton::ItemBool  *innerItemNotifyFavorite;
  innerItemNotifyFavorite = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyFavorite" ), mNotifyFavorite, true );
  itemNotifyFavorite = new KConfigCompilerSignallingItem(innerItemNotifyFavorite, this, notifyFunction, signalNotifyFavoriteChanged);
  addItem( itemNotifyFavorite, QStringLiteral( "NotifyFavorite" ) );
  KConfigCompilerSignallingItem  *itemNotifyPoll;
  KConfigSkeleton::ItemBool  *innerItemNotifyPoll;
  innerItemNotifyPoll = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyPoll" ), mNotifyPoll, false );
  itemNotifyPoll = new KConfigCompilerSignallingItem(innerItemNotifyPoll, this, notifyFunction, signalNotifyPollChanged);
  addItem( itemNotifyPoll, QStringLiteral( "NotifyPoll" ) );
  KConfigCompilerSignallingItem  *itemNotifyUpdate;
  KConfigSkeleton::ItemBool  *innerItemNotifyUpdate;
  innerItemNotifyUpdate = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyUpdate" ), mNotifyUpdate, false );
  itemNotifyUpdate = new KConfigCompilerSignallingItem(innerItemNotifyUpdate, this, notifyFunction, signalNotifyUpdateChanged);
  addItem( itemNotifyUpdate, QStringLiteral( "NotifyUpdate" ) );
  KConfigCompilerSignallingItem  *itemNotifySignup;
  KConfigSkeleton::ItemBool  *innerItemNotifySignup;
  innerItemNotifySignup = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifySignup" ), mNotifySignup, true );
  itemNotifySignup = new KConfigCompilerSignallingItem(innerItemNotifySignup, this, notifyFunction, signalNotifySignupChanged);
  addItem( itemNotifySignup, QStringLiteral( "NotifySignup" ) );
  KConfigCompilerSignallingItem  *itemNotifyReport;
  KConfigSkeleton::ItemBool  *innerItemNotifyReport;
  innerItemNotifyReport = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyReport" ), mNotifyReport, true );
  itemNotifyReport = new KConfigCompilerSignallingItem(innerItemNotifyReport, this, notifyFunction, signalNotifyReportChanged);
  addItem( itemNotifyReport, QStringLiteral( "NotifyReport" ) );
  KConfigCompilerSignallingItem  *itemNotifyRelationships;
  KConfigSkeleton::ItemBool  *innerItemNotifyRelationships;
  innerItemNotifyRelationships = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyRelationships" ), mNotifyRelationships, true );
  itemNotifyRelationships = new KConfigCompilerSignallingItem(innerItemNotifyRelationships, this, notifyFunction, signalNotifyRelationshipsChanged);
  addItem( itemNotifyRelationships, QStringLiteral( "NotifyRelationships" ) );
  KConfigCompilerSignallingItem  *itemNotifyAnnualReport;
  KConfigSkeleton::ItemBool  *innerItemNotifyAnnualReport;
  innerItemNotifyAnnualReport = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyAnnualReport" ), mNotifyAnnualReport, true );
  itemNotifyAnnualReport = new KConfigCompilerSignallingItem(innerItemNotifyAnnualReport, this, notifyFunction, signalNotifyAnnualReportChanged);
  addItem( itemNotifyAnnualReport, QStringLiteral( "NotifyAnnualReport" ) );
  KConfigCompilerSignallingItem  *itemNotifyCollections;
  KConfigSkeleton::ItemBool  *innerItemNotifyCollections;
  innerItemNotifyCollections = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "NotifyCollections" ), mNotifyCollections, true );
  itemNotifyCollections = new KConfigCompilerSignallingItem(innerItemNotifyCollections, this, notifyFunction, signalNotifyCollectionsChanged);
  addItem( itemNotifyCollections, QStringLiteral( "NotifyCollections" ) );
  KConfigCompilerSignallingItem  *itemDisplayMention;
  KConfigSkeleton::ItemBool  *innerItemDisplayMention;
  innerItemDisplayMention = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayMention" ), mDisplayMention, true );
  itemDisplayMention = new KConfigCompilerSignallingItem(innerItemDisplayMention, this, notifyFunction, signalDisplayMentionChanged);
  addItem( itemDisplayMention, QStringLiteral( "DisplayMention" ) );
  KConfigCompilerSignallingItem  *itemDisplayQuote;
  KConfigSkeleton::ItemBool  *innerItemDisplayQuote;
  innerItemDisplayQuote = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayQuote" ), mDisplayQuote, true );
  itemDisplayQuote = new KConfigCompilerSignallingItem(innerItemDisplayQuote, this, notifyFunction, signalDisplayQuoteChanged);
  addItem( itemDisplayQuote, QStringLiteral( "DisplayQuote" ) );
  KConfigCompilerSignallingItem  *itemDisplayStatus;
  KConfigSkeleton::ItemBool  *innerItemDisplayStatus;
  innerItemDisplayStatus = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayStatus" ), mDisplayStatus, true );
  itemDisplayStatus = new KConfigCompilerSignallingItem(innerItemDisplayStatus, this, notifyFunction, signalDisplayStatusChanged);
  addItem( itemDisplayStatus, QStringLiteral( "DisplayStatus" ) );
  KConfigCompilerSignallingItem  *itemDisplayBoost;
  KConfigSkeleton::ItemBool  *innerItemDisplayBoost;
  innerItemDisplayBoost = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayBoost" ), mDisplayBoost, true );
  itemDisplayBoost = new KConfigCompilerSignallingItem(innerItemDisplayBoost, this, notifyFunction, signalDisplayBoostChanged);
  addItem( itemDisplayBoost, QStringLiteral( "DisplayBoost" ) );
  KConfigCompilerSignallingItem  *itemDisplayFollow;
  KConfigSkeleton::ItemBool  *innerItemDisplayFollow;
  innerItemDisplayFollow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayFollow" ), mDisplayFollow, true );
  itemDisplayFollow = new KConfigCompilerSignallingItem(innerItemDisplayFollow, this, notifyFunction, signalDisplayFollowChanged);
  addItem( itemDisplayFollow, QStringLiteral( "DisplayFollow" ) );
  KConfigCompilerSignallingItem  *itemDisplayFollowRequest;
  KConfigSkeleton::ItemBool  *innerItemDisplayFollowRequest;
  innerItemDisplayFollowRequest = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayFollowRequest" ), mDisplayFollowRequest, false );
  itemDisplayFollowRequest = new KConfigCompilerSignallingItem(innerItemDisplayFollowRequest, this, notifyFunction, signalDisplayFollowRequestChanged);
  addItem( itemDisplayFollowRequest, QStringLiteral( "DisplayFollowRequest" ) );
  KConfigCompilerSignallingItem  *itemDisplayFavorite;
  KConfigSkeleton::ItemBool  *innerItemDisplayFavorite;
  innerItemDisplayFavorite = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayFavorite" ), mDisplayFavorite, true );
  itemDisplayFavorite = new KConfigCompilerSignallingItem(innerItemDisplayFavorite, this, notifyFunction, signalDisplayFavoriteChanged);
  addItem( itemDisplayFavorite, QStringLiteral( "DisplayFavorite" ) );
  KConfigCompilerSignallingItem  *itemDisplayPoll;
  KConfigSkeleton::ItemBool  *innerItemDisplayPoll;
  innerItemDisplayPoll = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayPoll" ), mDisplayPoll, true );
  itemDisplayPoll = new KConfigCompilerSignallingItem(innerItemDisplayPoll, this, notifyFunction, signalDisplayPollChanged);
  addItem( itemDisplayPoll, QStringLiteral( "DisplayPoll" ) );
  KConfigCompilerSignallingItem  *itemDisplayUpdate;
  KConfigSkeleton::ItemBool  *innerItemDisplayUpdate;
  innerItemDisplayUpdate = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayUpdate" ), mDisplayUpdate, true );
  itemDisplayUpdate = new KConfigCompilerSignallingItem(innerItemDisplayUpdate, this, notifyFunction, signalDisplayUpdateChanged);
  addItem( itemDisplayUpdate, QStringLiteral( "DisplayUpdate" ) );
  KConfigCompilerSignallingItem  *itemDisplaySignup;
  KConfigSkeleton::ItemBool  *innerItemDisplaySignup;
  innerItemDisplaySignup = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplaySignup" ), mDisplaySignup, true );
  itemDisplaySignup = new KConfigCompilerSignallingItem(innerItemDisplaySignup, this, notifyFunction, signalDisplaySignupChanged);
  addItem( itemDisplaySignup, QStringLiteral( "DisplaySignup" ) );
  KConfigCompilerSignallingItem  *itemDisplayReport;
  KConfigSkeleton::ItemBool  *innerItemDisplayReport;
  innerItemDisplayReport = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayReport" ), mDisplayReport, true );
  itemDisplayReport = new KConfigCompilerSignallingItem(innerItemDisplayReport, this, notifyFunction, signalDisplayReportChanged);
  addItem( itemDisplayReport, QStringLiteral( "DisplayReport" ) );
  KConfigCompilerSignallingItem  *itemDisplayRelationships;
  KConfigSkeleton::ItemBool  *innerItemDisplayRelationships;
  innerItemDisplayRelationships = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayRelationships" ), mDisplayRelationships, true );
  itemDisplayRelationships = new KConfigCompilerSignallingItem(innerItemDisplayRelationships, this, notifyFunction, signalDisplayRelationshipsChanged);
  addItem( itemDisplayRelationships, QStringLiteral( "DisplayRelationships" ) );
  KConfigCompilerSignallingItem  *itemDisplayAnnualReport;
  KConfigSkeleton::ItemBool  *innerItemDisplayAnnualReport;
  innerItemDisplayAnnualReport = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayAnnualReport" ), mDisplayAnnualReport, true );
  itemDisplayAnnualReport = new KConfigCompilerSignallingItem(innerItemDisplayAnnualReport, this, notifyFunction, signalDisplayAnnualReportChanged);
  addItem( itemDisplayAnnualReport, QStringLiteral( "DisplayAnnualReport" ) );
  KConfigCompilerSignallingItem  *itemDisplayCollections;
  KConfigSkeleton::ItemBool  *innerItemDisplayCollections;
  innerItemDisplayCollections = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DisplayCollections" ), mDisplayCollections, true );
  itemDisplayCollections = new KConfigCompilerSignallingItem(innerItemDisplayCollections, this, notifyFunction, signalDisplayCollectionsChanged);
  addItem( itemDisplayCollections, QStringLiteral( "DisplayCollections" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesNotifyPolicy;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("All");
    valuesNotifyPolicy.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Followed");
    valuesNotifyPolicy.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Followers");
    valuesNotifyPolicy.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("None");
    valuesNotifyPolicy.append( choice );
  }
  KConfigCompilerSignallingItem  *itemNotifyPolicy;
  KConfigSkeleton::ItemEnum  *innerItemNotifyPolicy;
  innerItemNotifyPolicy = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "NotifyPolicy" ), mNotifyPolicy, valuesNotifyPolicy, EnumNotifyPolicy::All );
  itemNotifyPolicy = new KConfigCompilerSignallingItem(innerItemNotifyPolicy, this, notifyFunction, signalNotifyPolicyChanged);
  addItem( itemNotifyPolicy, QStringLiteral( "NotifyPolicy" ) );
  KConfigCompilerSignallingItem  *itemLastPushNotification;
  KConfigSkeleton::ItemString  *innerItemLastPushNotification;
  innerItemLastPushNotification = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LastPushNotification" ), mLastPushNotification );
  itemLastPushNotification = new KConfigCompilerSignallingItem(innerItemLastPushNotification, this, notifyFunction, signalLastPushNotificationChanged);
  addItem( itemLastPushNotification, QStringLiteral( "LastPushNotification" ) );
  KConfigCompilerSignallingItem  *itemEnablePushNotifications;
  KConfigSkeleton::ItemBool  *innerItemEnablePushNotifications;
  innerItemEnablePushNotifications = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnablePushNotifications" ), mEnablePushNotifications, false );
  itemEnablePushNotifications = new KConfigCompilerSignallingItem(innerItemEnablePushNotifications, this, notifyFunction, signalEnablePushNotificationsChanged);
  addItem( itemEnablePushNotifications, QStringLiteral( "EnablePushNotifications" ) );
  KConfigCompilerSignallingItem  *itemFavoriteListIds;
  KConfigSkeleton::ItemStringList  *innerItemFavoriteListIds;
  innerItemFavoriteListIds = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "FavoriteListIds" ), mFavoriteListIds );
  itemFavoriteListIds = new KConfigCompilerSignallingItem(innerItemFavoriteListIds, this, notifyFunction, signalFavoriteListIdsChanged);
  addItem( itemFavoriteListIds, QStringLiteral( "FavoriteListIds" ) );
}

bool AccountConfig::defaultEnableNotificationsValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyMentionValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyQuoteValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyStatusValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyBoostValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyFollowValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyFollowRequestValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyFavoriteValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyPollValue_helper() const
{

  return false;
}

bool AccountConfig::defaultNotifyUpdateValue_helper() const
{

  return false;
}

bool AccountConfig::defaultNotifySignupValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyReportValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyRelationshipsValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyAnnualReportValue_helper() const
{

  return true;
}

bool AccountConfig::defaultNotifyCollectionsValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayMentionValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayQuoteValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayStatusValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayBoostValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayFollowValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayFollowRequestValue_helper() const
{

  return false;
}

bool AccountConfig::defaultDisplayFavoriteValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayPollValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayUpdateValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplaySignupValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayReportValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayRelationshipsValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayAnnualReportValue_helper() const
{

  return true;
}

bool AccountConfig::defaultDisplayCollectionsValue_helper() const
{

  return true;
}

int AccountConfig::defaultNotifyPolicyValue_helper() const
{

  return EnumNotifyPolicy::All;
}

bool AccountConfig::defaultEnablePushNotificationsValue_helper() const
{

  return false;
}

AccountConfig::~AccountConfig()
{
}


void AccountConfig::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalTokenChanged:
    Q_EMIT TokenChanged();
    break;
  case signalClientIdChanged:
    Q_EMIT ClientIdChanged();
    break;
  case signalInstanceUriChanged:
    Q_EMIT InstanceUriChanged();
    break;
  case signalNameChanged:
    Q_EMIT NameChanged();
    break;
  case signalLastUsedEmojisChanged:
    Q_EMIT lastUsedEmojisChanged();
    break;
  case signalEnableNotificationsChanged:
    Q_EMIT EnableNotificationsChanged();
    break;
  case signalNotifyMentionChanged:
    Q_EMIT NotifyMentionChanged();
    break;
  case signalNotifyQuoteChanged:
    Q_EMIT NotifyQuoteChanged();
    break;
  case signalNotifyStatusChanged:
    Q_EMIT NotifyStatusChanged();
    break;
  case signalNotifyBoostChanged:
    Q_EMIT NotifyBoostChanged();
    break;
  case signalNotifyFollowChanged:
    Q_EMIT NotifyFollowChanged();
    break;
  case signalNotifyFollowRequestChanged:
    Q_EMIT NotifyFollowRequestChanged();
    break;
  case signalNotifyFavoriteChanged:
    Q_EMIT NotifyFavoriteChanged();
    break;
  case signalNotifyPollChanged:
    Q_EMIT NotifyPollChanged();
    break;
  case signalNotifyUpdateChanged:
    Q_EMIT NotifyUpdateChanged();
    break;
  case signalNotifySignupChanged:
    Q_EMIT NotifySignupChanged();
    break;
  case signalNotifyReportChanged:
    Q_EMIT NotifyReportChanged();
    break;
  case signalNotifyRelationshipsChanged:
    Q_EMIT NotifyRelationshipsChanged();
    break;
  case signalNotifyAnnualReportChanged:
    Q_EMIT NotifyAnnualReportChanged();
    break;
  case signalNotifyCollectionsChanged:
    Q_EMIT NotifyCollectionsChanged();
    break;
  case signalDisplayMentionChanged:
    Q_EMIT DisplayMentionChanged();
    break;
  case signalDisplayQuoteChanged:
    Q_EMIT DisplayQuoteChanged();
    break;
  case signalDisplayStatusChanged:
    Q_EMIT DisplayStatusChanged();
    break;
  case signalDisplayBoostChanged:
    Q_EMIT DisplayBoostChanged();
    break;
  case signalDisplayFollowChanged:
    Q_EMIT DisplayFollowChanged();
    break;
  case signalDisplayFollowRequestChanged:
    Q_EMIT DisplayFollowRequestChanged();
    break;
  case signalDisplayFavoriteChanged:
    Q_EMIT DisplayFavoriteChanged();
    break;
  case signalDisplayPollChanged:
    Q_EMIT DisplayPollChanged();
    break;
  case signalDisplayUpdateChanged:
    Q_EMIT DisplayUpdateChanged();
    break;
  case signalDisplaySignupChanged:
    Q_EMIT DisplaySignupChanged();
    break;
  case signalDisplayReportChanged:
    Q_EMIT DisplayReportChanged();
    break;
  case signalDisplayRelationshipsChanged:
    Q_EMIT DisplayRelationshipsChanged();
    break;
  case signalDisplayAnnualReportChanged:
    Q_EMIT DisplayAnnualReportChanged();
    break;
  case signalDisplayCollectionsChanged:
    Q_EMIT DisplayCollectionsChanged();
    break;
  case signalNotifyPolicyChanged:
    Q_EMIT NotifyPolicyChanged();
    break;
  case signalLastPushNotificationChanged:
    Q_EMIT LastPushNotificationChanged();
    break;
  case signalEnablePushNotificationsChanged:
    Q_EMIT EnablePushNotificationsChanged();
    break;
  case signalFavoriteListIdsChanged:
    Q_EMIT FavoriteListIdsChanged();
    break;
  }
}
