/****************************************************************************
** Meta object code from reading C++ file 'notification.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/timeline/notification.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notification.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14AccountWarningE_t {};
} // unnamed namespace

template <> constexpr inline auto AccountWarning::qt_create_metaobjectdata<qt_meta_tag_ZN14AccountWarningE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AccountWarning",
        "id",
        "action",
        "Action",
        "text",
        "None",
        "Disable",
        "MarkStatusesAsSensitive",
        "DeleteStatuses",
        "Sensitive",
        "Silence",
        "Suspend"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'action'
        QtMocHelpers::PropertyData<enum Action>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Action'
        QtMocHelpers::EnumData<enum Action>(3, 3, QMC::EnumFlags{}).add({
            {    5, Action::None },
            {    6, Action::Disable },
            {    7, Action::MarkStatusesAsSensitive },
            {    8, Action::DeleteStatuses },
            {    9, Action::Sensitive },
            {   10, Action::Silence },
            {   11, Action::Suspend },
        }),
    };
    return QtMocHelpers::metaObjectData<AccountWarning, qt_meta_tag_ZN14AccountWarningE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AccountWarning::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AccountWarningE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AccountWarningE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AccountWarningE_t>.metaTypes,
    nullptr
} };

void AccountWarning::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<AccountWarning *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<enum Action*>(_v) = _t->action(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN26RelationshipSeveranceEventE_t {};
} // unnamed namespace

template <> constexpr inline auto RelationshipSeveranceEvent::qt_create_metaobjectdata<qt_meta_tag_ZN26RelationshipSeveranceEventE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RelationshipSeveranceEvent",
        "id",
        "type",
        "Type",
        "purged",
        "targetName",
        "followersCount",
        "followingCount",
        "DomainBlock",
        "UserDomainBlock",
        "AccountSuspension"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'purged'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'targetName'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'followersCount'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'followingCount'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(3, 3, QMC::EnumFlags{}).add({
            {    8, Type::DomainBlock },
            {    9, Type::UserDomainBlock },
            {   10, Type::AccountSuspension },
        }),
    };
    return QtMocHelpers::metaObjectData<RelationshipSeveranceEvent, qt_meta_tag_ZN26RelationshipSeveranceEventE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RelationshipSeveranceEvent::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26RelationshipSeveranceEventE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26RelationshipSeveranceEventE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26RelationshipSeveranceEventE_t>.metaTypes,
    nullptr
} };

void RelationshipSeveranceEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<RelationshipSeveranceEvent *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<enum Type*>(_v) = _t->type(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->purged(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->targetName(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->followersCount(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->followingCount(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17AnnualReportEventE_t {};
} // unnamed namespace

template <> constexpr inline auto AnnualReportEvent::qt_create_metaobjectdata<qt_meta_tag_ZN17AnnualReportEventE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AnnualReportEvent",
        "QML.Element",
        "annualReportEvent",
        "year"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'year'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AnnualReportEvent, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AnnualReportEvent::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AnnualReportEventE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AnnualReportEventE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17AnnualReportEventE_t>.metaTypes,
    nullptr
} };

void AnnualReportEvent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<AnnualReportEvent *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->year(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN12NotificationE_t {};
} // unnamed namespace

template <> constexpr inline auto Notification::qt_create_metaobjectdata<qt_meta_tag_ZN12NotificationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Notification",
        "QML.Element",
        "notification",
        "Type",
        "Unknown",
        "Mention",
        "Follow",
        "Repeat",
        "Favorite",
        "Poll",
        "FollowRequest",
        "Update",
        "Status",
        "AdminSignUp",
        "AdminReport",
        "SeveredRelationships",
        "ModerationWarning",
        "AnnualReport",
        "Quote",
        "AddedToCollection",
        "CollectionUpdate"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(3, 3, QMC::EnumFlags{}).add({
            {    4, Type::Unknown },
            {    5, Type::Mention },
            {    6, Type::Follow },
            {    7, Type::Repeat },
            {    8, Type::Favorite },
            {    9, Type::Poll },
            {   10, Type::FollowRequest },
            {   11, Type::Update },
            {   12, Type::Status },
            {   13, Type::AdminSignUp },
            {   14, Type::AdminReport },
            {   15, Type::SeveredRelationships },
            {   16, Type::ModerationWarning },
            {   17, Type::AnnualReport },
            {   18, Type::Quote },
            {   19, Type::AddedToCollection },
            {   20, Type::CollectionUpdate },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Notification, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Notification::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NotificationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NotificationE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12NotificationE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19NotificationDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationDerived::qt_create_metaobjectdata<qt_meta_tag_ZN19NotificationDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NotificationDerived, qt_meta_tag_ZN19NotificationDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NotificationDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<Notification>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19NotificationDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19NotificationDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN26NotificationDerivedForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN26NotificationDerivedForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationDerivedForeign",
        "QML.Element",
        "Notification",
        "QML.Foreign",
        "NotificationDerived",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN26NotificationDerivedForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN26NotificationDerivedForeignE =
    NotificationDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN26NotificationDerivedForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN26NotificationDerivedForeignE =
    qt_staticMetaObjectContent_ZN26NotificationDerivedForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN26NotificationDerivedForeignE =
    qt_staticMetaObjectContent_ZN26NotificationDerivedForeignE.relocatingData;

Q_CONSTINIT const QMetaObject NotificationDerivedForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN26NotificationDerivedForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN26NotificationDerivedForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN26NotificationDerivedForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
