/****************************************************************************
** Meta object code from reading C++ file 'accounttoolmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/admin/accounttoolmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accounttoolmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17AccountsToolModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AccountsToolModel::qt_create_metaobjectdata<qt_meta_tag_ZN17AccountsToolModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AccountsToolModel",
        "QML.Element",
        "auto",
        "loadingChanged",
        "",
        "locationChanged",
        "moderationStatusChanged",
        "roleChanged",
        "usernameChanged",
        "displayNameChanged",
        "emailChanged",
        "ipChanged",
        "deleteAccountData",
        "row",
        "approveAccount",
        "rejectAccount",
        "enableAccount",
        "unsilenceAccount",
        "unsuspendAccount",
        "unsensitiveAccount",
        "actionAgainstAccount",
        "type",
        "emailWarning",
        "note",
        "loading",
        "location",
        "moderationStatus",
        "role",
        "username",
        "displayName",
        "email",
        "ip",
        "selectedAccountPosition"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'locationChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'moderationStatusChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'roleChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usernameChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayNameChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emailChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ipChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'deleteAccountData'
        QtMocHelpers::MethodData<void(int)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'approveAccount'
        QtMocHelpers::MethodData<void(int)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'rejectAccount'
        QtMocHelpers::MethodData<void(int)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'enableAccount'
        QtMocHelpers::MethodData<void(int)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'unsilenceAccount'
        QtMocHelpers::MethodData<void(int)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'unsuspendAccount'
        QtMocHelpers::MethodData<void(int)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'unsensitiveAccount'
        QtMocHelpers::MethodData<void(int)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'actionAgainstAccount'
        QtMocHelpers::MethodData<void(int, const QString &, const bool &, const QString &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { QMetaType::QString, 21 }, { QMetaType::Bool, 22 }, { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'location'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'moderationStatus'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'role'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'username'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'email'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'ip'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'selectedAccountPosition'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AccountsToolModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AccountsToolModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AccountsToolModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AccountsToolModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17AccountsToolModelE_t>.metaTypes,
    nullptr
} };

void AccountsToolModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountsToolModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loadingChanged(); break;
        case 1: _t->locationChanged(); break;
        case 2: _t->moderationStatusChanged(); break;
        case 3: _t->roleChanged(); break;
        case 4: _t->usernameChanged(); break;
        case 5: _t->displayNameChanged(); break;
        case 6: _t->emailChanged(); break;
        case 7: _t->ipChanged(); break;
        case 8: _t->deleteAccountData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->approveAccount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->rejectAccount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->enableAccount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->unsilenceAccount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->unsuspendAccount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->unsensitiveAccount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->actionAgainstAccount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountsToolModel::*)()>(_a, &AccountsToolModel::loadingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsToolModel::*)()>(_a, &AccountsToolModel::locationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsToolModel::*)()>(_a, &AccountsToolModel::moderationStatusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsToolModel::*)()>(_a, &AccountsToolModel::roleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsToolModel::*)()>(_a, &AccountsToolModel::usernameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsToolModel::*)()>(_a, &AccountsToolModel::displayNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsToolModel::*)()>(_a, &AccountsToolModel::emailChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountsToolModel::*)()>(_a, &AccountsToolModel::ipChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->location(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->moderationStatus(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->role(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->username(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->email(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->ip(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->selectedAccountPosition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setLocation(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setModerationStatus(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setRole(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setUsername(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setDisplayName(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setEmail(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setIp(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AccountsToolModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AccountsToolModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17AccountsToolModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int AccountsToolModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void AccountsToolModel::loadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AccountsToolModel::locationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AccountsToolModel::moderationStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AccountsToolModel::roleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AccountsToolModel::usernameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AccountsToolModel::displayNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AccountsToolModel::emailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AccountsToolModel::ipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
