/****************************************************************************
** Meta object code from reading C++ file 'timelinemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/timeline/timelinemodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timelinemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13TimelineModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineModel::qt_create_metaobjectdata<qt_meta_tag_ZN13TimelineModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineModel",
        "wantReply",
        "",
        "AbstractAccount*",
        "account",
        "Post*",
        "post",
        "QModelIndex",
        "index",
        "nameChanged",
        "shouldLoadMoreChanged",
        "showRepliesChanged",
        "showBoostsChanged",
        "showQuotesChanged",
        "repositionAt",
        "streamedPostAdded",
        "postId",
        "actionReply",
        "actionFavorite",
        "actionRepeat",
        "actionVote",
        "QList<int>",
        "choices",
        "actionBookmark",
        "actionRedraft",
        "isEdit",
        "actionDelete",
        "actionPin",
        "actionMute",
        "reset",
        "displayName",
        "shouldLoadMore",
        "showReplies",
        "showBoosts",
        "showQuotes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wantReply'
        QtMocHelpers::SignalData<void(AbstractAccount *, Post *, const QModelIndex &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shouldLoadMoreChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showRepliesChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showBoostsChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showQuotesChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'repositionAt'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'streamedPostAdded'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'actionReply'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'actionFavorite'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'actionRepeat'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'actionVote'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QList<int> &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'actionBookmark'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'actionRedraft'
        QtMocHelpers::SlotData<void(const QModelIndex &, bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'actionDelete'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'actionPin'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'actionMute'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'shouldLoadMore'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'showReplies'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'showBoosts'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'showQuotes'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TimelineModel, qt_meta_tag_ZN13TimelineModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TimelineModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractTimelineModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TimelineModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TimelineModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13TimelineModelE_t>.metaTypes,
    nullptr
} };

void TimelineModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimelineModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wantReply((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Post*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[3]))); break;
        case 1: _t->nameChanged(); break;
        case 2: _t->shouldLoadMoreChanged(); break;
        case 3: _t->showRepliesChanged(); break;
        case 4: _t->showBoostsChanged(); break;
        case 5: _t->showQuotesChanged(); break;
        case 6: _t->repositionAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->streamedPostAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->actionReply((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: _t->actionFavorite((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->actionRepeat((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 11: _t->actionVote((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 12: _t->actionBookmark((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 13: _t->actionRedraft((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->actionDelete((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 15: _t->actionPin((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 16: _t->actionMute((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 17: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Post* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(AbstractAccount * , Post * , const QModelIndex & )>(_a, &TimelineModel::wantReply, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::shouldLoadMoreChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::showRepliesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::showBoostsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::showQuotesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(int )>(_a, &TimelineModel::repositionAt, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(const QString & )>(_a, &TimelineModel::streamedPostAdded, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->m_shouldLoadMore; break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->m_showReplies; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->m_showBoosts; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_showQuotes; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setShouldLoadMore(*reinterpret_cast<bool*>(_v)); break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_showReplies, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->showRepliesChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_showBoosts, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->showBoostsChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_showQuotes, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->showQuotesChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *TimelineModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimelineModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TimelineModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractTimelineModel::qt_metacast(_clname);
}

int TimelineModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTimelineModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void TimelineModel::wantReply(AbstractAccount * _t1, Post * _t2, const QModelIndex & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void TimelineModel::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TimelineModel::shouldLoadMoreChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TimelineModel::showRepliesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TimelineModel::showBoostsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TimelineModel::showQuotesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TimelineModel::repositionAt(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void TimelineModel::streamedPostAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
