/****************************************************************************
** Meta object code from reading C++ file 'post.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/datatypes/post.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'post.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4PostE_t {};
} // unnamed namespace

template <> constexpr inline auto Post::qt_create_metaobjectdata<qt_meta_tag_ZN4PostE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Post",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Posts should be accessed via models",
        "pollChanged",
        "",
        "replyIdentityChanged",
        "quotedPostChanged",
        "addAttachments",
        "QJsonArray",
        "attachments",
        "postId",
        "spoilerText",
        "content",
        "hasContent",
        "sensitive",
        "visibility",
        "Visibility",
        "language",
        "inReplyTo",
        "mentions",
        "poll",
        "Poll",
        "hasPoll",
        "filters",
        "authorIdentity",
        "Identity*",
        "QList<Attachment*>",
        "relativeTime",
        "absoluteTime",
        "card",
        "Card*",
        "type",
        "editedAt",
        "wasEdited",
        "standaloneTags",
        "quotedPost",
        "Post*",
        "Public",
        "Unlisted",
        "Private",
        "Direct",
        "Local"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pollChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'replyIdentityChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'quotedPostChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'addAttachments'
        QtMocHelpers::MethodData<void(const QJsonArray &)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'postId'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'spoilerText'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'content'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasContent'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sensitive'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visibility'
        QtMocHelpers::PropertyData<enum Visibility>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'language'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inReplyTo'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mentions'
        QtMocHelpers::PropertyData<QStringList>(23, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'poll'
        QtMocHelpers::PropertyData<Poll>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'hasPoll'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'filters'
        QtMocHelpers::PropertyData<QStringList>(27, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'authorIdentity'
        QtMocHelpers::PropertyData<Identity*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'attachments'
        QtMocHelpers::PropertyData<QList<Attachment*>>(13, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'relativeTime'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'absoluteTime'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'card'
        QtMocHelpers::PropertyData<Card*>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'type'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'editedAt'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'wasEdited'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'standaloneTags'
        QtMocHelpers::PropertyData<QList<QString>>(38, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'quotedPost'
        QtMocHelpers::PropertyData<Post*>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Visibility'
        QtMocHelpers::EnumData<enum Visibility>(20, 20, QMC::EnumFlags{}).add({
            {   41, Visibility::Public },
            {   42, Visibility::Unlisted },
            {   43, Visibility::Private },
            {   44, Visibility::Direct },
            {   45, Visibility::Local },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Post, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Post::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4PostE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4PostE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4PostE_t>.metaTypes,
    nullptr
} };

void Post::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Post *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pollChanged(); break;
        case 1: _t->replyIdentityChanged(); break;
        case 2: _t->quotedPostChanged(); break;
        case 3: _t->addAttachments((*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Post::*)()>(_a, &Post::pollChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Post::*)()>(_a, &Post::replyIdentityChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Post::*)()>(_a, &Post::quotedPostChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Identity* >(); break;
        case 21:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Post* >(); break;
        case 13:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<Attachment*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->postId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->spoilerText(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->content(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasContent(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->sensitive(); break;
        case 5: *reinterpret_cast<enum Visibility*>(_v) = _t->visibility(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->language(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->inReplyTo(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->mentions(); break;
        case 9: _a[0] = const_cast<void*>(reinterpret_cast<const void*>(_t->poll())); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->hasPoll(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->filters(); break;
        case 12: *reinterpret_cast<Identity**>(_v) = _t->getAuthorIdentity(); break;
        case 13: *reinterpret_cast<QList<Attachment*>*>(_v) = _t->attachments(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->relativeTime(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->absoluteTime(); break;
        case 16: *reinterpret_cast<Card**>(_v) = _t->getCard(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->editedAt(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->wasEdited(); break;
        case 20: *reinterpret_cast<QList<QString>*>(_v) = _t->standaloneTags(); break;
        case 21: *reinterpret_cast<Post**>(_v) = _t->quotedPost(); break;
        default: break;
        }
    }
}

const QMetaObject *Post::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Post::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4PostE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Post::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void Post::pollChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Post::replyIdentityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Post::quotedPostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
