/****************************************************************************
** Meta object code from reading C++ file 'emojimodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/utils/emojimodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'emojimodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5EmojiE_t {};
} // unnamed namespace

template <> constexpr inline auto Emoji::qt_create_metaobjectdata<qt_meta_tag_ZN5EmojiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Emoji",
        "unicode",
        "shortName",
        "description",
        "isCustom"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'unicode'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'shortName'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isCustom'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Emoji, qt_meta_tag_ZN5EmojiE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Emoji::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EmojiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5EmojiE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5EmojiE_t>.metaTypes,
    nullptr
} };

void Emoji::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Emoji *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->unicode; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->shortName; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->description; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isCustom; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->unicode, *reinterpret_cast<QString*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->shortName, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->description, *reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->isCustom, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN10EmojiModelE_t {};
} // unnamed namespace

template <> constexpr inline auto EmojiModel::qt_create_metaobjectdata<qt_meta_tag_ZN10EmojiModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EmojiModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "historyChanged",
        "",
        "emojiUsed",
        "AbstractAccount*",
        "account",
        "shortcode",
        "filterModel",
        "QVariantList",
        "filter",
        "emojis",
        "Category",
        "category",
        "tones",
        "QList<Emoji>",
        "baseEmoji",
        "history",
        "categories",
        "Custom",
        "Search",
        "History",
        "Smileys",
        "People",
        "Nature",
        "Food",
        "Activities",
        "Travel",
        "Objects",
        "Symbols",
        "Flags",
        "Component"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'historyChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'emojiUsed'
        QtMocHelpers::SlotData<void(AbstractAccount *, const QString &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 },
        }}),
        // Method 'filterModel'
        QtMocHelpers::MethodData<QVariantList(AbstractAccount *, const QString &)>(11, 6, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 13 },
        }}),
        // Method 'emojis'
        QtMocHelpers::MethodData<QVariantList(AbstractAccount *, enum Category) const>(14, 6, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 15, 16 },
        }}),
        // Method 'tones'
        QtMocHelpers::MethodData<QList<Emoji>(const QString &) const>(17, 6, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'history'
        QtMocHelpers::MethodData<QStringList(AbstractAccount *) const>(20, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'categories'
        QtMocHelpers::PropertyData<QVariantList>(21, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Category'
        QtMocHelpers::EnumData<enum Category>(15, 15, QMC::EnumFlags{}).add({
            {   22, Category::Custom },
            {   23, Category::Search },
            {   24, Category::History },
            {   25, Category::Smileys },
            {   26, Category::People },
            {   27, Category::Nature },
            {   28, Category::Food },
            {   29, Category::Activities },
            {   30, Category::Travel },
            {   31, Category::Objects },
            {   32, Category::Symbols },
            {   33, Category::Flags },
            {   34, Category::Component },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<EmojiModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EmojiModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EmojiModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EmojiModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EmojiModelE_t>.metaTypes,
    nullptr
} };

void EmojiModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EmojiModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->historyChanged(); break;
        case 1: _t->emojiUsed((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: { QVariantList _r = _t->filterModel((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 3: { QVariantList _r = _t->emojis((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Category>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 4: { QList<Emoji> _r = _t->tones((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<Emoji>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QStringList _r = _t->history((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EmojiModel::*)()>(_a, &EmojiModel::historyChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantList*>(_v) = _t->categories(); break;
        default: break;
        }
    }
}

const QMetaObject *EmojiModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EmojiModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EmojiModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EmojiModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void EmojiModel::historyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
