/****************************************************************************
** Meta object code from reading C++ file 'accountmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/account/accountmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accountmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14AccountManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto AccountManager::qt_create_metaobjectdata<qt_meta_tag_ZN14AccountManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AccountManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "accountAdded",
        "",
        "AbstractAccount*",
        "account",
        "accountRemoved",
        "accountsChanged",
        "accountsReady",
        "accountsReloaded",
        "accountSelected",
        "identityChanged",
        "childIdentityChanged",
        "slotAccountCreationFinished",
        "QDBusObjectPath",
        "path",
        "xdgActivationToken",
        "addAccount",
        "removeAccount",
        "selectedAccountHasIssue",
        "accountHasIssue",
        "selectedAccountLoginIssue",
        "createNewAccount",
        "instanceUri",
        "requestSystemAccount",
        "QWindow*",
        "context",
        "isReady",
        "hasAccounts",
        "hasAnyAccounts",
        "selectedAccount",
        "selectedAccountId",
        "selectedIndex",
        "isFlatpak",
        "testMode",
        "supportsSystemAccounts"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accountAdded'
        QtMocHelpers::SignalData<void(AbstractAccount *)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'accountRemoved'
        QtMocHelpers::SignalData<void(AbstractAccount *)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'accountsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accountsReady'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accountsReloaded'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accountSelected'
        QtMocHelpers::SignalData<void(AbstractAccount *)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void(AbstractAccount *)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'childIdentityChanged'
        QtMocHelpers::SlotData<void(AbstractAccount *)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'slotAccountCreationFinished'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QString, 19 },
        }}),
        // Method 'addAccount'
        QtMocHelpers::MethodData<void(AbstractAccount *)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'removeAccount'
        QtMocHelpers::MethodData<void(AbstractAccount *)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'selectedAccountHasIssue'
        QtMocHelpers::MethodData<bool() const>(22, 6, QMC::AccessPublic, QMetaType::Bool),
        // Method 'accountHasIssue'
        QtMocHelpers::MethodData<bool(AbstractAccount *) const>(23, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'selectedAccountLoginIssue'
        QtMocHelpers::MethodData<QString() const>(24, 6, QMC::AccessPublic, QMetaType::QString),
        // Method 'createNewAccount'
        QtMocHelpers::MethodData<AbstractAccount *(const QString &)>(25, 6, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'requestSystemAccount'
        QtMocHelpers::MethodData<void(QWindow *)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isReady'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'hasAccounts'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'hasAnyAccounts'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'selectedAccount'
        QtMocHelpers::PropertyData<AbstractAccount*>(33, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 5),
        // property 'selectedAccountId'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'selectedIndex'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'isFlatpak'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'selectedAccountHasIssue'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'testMode'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supportsSystemAccounts'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AccountManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AccountManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AccountManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AccountManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AccountManagerE_t>.metaTypes,
    nullptr
} };

void AccountManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accountAdded((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1]))); break;
        case 1: _t->accountRemoved((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1]))); break;
        case 2: _t->accountsChanged(); break;
        case 3: _t->accountsReady(); break;
        case 4: _t->accountsReloaded(); break;
        case 5: _t->accountSelected((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1]))); break;
        case 6: _t->identityChanged((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1]))); break;
        case 7: _t->childIdentityChanged((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1]))); break;
        case 8: _t->slotAccountCreationFinished((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->addAccount((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1]))); break;
        case 10: _t->removeAccount((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1]))); break;
        case 11: { bool _r = _t->selectedAccountHasIssue();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->accountHasIssue((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->selectedAccountLoginIssue();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { AbstractAccount* _r = _t->createNewAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<AbstractAccount**>(_a[0]) = std::move(_r); }  break;
        case 15: _t->requestSystemAccount((*reinterpret_cast<std::add_pointer_t<QWindow*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountManager::*)(AbstractAccount * )>(_a, &AccountManager::accountAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountManager::*)(AbstractAccount * )>(_a, &AccountManager::accountRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountManager::*)()>(_a, &AccountManager::accountsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountManager::*)()>(_a, &AccountManager::accountsReady, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountManager::*)()>(_a, &AccountManager::accountsReloaded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountManager::*)(AbstractAccount * )>(_a, &AccountManager::accountSelected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountManager::*)(AbstractAccount * )>(_a, &AccountManager::identityChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AbstractAccount* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isReady(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasAccounts(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasAnyAccounts(); break;
        case 3: *reinterpret_cast<AbstractAccount**>(_v) = _t->selectedAccount(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->selectedAccountId(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->selectedIndex(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isFlatpak(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->selectedAccountHasIssue(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->testMode(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->supportsSystemAccounts(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->selectAccount(*reinterpret_cast<AbstractAccount**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AccountManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AccountManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AccountManagerE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int AccountManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void AccountManager::accountAdded(AbstractAccount * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AccountManager::accountRemoved(AbstractAccount * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AccountManager::accountsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AccountManager::accountsReady()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AccountManager::accountsReloaded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AccountManager::accountSelected(AbstractAccount * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AccountManager::identityChanged(AbstractAccount * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
