/****************************************************************************
** Meta object code from reading C++ file 'navigation.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/utils/navigation.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'navigation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10NavigationE_t {};
} // unnamed namespace

template <> constexpr inline auto Navigation::qt_create_metaobjectdata<qt_meta_tag_ZN10NavigationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Navigation",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "openComposer",
        "",
        "text",
        "openConversation",
        "accountId",
        "replyTo",
        "Post*",
        "post",
        "openAccount",
        "openPost",
        "postId",
        "openFullScreenImage",
        "QVariant",
        "attachments",
        "Identity*",
        "identity",
        "currentIndex",
        "openTag",
        "tag",
        "reportPost",
        "reportUser",
        "openList",
        "listId",
        "listName",
        "searchFor",
        "query",
        "openCollection",
        "collectionId",
        "collectionName",
        "isDebug",
        "hasWebView"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openComposer'
        QtMocHelpers::SignalData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'openConversation'
        QtMocHelpers::SignalData<void(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'replyTo'
        QtMocHelpers::SignalData<void(Post *)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'openAccount'
        QtMocHelpers::SignalData<void(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'openPost'
        QtMocHelpers::SignalData<void(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'openFullScreenImage'
        QtMocHelpers::SignalData<void(const QVariant &, Identity *, int)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 }, { QMetaType::Int, 21 },
        }}),
        // Signal 'openTag'
        QtMocHelpers::SignalData<void(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Signal 'reportPost'
        QtMocHelpers::SignalData<void(Identity *, const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'reportUser'
        QtMocHelpers::SignalData<void(Identity *)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'openList'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 28 },
        }}),
        // Signal 'searchFor'
        QtMocHelpers::SignalData<void(const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Signal 'openCollection'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 33 },
        }}),
        // Method 'isDebug'
        QtMocHelpers::MethodData<bool() const>(34, 6, QMC::AccessPublic, QMetaType::Bool),
        // Method 'hasWebView'
        QtMocHelpers::MethodData<bool() const>(35, 6, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Navigation, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Navigation::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10NavigationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10NavigationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10NavigationE_t>.metaTypes,
    nullptr
} };

void Navigation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Navigation *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openComposer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->openConversation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->replyTo((*reinterpret_cast<std::add_pointer_t<Post*>>(_a[1]))); break;
        case 3: _t->openAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->openPost((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->openFullScreenImage((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->openTag((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->reportPost((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->reportUser((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1]))); break;
        case 9: _t->openList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->searchFor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->openCollection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: { bool _r = _t->isDebug();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->hasWebView();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Post* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(const QString & )>(_a, &Navigation::openComposer, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(const QString & )>(_a, &Navigation::openConversation, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(Post * )>(_a, &Navigation::replyTo, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(const QString & )>(_a, &Navigation::openAccount, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(const QString & )>(_a, &Navigation::openPost, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(const QVariant & , Identity * , int )>(_a, &Navigation::openFullScreenImage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(const QString & )>(_a, &Navigation::openTag, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(Identity * , const QString & )>(_a, &Navigation::reportPost, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(Identity * )>(_a, &Navigation::reportUser, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(const QString & , const QString & )>(_a, &Navigation::openList, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(const QString & )>(_a, &Navigation::searchFor, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Navigation::*)(const QString & , const QString & )>(_a, &Navigation::openCollection, 11))
            return;
    }
}

const QMetaObject *Navigation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Navigation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10NavigationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Navigation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void Navigation::openComposer(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Navigation::openConversation(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Navigation::replyTo(Post * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Navigation::openAccount(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Navigation::openPost(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Navigation::openFullScreenImage(const QVariant & _t1, Identity * _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void Navigation::openTag(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Navigation::reportPost(Identity * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Navigation::reportUser(Identity * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Navigation::openList(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void Navigation::searchFor(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Navigation::openCollection(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}
QT_WARNING_POP
