/****************************************************************************
** Meta object code from reading C++ file 'posteditorbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/editor/posteditorbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'posteditorbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17PostEditorBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto PostEditorBackend::qt_create_metaobjectdata<qt_meta_tag_ZN17PostEditorBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PostEditorBackend",
        "QML.Element",
        "auto",
        "statusChanged",
        "",
        "spoilerTextChanged",
        "inReplyToChanged",
        "visibilityChanged",
        "languageChanged",
        "scheduledAtChanged",
        "mentionsChanged",
        "accountChanged",
        "sensitiveChanged",
        "editComplete",
        "QJsonObject",
        "object",
        "posted",
        "error",
        "pollEnabledChanged",
        "scheduledPostLoaded",
        "save",
        "edit",
        "saveDraft",
        "loadScheduledPost",
        "id",
        "copyFromOther",
        "PostEditorBackend*",
        "other",
        "setupReplyTo",
        "Post*",
        "post",
        "status",
        "inReplyTo",
        "spoilerText",
        "visibility",
        "Post::Visibility",
        "language",
        "scheduledAt",
        "mentions",
        "attachmentEditorModel",
        "AttachmentEditorModel*",
        "sensitive",
        "poll",
        "PollEditorBackend*",
        "pollEnabled",
        "charactersLeft",
        "account",
        "AbstractAccount*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spoilerTextChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inReplyToChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibilityChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'languageChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scheduledAtChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mentionsChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accountChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sensitiveChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editComplete'
        QtMocHelpers::SignalData<void(QJsonObject)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'posted'
        QtMocHelpers::SignalData<void(QString)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'pollEnabledChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scheduledPostLoaded'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'edit'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveDraft'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadScheduledPost'
        QtMocHelpers::SlotData<void(const QString &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Method 'copyFromOther'
        QtMocHelpers::MethodData<void(PostEditorBackend *)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Method 'setupReplyTo'
        QtMocHelpers::MethodData<void(Post *)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'status'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'inReplyTo'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'spoilerText'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'visibility'
        QtMocHelpers::PropertyData<Post::Visibility>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'language'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'scheduledAt'
        QtMocHelpers::PropertyData<QDateTime>(37, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'mentions'
        QtMocHelpers::PropertyData<QStringList>(38, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'attachmentEditorModel'
        QtMocHelpers::PropertyData<AttachmentEditorModel*>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sensitive'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'poll'
        QtMocHelpers::PropertyData<PollEditorBackend*>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'pollEnabled'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 11),
        // property 'charactersLeft'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'account'
        QtMocHelpers::PropertyData<AbstractAccount*>(46, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PostEditorBackend, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17PostEditorBackendE[] = {
    QMetaObject::SuperData::link<Post::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject PostEditorBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PostEditorBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PostEditorBackendE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17PostEditorBackendE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17PostEditorBackendE_t>.metaTypes,
    nullptr
} };

void PostEditorBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PostEditorBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusChanged(); break;
        case 1: _t->spoilerTextChanged(); break;
        case 2: _t->inReplyToChanged(); break;
        case 3: _t->visibilityChanged(); break;
        case 4: _t->languageChanged(); break;
        case 5: _t->scheduledAtChanged(); break;
        case 6: _t->mentionsChanged(); break;
        case 7: _t->accountChanged(); break;
        case 8: _t->sensitiveChanged(); break;
        case 9: _t->editComplete((*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[1]))); break;
        case 10: _t->posted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->pollEnabledChanged(); break;
        case 12: _t->scheduledPostLoaded(); break;
        case 13: _t->save(); break;
        case 14: _t->edit(); break;
        case 15: _t->saveDraft(); break;
        case 16: _t->loadScheduledPost((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->copyFromOther((*reinterpret_cast<std::add_pointer_t<PostEditorBackend*>>(_a[1]))); break;
        case 18: _t->setupReplyTo((*reinterpret_cast<std::add_pointer_t<Post*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PostEditorBackend* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Post* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::statusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::spoilerTextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::inReplyToChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::visibilityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::languageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::scheduledAtChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::mentionsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::accountChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::sensitiveChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)(QJsonObject )>(_a, &PostEditorBackend::editComplete, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)(QString )>(_a, &PostEditorBackend::posted, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::pollEnabledChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PostEditorBackend::*)()>(_a, &PostEditorBackend::scheduledPostLoaded, 12))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PollEditorBackend* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->status(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->inReplyTo(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->spoilerText(); break;
        case 3: *reinterpret_cast<Post::Visibility*>(_v) = _t->visibility(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->language(); break;
        case 5: *reinterpret_cast<QDateTime*>(_v) = _t->scheduledAt(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->mentions(); break;
        case 7: *reinterpret_cast<AttachmentEditorModel**>(_v) = _t->attachmentEditorModel(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->sensitive(); break;
        case 9: *reinterpret_cast<PollEditorBackend**>(_v) = _t->m_poll; break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->m_pollEnabled; break;
        case 11: *reinterpret_cast<int*>(_v) = _t->charactersLeft(); break;
        case 12: *reinterpret_cast<AbstractAccount**>(_v) = _t->account(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setStatus(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setInReplyTo(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setSpoilerText(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setVisibility(*reinterpret_cast<Post::Visibility*>(_v)); break;
        case 4: _t->setLanguage(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setScheduledAt(*reinterpret_cast<QDateTime*>(_v)); break;
        case 6: _t->setMentions(*reinterpret_cast<QStringList*>(_v)); break;
        case 8: _t->setSensitive(*reinterpret_cast<bool*>(_v)); break;
        case 10:
            if (QtMocHelpers::setProperty(_t->m_pollEnabled, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->pollEnabledChanged();
            break;
        case 12: _t->setAccount(*reinterpret_cast<AbstractAccount**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PostEditorBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PostEditorBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PostEditorBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PostEditorBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void PostEditorBackend::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PostEditorBackend::spoilerTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PostEditorBackend::inReplyToChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PostEditorBackend::visibilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PostEditorBackend::languageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PostEditorBackend::scheduledAtChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PostEditorBackend::mentionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PostEditorBackend::accountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PostEditorBackend::sensitiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PostEditorBackend::editComplete(QJsonObject _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void PostEditorBackend::posted(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void PostEditorBackend::pollEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void PostEditorBackend::scheduledPostLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
