/****************************************************************************
** Meta object code from reading C++ file 'listeditorbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/editor/listeditorbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'listeditorbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17ListEditorBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto ListEditorBackend::qt_create_metaobjectdata<qt_meta_tag_ZN17ListEditorBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ListEditorBackend",
        "QML.Element",
        "auto",
        "listIdChanged",
        "",
        "titleChanged",
        "exclusiveChanged",
        "done",
        "loadingChanged",
        "favoriteChanged",
        "submit",
        "deleteList",
        "replyPolicies",
        "replyPolicyIndex",
        "setReplyPolicyIndex",
        "index",
        "listId",
        "title",
        "exclusive",
        "loading",
        "favorite"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'listIdChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exclusiveChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favoriteChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'submit'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteList'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'replyPolicies'
        QtMocHelpers::SlotData<QStringList()>(12, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'replyPolicyIndex'
        QtMocHelpers::SlotData<int() const>(13, 4, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setReplyPolicyIndex'
        QtMocHelpers::SlotData<void(int)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'listId'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'exclusive'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'favorite'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ListEditorBackend, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ListEditorBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ListEditorBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ListEditorBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ListEditorBackendE_t>.metaTypes,
    nullptr
} };

void ListEditorBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ListEditorBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->listIdChanged(); break;
        case 1: _t->titleChanged(); break;
        case 2: _t->exclusiveChanged(); break;
        case 3: _t->done(); break;
        case 4: _t->loadingChanged(); break;
        case 5: _t->favoriteChanged(); break;
        case 6: _t->submit(); break;
        case 7: _t->deleteList(); break;
        case 8: { QStringList _r = _t->replyPolicies();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->replyPolicyIndex();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setReplyPolicyIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ListEditorBackend::*)()>(_a, &ListEditorBackend::listIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListEditorBackend::*)()>(_a, &ListEditorBackend::titleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListEditorBackend::*)()>(_a, &ListEditorBackend::exclusiveChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListEditorBackend::*)()>(_a, &ListEditorBackend::done, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListEditorBackend::*)()>(_a, &ListEditorBackend::loadingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ListEditorBackend::*)()>(_a, &ListEditorBackend::favoriteChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->listId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_title; break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->m_exclusive; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_favorite; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setListId(*reinterpret_cast<QString*>(_v)); break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_title, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->titleChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_exclusive, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->exclusiveChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_favorite, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->favoriteChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *ListEditorBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ListEditorBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ListEditorBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ListEditorBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ListEditorBackend::listIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ListEditorBackend::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ListEditorBackend::exclusiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ListEditorBackend::done()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ListEditorBackend::loadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ListEditorBackend::favoriteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
