/****************************************************************************
** Meta object code from reading C++ file 'adminaccountinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/admin/adminaccountinfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'adminaccountinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16AdminAccountInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto AdminAccountInfo::qt_create_metaobjectdata<qt_meta_tag_ZN16AdminAccountInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdminAccountInfo",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Enum",
        "adminAccountInfoUpdated",
        "",
        "emailStatus",
        "suspended",
        "silenced",
        "sensitized",
        "disabled",
        "approved",
        "isLocal",
        "loginStatus",
        "inviteRequest",
        "ip",
        "email",
        "emailProvider",
        "locale",
        "joined",
        "lastActive",
        "role",
        "ips",
        "QJsonArray",
        "invitedByIdentity",
        "Identity*",
        "userLevelIdentity",
        "position",
        "Permission",
        "Administrator",
        "Devops",
        "ViewAuditLog",
        "ViewDashboard",
        "ManageReports",
        "ManageFederation",
        "ManageSettings",
        "ManageBlocks",
        "ManageTaxonomies",
        "ManageAppeals",
        "ManageUsers",
        "ManageInvites",
        "ManageRules",
        "ManageAnnouncements",
        "ManageCustomEmojis",
        "ManageWebhooks",
        "InviteUsers",
        "ManageRoles",
        "ManageUserAccess",
        "DeleteUserData",
        "ModerationToolAccess"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'adminAccountInfoUpdated'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'emailStatus'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'suspended'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'silenced'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'sensitized'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'disabled'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'approved'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isLocal'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'loginStatus'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'inviteRequest'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'ip'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'email'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'emailProvider'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'locale'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'joined'
        QtMocHelpers::PropertyData<QDateTime>(22, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 0),
        // property 'lastActive'
        QtMocHelpers::PropertyData<QDateTime>(23, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 0),
        // property 'role'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'ips'
        QtMocHelpers::PropertyData<QJsonArray>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'invitedByIdentity'
        QtMocHelpers::PropertyData<Identity*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'userLevelIdentity'
        QtMocHelpers::PropertyData<Identity*>(29, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'position'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Permission'
        QtMocHelpers::EnumData<enum Permission>(31, 31, QMC::EnumFlags{}).add({
            {   32, Permission::Administrator },
            {   33, Permission::Devops },
            {   34, Permission::ViewAuditLog },
            {   35, Permission::ViewDashboard },
            {   36, Permission::ManageReports },
            {   37, Permission::ManageFederation },
            {   38, Permission::ManageSettings },
            {   39, Permission::ManageBlocks },
            {   40, Permission::ManageTaxonomies },
            {   41, Permission::ManageAppeals },
            {   42, Permission::ManageUsers },
            {   43, Permission::ManageInvites },
            {   44, Permission::ManageRules },
            {   45, Permission::ManageAnnouncements },
            {   46, Permission::ManageCustomEmojis },
            {   47, Permission::ManageWebhooks },
            {   48, Permission::InviteUsers },
            {   49, Permission::ManageRoles },
            {   50, Permission::ManageUserAccess },
            {   51, Permission::DeleteUserData },
            {   52, Permission::ModerationToolAccess },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AdminAccountInfo, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AdminAccountInfo::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AdminAccountInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AdminAccountInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16AdminAccountInfoE_t>.metaTypes,
    nullptr
} };

void AdminAccountInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AdminAccountInfo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->adminAccountInfoUpdated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AdminAccountInfo::*)()>(_a, &AdminAccountInfo::adminAccountInfoUpdated, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->emailStatus(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->suspended(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->silenced(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->sensitized(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->disabled(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->approved(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isLocal(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->loginStatus(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->inviteRequest(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->ip(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->email(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->emailProvider(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->locale(); break;
        case 13: *reinterpret_cast<QDateTime*>(_v) = _t->joined(); break;
        case 14: *reinterpret_cast<QDateTime*>(_v) = _t->lastActive(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->role(); break;
        case 16: *reinterpret_cast<QJsonArray*>(_v) = _t->ips(); break;
        case 17: *reinterpret_cast<Identity**>(_v) = _t->invitedByIdentity(); break;
        case 18: *reinterpret_cast<Identity**>(_v) = _t->userLevelIdentity(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->position(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setSuspended(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setSilence(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setSensitized(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setDisabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setApproved(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AdminAccountInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdminAccountInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16AdminAccountInfoE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AdminAccountInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void AdminAccountInfo::adminAccountInfoUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
