/****************************************************************************
** Meta object code from reading C++ file 'profileeditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/account/profileeditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'profileeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20ProfileEditorBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto ProfileEditorBackend::qt_create_metaobjectdata<qt_meta_tag_ZN20ProfileEditorBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProfileEditorBackend",
        "QML.Element",
        "auto",
        "accountChanged",
        "",
        "displayNameChanged",
        "noteChanged",
        "botChanged",
        "avatarUrlChanged",
        "backgroundUrlChanged",
        "discoverableChanged",
        "lockedChanged",
        "fieldsChanged",
        "sendNotification",
        "message",
        "type",
        "save",
        "fetchAccountInfo",
        "setFieldName",
        "index",
        "name",
        "setFieldValue",
        "value",
        "addField",
        "removeField",
        "account",
        "AbstractAccount*",
        "displayName",
        "displayNameHtml",
        "note",
        "bot",
        "backgroundUrl",
        "QUrl",
        "avatarUrl",
        "backgroundUrlError",
        "avatarUrlError",
        "locked",
        "discoverable",
        "fields",
        "QJsonArray"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accountChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayNameChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'botChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'avatarUrlChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundUrlChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'discoverableChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lockedChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fieldsChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sendNotification'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'sendNotification'
        QtMocHelpers::SignalData<void(const QString &)>(13, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fetchAccountInfo'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFieldName'
        QtMocHelpers::SlotData<void(int, const QString &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::QString, 20 },
        }}),
        // Slot 'setFieldValue'
        QtMocHelpers::SlotData<void(int, const QString &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'addField'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeField'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'account'
        QtMocHelpers::PropertyData<AbstractAccount*>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Required, 0),
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'displayNameHtml'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'note'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'bot'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'backgroundUrl'
        QtMocHelpers::PropertyData<QUrl>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'avatarUrl'
        QtMocHelpers::PropertyData<QUrl>(33, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'backgroundUrlError'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'avatarUrlError'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'discoverable'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'fields'
        QtMocHelpers::PropertyData<QJsonArray>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ProfileEditorBackend, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ProfileEditorBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ProfileEditorBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ProfileEditorBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20ProfileEditorBackendE_t>.metaTypes,
    nullptr
} };

void ProfileEditorBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProfileEditorBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accountChanged(); break;
        case 1: _t->displayNameChanged(); break;
        case 2: _t->noteChanged(); break;
        case 3: _t->botChanged(); break;
        case 4: _t->avatarUrlChanged(); break;
        case 5: _t->backgroundUrlChanged(); break;
        case 6: _t->discoverableChanged(); break;
        case 7: _t->lockedChanged(); break;
        case 8: _t->fieldsChanged(); break;
        case 9: _t->sendNotification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->sendNotification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->save(); break;
        case 12: _t->fetchAccountInfo(); break;
        case 13: _t->setFieldName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->setFieldValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->addField(); break;
        case 16: _t->removeField(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProfileEditorBackend::*)()>(_a, &ProfileEditorBackend::accountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileEditorBackend::*)()>(_a, &ProfileEditorBackend::displayNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileEditorBackend::*)()>(_a, &ProfileEditorBackend::noteChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileEditorBackend::*)()>(_a, &ProfileEditorBackend::botChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileEditorBackend::*)()>(_a, &ProfileEditorBackend::avatarUrlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileEditorBackend::*)()>(_a, &ProfileEditorBackend::backgroundUrlChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileEditorBackend::*)()>(_a, &ProfileEditorBackend::discoverableChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileEditorBackend::*)()>(_a, &ProfileEditorBackend::lockedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileEditorBackend::*)()>(_a, &ProfileEditorBackend::fieldsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileEditorBackend::*)(const QString & , const QString & )>(_a, &ProfileEditorBackend::sendNotification, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<AbstractAccount**>(_v) = _t->account(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->displayNameHtml(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->note(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->bot(); break;
        case 5: *reinterpret_cast<QUrl*>(_v) = _t->backgroundUrl(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->avatarUrl(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->backgroundUrlError(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->avatarUrlError(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->discoverable(); break;
        case 11: *reinterpret_cast<QJsonArray*>(_v) = _t->fields(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAccount(*reinterpret_cast<AbstractAccount**>(_v)); break;
        case 1: _t->setDisplayName(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setNote(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setBot(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setBackgroundUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 6: _t->setAvatarUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 9: _t->setLocked(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setDiscoverable(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setFields(*reinterpret_cast<QJsonArray*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ProfileEditorBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProfileEditorBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ProfileEditorBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ProfileEditorBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ProfileEditorBackend::accountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ProfileEditorBackend::displayNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ProfileEditorBackend::noteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ProfileEditorBackend::botChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ProfileEditorBackend::avatarUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ProfileEditorBackend::backgroundUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ProfileEditorBackend::discoverableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ProfileEditorBackend::lockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ProfileEditorBackend::fieldsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ProfileEditorBackend::sendNotification(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}
QT_WARNING_POP
