/****************************************************************************
** Meta object code from reading C++ file 'collectioneditorbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/editor/collectioneditorbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'collectioneditorbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23CollectionEditorBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto CollectionEditorBackend::qt_create_metaobjectdata<qt_meta_tag_ZN23CollectionEditorBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CollectionEditorBackend",
        "QML.Element",
        "auto",
        "collectionIdChanged",
        "",
        "nameChanged",
        "done",
        "loadingChanged",
        "descriptionChanged",
        "sensitiveChanged",
        "discoverableChanged",
        "submit",
        "deleteCollection",
        "collectionId",
        "name",
        "description",
        "sensitive",
        "discoverable",
        "loading"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'collectionIdChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sensitiveChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'discoverableChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'submit'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteCollection'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'collectionId'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'sensitive'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'discoverable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 6),
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<CollectionEditorBackend, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CollectionEditorBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23CollectionEditorBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23CollectionEditorBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23CollectionEditorBackendE_t>.metaTypes,
    nullptr
} };

void CollectionEditorBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CollectionEditorBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->collectionIdChanged(); break;
        case 1: _t->nameChanged(); break;
        case 2: _t->done(); break;
        case 3: _t->loadingChanged(); break;
        case 4: _t->descriptionChanged(); break;
        case 5: _t->sensitiveChanged(); break;
        case 6: _t->discoverableChanged(); break;
        case 7: _t->submit(); break;
        case 8: _t->deleteCollection(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CollectionEditorBackend::*)()>(_a, &CollectionEditorBackend::collectionIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionEditorBackend::*)()>(_a, &CollectionEditorBackend::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionEditorBackend::*)()>(_a, &CollectionEditorBackend::done, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionEditorBackend::*)()>(_a, &CollectionEditorBackend::loadingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionEditorBackend::*)()>(_a, &CollectionEditorBackend::descriptionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionEditorBackend::*)()>(_a, &CollectionEditorBackend::sensitiveChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionEditorBackend::*)()>(_a, &CollectionEditorBackend::discoverableChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->collectionId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_name; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_description; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->m_sensitive; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_discoverable; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCollectionId(*reinterpret_cast<QString*>(_v)); break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_name, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->nameChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_description, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->descriptionChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_sensitive, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->sensitiveChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_discoverable, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->discoverableChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *CollectionEditorBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CollectionEditorBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23CollectionEditorBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CollectionEditorBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void CollectionEditorBackend::collectionIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CollectionEditorBackend::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CollectionEditorBackend::done()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CollectionEditorBackend::loadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CollectionEditorBackend::descriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CollectionEditorBackend::sensitiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CollectionEditorBackend::discoverableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
