/****************************************************************************
** Meta object code from reading C++ file 'filtereditorbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/editor/filtereditorbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filtereditorbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19FilterEditorBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto FilterEditorBackend::qt_create_metaobjectdata<qt_meta_tag_ZN19FilterEditorBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FilterEditorBackend",
        "QML.Element",
        "auto",
        "filterIdChanged",
        "",
        "titleChanged",
        "done",
        "loadingChanged",
        "homeAndListsContextChanged",
        "notificationsContextChanged",
        "publicTimelinesContextChanged",
        "conversationsContextChanged",
        "profilesContextChanged",
        "filterActionChanged",
        "keywordsChanged",
        "submit",
        "deleteFilter",
        "removeKeyword",
        "index",
        "addKeyword",
        "editKeyword",
        "keyword",
        "editWholeWord",
        "wholeWord",
        "filterId",
        "title",
        "homeAndListsContext",
        "notificationsContext",
        "publicTimelinesContext",
        "conversationsContext",
        "profilesContext",
        "filterAction",
        "keywords",
        "QVariantList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterIdChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'homeAndListsContextChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'notificationsContextChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'publicTimelinesContextChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'conversationsContextChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'profilesContextChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterActionChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keywordsChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'submit'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteFilter'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeKeyword'
        QtMocHelpers::SlotData<void(int)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'addKeyword'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editKeyword'
        QtMocHelpers::SlotData<void(int, const QString &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'editWholeWord'
        QtMocHelpers::SlotData<void(int, bool)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 }, { QMetaType::Bool, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filterId'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'homeAndListsContext'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'notificationsContext'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'publicTimelinesContext'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 6),
        // property 'conversationsContext'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 7),
        // property 'profilesContext'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 8),
        // property 'filterAction'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 9),
        // property 'keywords'
        QtMocHelpers::PropertyData<QVariantList>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 10),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FilterEditorBackend, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FilterEditorBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19FilterEditorBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19FilterEditorBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19FilterEditorBackendE_t>.metaTypes,
    nullptr
} };

void FilterEditorBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FilterEditorBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterIdChanged(); break;
        case 1: _t->titleChanged(); break;
        case 2: _t->done(); break;
        case 3: _t->loadingChanged(); break;
        case 4: _t->homeAndListsContextChanged(); break;
        case 5: _t->notificationsContextChanged(); break;
        case 6: _t->publicTimelinesContextChanged(); break;
        case 7: _t->conversationsContextChanged(); break;
        case 8: _t->profilesContextChanged(); break;
        case 9: _t->filterActionChanged(); break;
        case 10: _t->keywordsChanged(); break;
        case 11: _t->submit(); break;
        case 12: _t->deleteFilter(); break;
        case 13: _t->removeKeyword((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->addKeyword(); break;
        case 15: _t->editKeyword((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->editWholeWord((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::filterIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::titleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::done, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::loadingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::homeAndListsContextChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::notificationsContextChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::publicTimelinesContextChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::conversationsContextChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::profilesContextChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::filterActionChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterEditorBackend::*)()>(_a, &FilterEditorBackend::keywordsChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->filterId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_title; break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->m_homeAndListsContext; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->m_notificationsContext; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_publicTimelinesContext; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->m_conversationsContext; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->m_profilesContext; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->m_filterAction; break;
        case 8: *reinterpret_cast<QVariantList*>(_v) = _t->m_keywords; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFilterId(*reinterpret_cast<QString*>(_v)); break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_title, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->titleChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_homeAndListsContext, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->homeAndListsContextChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_notificationsContext, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->notificationsContextChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_publicTimelinesContext, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->publicTimelinesContextChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_conversationsContext, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->conversationsContextChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_profilesContext, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->profilesContextChanged();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_filterAction, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->filterActionChanged();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_keywords, *reinterpret_cast<QVariantList*>(_v)))
                Q_EMIT _t->keywordsChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *FilterEditorBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FilterEditorBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19FilterEditorBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FilterEditorBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void FilterEditorBackend::filterIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FilterEditorBackend::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FilterEditorBackend::done()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FilterEditorBackend::loadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FilterEditorBackend::homeAndListsContextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FilterEditorBackend::notificationsContextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void FilterEditorBackend::publicTimelinesContextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void FilterEditorBackend::conversationsContextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void FilterEditorBackend::profilesContextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void FilterEditorBackend::filterActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void FilterEditorBackend::keywordsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
