/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<abstractaccount.h>)
#  include <abstractaccount.h>
#endif
#if __has_include(<accountconfig.h>)
#  include <accountconfig.h>
#endif
#if __has_include(<accountmanager.h>)
#  include <accountmanager.h>
#endif
#if __has_include(<accountmediatimelinemodel.h>)
#  include <accountmediatimelinemodel.h>
#endif
#if __has_include(<accountmodel.h>)
#  include <accountmodel.h>
#endif
#if __has_include(<accounttoolmodel.h>)
#  include <accounttoolmodel.h>
#endif
#if __has_include(<adminaccountinfo.h>)
#  include <adminaccountinfo.h>
#endif
#if __has_include(<announcementmodel.h>)
#  include <announcementmodel.h>
#endif
#if __has_include(<annualreport.h>)
#  include <annualreport.h>
#endif
#if __has_include(<attachment.h>)
#  include <attachment.h>
#endif
#if __has_include(<blockeddomainmodel.h>)
#  include <blockeddomainmodel.h>
#endif
#if __has_include(<collectioneditorbackend.h>)
#  include <collectioneditorbackend.h>
#endif
#if __has_include(<collectionmodel.h>)
#  include <collectionmodel.h>
#endif
#if __has_include(<collectionsmodel.h>)
#  include <collectionsmodel.h>
#endif
#if __has_include(<colorschemer.h>)
#  include <colorschemer.h>
#endif
#if __has_include(<config.h>)
#  include <config.h>
#endif
#if __has_include(<conversationmodel.h>)
#  include <conversationmodel.h>
#endif
#if __has_include(<emailblocktoolmodel.h>)
#  include <emailblocktoolmodel.h>
#endif
#if __has_include(<emailinfo.h>)
#  include <emailinfo.h>
#endif
#if __has_include(<emojimodel.h>)
#  include <emojimodel.h>
#endif
#if __has_include(<favoritelistsmodel.h>)
#  include <favoritelistsmodel.h>
#endif
#if __has_include(<featuredtagsmodel.h>)
#  include <featuredtagsmodel.h>
#endif
#if __has_include(<federationtoolmodel.h>)
#  include <federationtoolmodel.h>
#endif
#if __has_include(<filehelper.h>)
#  include <filehelper.h>
#endif
#if __has_include(<filtereditorbackend.h>)
#  include <filtereditorbackend.h>
#endif
#if __has_include(<filtersmodel.h>)
#  include <filtersmodel.h>
#endif
#if __has_include(<identity.h>)
#  include <identity.h>
#endif
#if __has_include(<initialsetupflow.h>)
#  include <initialsetupflow.h>
#endif
#if __has_include(<ipinfo.h>)
#  include <ipinfo.h>
#endif
#if __has_include(<iprulestoolmodel.h>)
#  include <iprulestoolmodel.h>
#endif
#if __has_include(<languagemodel.h>)
#  include <languagemodel.h>
#endif
#if __has_include(<limitermodel.h>)
#  include <limitermodel.h>
#endif
#if __has_include(<listeditorbackend.h>)
#  include <listeditorbackend.h>
#endif
#if __has_include(<listsmodel.h>)
#  include <listsmodel.h>
#endif
#if __has_include(<maintimelinemodel.h>)
#  include <maintimelinemodel.h>
#endif
#if __has_include(<navigation.h>)
#  include <navigation.h>
#endif
#if __has_include(<networkcontroller.h>)
#  include <networkcontroller.h>
#endif
#if __has_include(<networkrequestprogress.h>)
#  include <networkrequestprogress.h>
#endif
#if __has_include(<notification.h>)
#  include <notification.h>
#endif
#if __has_include(<notificationgroupingmodel.h>)
#  include <notificationgroupingmodel.h>
#endif
#if __has_include(<notificationmodel.h>)
#  include <notificationmodel.h>
#endif
#if __has_include(<polltimemodel.h>)
#  include <polltimemodel.h>
#endif
#if __has_include(<post.h>)
#  include <post.h>
#endif
#if __has_include(<posteditorbackend.h>)
#  include <posteditorbackend.h>
#endif
#if __has_include(<profileeditor.h>)
#  include <profileeditor.h>
#endif
#if __has_include(<publicserversmodel.h>)
#  include <publicserversmodel.h>
#endif
#if __has_include(<reporteditorbackend.h>)
#  include <reporteditorbackend.h>
#endif
#if __has_include(<reporttoolmodel.h>)
#  include <reporttoolmodel.h>
#endif
#if __has_include(<rulesmodel.h>)
#  include <rulesmodel.h>
#endif
#if __has_include(<scheduledstatusesmodel.h>)
#  include <scheduledstatusesmodel.h>
#endif
#if __has_include(<searchmodel.h>)
#  include <searchmodel.h>
#endif
#if __has_include(<serverinformation.h>)
#  include <serverinformation.h>
#endif
#if __has_include(<socialgraphmodel.h>)
#  include <socialgraphmodel.h>
#endif
#if __has_include(<suggestionsmodel.h>)
#  include <suggestionsmodel.h>
#endif
#if __has_include(<tagsmodel.h>)
#  include <tagsmodel.h>
#endif
#if __has_include(<tagstimelinemodel.h>)
#  include <tagstimelinemodel.h>
#endif
#if __has_include(<texthandler.h>)
#  include <texthandler.h>
#endif
#if __has_include(<threadmodel.h>)
#  include <threadmodel.h>
#endif
#if __has_include(<tokodonapplication.h>)
#  include <tokodonapplication.h>
#endif
#if __has_include(<trendingnewsmodel.h>)
#  include <trendingnewsmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_tokodon()
{
    qmlRegisterModule("org.kde.tokodon", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AbstractAccount>("org.kde.tokodon", 254);
    QMetaType::fromType<AbstractListModel *>().id();
    QMetaType::fromType<AbstractTimelineModel *>().id();
    qmlRegisterTypesAndRevisions<AccountConfig>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<AccountManager>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<AccountMediaTimelineModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<AccountModel>("org.kde.tokodon", 254);
    qmlRegisterEnum<AccountModel::AccountTab>("AccountModel::AccountTab");
    qmlRegisterTypesAndRevisions<AccountsToolModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<AdminAccountInfo>("org.kde.tokodon", 254);
    qmlRegisterEnum<AdminAccountInfo::Permission>("AdminAccountInfo::Permission");
    qmlRegisterTypesAndRevisions<AnnouncementModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<AnnualReport>("org.kde.tokodon", 254);
    QMetaType::fromType<AnnualReport *>().id();
    qmlRegisterTypesAndRevisions<AnnualReportEvent>("org.kde.tokodon", 254);
    QMetaType::fromType<AnnualReportEvent *>().id();
    qmlRegisterTypesAndRevisions<AnnualReports>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<Attachment>("org.kde.tokodon", 254);
    qmlRegisterEnum<Attachment::AttachmentType>("Attachment::AttachmentType");
    qmlRegisterTypesAndRevisions<BlockedDomainModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<CollectionEditorBackend>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<CollectionModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<CollectionsModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<ColorSchemer>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<Config>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<ConversationModel>("org.kde.tokodon", 254);
    qmlRegisterEnum<ConversationModel::ExtraRole>("ConversationModel::ExtraRole");
    qmlRegisterTypesAndRevisions<EmailBlockToolModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<EmailInfo>("org.kde.tokodon", 254);
    QMetaType::fromType<EmailInfo *>().id();
    qmlRegisterEnum<EmailInfo::SeverityValues>("EmailInfo::SeverityValues");
    qmlRegisterTypesAndRevisions<EmojiModel>("org.kde.tokodon", 254);
    qmlRegisterEnum<EmojiModel::Category>("EmojiModel::Category");
    qmlRegisterTypesAndRevisions<FavoriteListsModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<FeaturedTagsModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<FederationToolModel>("org.kde.tokodon", 254);
    qmlRegisterEnum<FederationToolModel::FederationAction>("FederationToolModel::FederationAction");
    qmlRegisterTypesAndRevisions<FileHelper>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<FilterEditorBackend>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<FiltersModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<Identity>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<InitialSetupFlow>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<IpInfo>("org.kde.tokodon", 254);
    QMetaType::fromType<IpInfo *>().id();
    qmlRegisterEnum<IpInfo::SeverityValues>("IpInfo::SeverityValues");
    qmlRegisterTypesAndRevisions<IpRulesToolModel>("org.kde.tokodon", 254);
    qmlRegisterEnum<IpRulesToolModel::TimeInterval>("IpRulesToolModel::TimeInterval");
    QMetaType::fromType<KConfigSkeleton *>().id();
    QMetaType::fromType<KCoreConfigSkeleton *>().id();
    qmlRegisterEnum<KCoreConfigSkeleton::DisambiguateConstructor>("KCoreConfigSkeleton::DisambiguateConstructor");
    qmlRegisterTypesAndRevisions<LimiterModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<ListEditorBackend>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<ListsModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<MainTimelineModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<Navigation>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<NetworkController>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<NetworkRequestProgress>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<Notification>("org.kde.tokodon", 254);
    QMetaType::fromType<Notification *>().id();
    qmlRegisterEnum<Notification::Type>("Notification::Type");
    QMetaType::fromType<NotificationDerived>().id();
    qmlRegisterNamespaceAndRevisions(&NotificationDerived::staticMetaObject, "org.kde.tokodon", 254, nullptr, &NotificationDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<NotificationGroupingModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<NotificationModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<PollTimeModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<Post>("org.kde.tokodon", 254);
    qmlRegisterEnum<Post::Visibility>("Post::Visibility");
    qmlRegisterTypesAndRevisions<PostEditorBackend>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<ProfileEditorBackend>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<PublicServersModel>("org.kde.tokodon", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<RawLanguageModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<ReportEditorBackend>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<ReportToolModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<RulesModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<ScheduledStatusesModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<SearchModel>("org.kde.tokodon", 254);
    qmlRegisterEnum<SearchModel::ResultType>("SearchModel::ResultType");
    qmlRegisterTypesAndRevisions<ServerInformation>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<SocialGraphModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<SuggestionsModel>("org.kde.tokodon", 254);
    qmlRegisterEnum<SuggestionsModel::Source>("SuggestionsModel::Source");
    qmlRegisterTypesAndRevisions<TagsModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<TagsTimelineModel>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<TextHandler>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<ThreadModel>("org.kde.tokodon", 254);
    QMetaType::fromType<TimelineModel *>().id();
    qmlRegisterTypesAndRevisions<TokodonApplication>("org.kde.tokodon", 254);
    qmlRegisterTypesAndRevisions<TrendingNewsModel>("org.kde.tokodon", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.tokodon", 254, 254);
}

static const QQmlModuleRegistration orgkdetokodonRegistration("org.kde.tokodon", qml_register_types_org_kde_tokodon);
