/****************************************************************************
** Meta object code from reading C++ file 'accountmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/timeline/accountmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accountmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12AccountModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AccountModel::qt_create_metaobjectdata<qt_meta_tag_ZN12AccountModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AccountModel",
        "QML.Element",
        "auto",
        "identityChanged",
        "",
        "accountChanged",
        "accountIdChanged",
        "filtersChanged",
        "tabChanged",
        "accountId",
        "identity",
        "Identity*",
        "account",
        "AbstractAccount*",
        "isSelf",
        "excludeReplies",
        "excludeBoosts",
        "excludePinned",
        "onlyMedia",
        "tagged",
        "currentTab",
        "AccountTab",
        "Posts",
        "Replies",
        "Media",
        "None"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accountChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accountIdChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filtersChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'accountId'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'identity'
        QtMocHelpers::PropertyData<Identity*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'account'
        QtMocHelpers::PropertyData<AbstractAccount*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'isSelf'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'excludeReplies'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'excludeBoosts'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'excludePinned'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'onlyMedia'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'tagged'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'currentTab'
        QtMocHelpers::PropertyData<enum AccountTab>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AccountTab'
        QtMocHelpers::EnumData<enum AccountTab>(21, 21, QMC::EnumFlags{}).add({
            {   22, AccountTab::Posts },
            {   23, AccountTab::Replies },
            {   24, AccountTab::Media },
            {   25, AccountTab::None },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AccountModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AccountModel::staticMetaObject = { {
    QMetaObject::SuperData::link<TimelineModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AccountModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AccountModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12AccountModelE_t>.metaTypes,
    nullptr
} };

void AccountModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->identityChanged(); break;
        case 1: _t->accountChanged(); break;
        case 2: _t->accountIdChanged(); break;
        case 3: _t->filtersChanged(); break;
        case 4: _t->tabChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountModel::*)()>(_a, &AccountModel::identityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountModel::*)()>(_a, &AccountModel::accountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountModel::*)()>(_a, &AccountModel::accountIdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountModel::*)()>(_a, &AccountModel::filtersChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountModel::*)()>(_a, &AccountModel::tabChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AbstractAccount* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Identity* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->accountId(); break;
        case 1: *reinterpret_cast<Identity**>(_v) = _t->identity(); break;
        case 2: *reinterpret_cast<AbstractAccount**>(_v) = _t->account(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isSelf(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_excludeReplies; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->m_excludeBoosts; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->m_excludePinned; break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->m_onlyMedia; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->m_tagged; break;
        case 9: *reinterpret_cast<enum AccountTab*>(_v) = _t->m_currentTab; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAccountId(*reinterpret_cast<QString*>(_v)); break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_excludeReplies, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->filtersChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_excludeBoosts, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->filtersChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_excludePinned, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->filtersChanged();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_onlyMedia, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->filtersChanged();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_tagged, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->filtersChanged();
            break;
        case 9:
            if (QtMocHelpers::setProperty(_t->m_currentTab, *reinterpret_cast<enum AccountTab*>(_v)))
                Q_EMIT _t->tabChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *AccountModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AccountModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AccountModelE_t>.strings))
        return static_cast<void*>(this);
    return TimelineModel::qt_metacast(_clname);
}

int AccountModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TimelineModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void AccountModel::identityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AccountModel::accountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AccountModel::accountIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AccountModel::filtersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AccountModel::tabChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
