/****************************************************************************
** Meta object code from reading C++ file 'notificationmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/notification/notificationmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17NotificationModelE_t {};
} // unnamed namespace

template <> constexpr inline auto NotificationModel::qt_create_metaobjectdata<qt_meta_tag_ZN17NotificationModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotificationModel",
        "QML.Element",
        "auto",
        "excludeTypesChanged",
        "",
        "wantReply",
        "AbstractAccount*",
        "account",
        "Post*",
        "post",
        "QModelIndex",
        "index",
        "readMarkerChanged",
        "actionReply",
        "actionFavorite",
        "actionRepeat",
        "actionRedraft",
        "isEdit",
        "actionDelete",
        "actionBookmark",
        "actionMute",
        "markAllNotificationsAsRead",
        "allExcludeTypes",
        "excludeTypes",
        "fullyRead",
        "fetchedLastReadId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'excludeTypesChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wantReply'
        QtMocHelpers::SignalData<void(AbstractAccount *, Post *, const QModelIndex &)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'readMarkerChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'actionReply'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'actionFavorite'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'actionRepeat'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'actionRedraft'
        QtMocHelpers::SlotData<void(const QModelIndex &, bool)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::Bool, 17 },
        }}),
        // Slot 'actionDelete'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'actionBookmark'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'actionMute'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Method 'markAllNotificationsAsRead'
        QtMocHelpers::MethodData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'allExcludeTypes'
        QtMocHelpers::MethodData<QStringList()>(22, 4, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'excludeTypes'
        QtMocHelpers::PropertyData<QStringList>(23, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'fullyRead'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'fetchedLastReadId'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<NotificationModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NotificationModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractTimelineModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17NotificationModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17NotificationModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17NotificationModelE_t>.metaTypes,
    nullptr
} };

void NotificationModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->excludeTypesChanged(); break;
        case 1: _t->wantReply((*reinterpret_cast<std::add_pointer_t<AbstractAccount*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Post*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[3]))); break;
        case 2: _t->readMarkerChanged(); break;
        case 3: _t->actionReply((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 4: _t->actionFavorite((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 5: _t->actionRepeat((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 6: _t->actionRedraft((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 7: _t->actionDelete((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->actionBookmark((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: _t->actionMute((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->markAllNotificationsAsRead(); break;
        case 11: { QStringList _r = _t->allExcludeTypes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractAccount* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Post* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NotificationModel::*)()>(_a, &NotificationModel::excludeTypesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationModel::*)(AbstractAccount * , Post * , const QModelIndex & )>(_a, &NotificationModel::wantReply, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationModel::*)()>(_a, &NotificationModel::readMarkerChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->excludeTypes(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->fullyRead(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->fetchedLastReadId(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setExcludesTypes(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NotificationModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17NotificationModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractTimelineModel::qt_metacast(_clname);
}

int NotificationModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTimelineModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void NotificationModel::excludeTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NotificationModel::wantReply(AbstractAccount * _t1, Post * _t2, const QModelIndex & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void NotificationModel::readMarkerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
