// This file is generated by kconfig_compiler_kf6 from accountconfig.kcfg.
// All changes you do to this file will be lost.
#ifndef ACCOUNTCONFIG_H
#define ACCOUNTCONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>
#include <qqmlintegration.h>

class AccountConfig : public KConfigSkeleton
{
  Q_OBJECT
  QML_ELEMENT
  QML_UNCREATABLE("")
  public:
    class EnumNotifyPolicy
    {
      public:
      enum type { All, Followed, Followers, None, COUNT };
    };

    AccountConfig( const QString & groupname, QObject *parent = nullptr );
    ~AccountConfig() override;

    /**
      Set Token
    */
    void setToken( const QString & v )
    {
      if (v != mToken && !isTokenImmutable()) {
        mToken = v;
        Q_EMIT TokenChanged();
      }
    }

    Q_PROPERTY(QString token READ token WRITE setToken NOTIFY TokenChanged)
    Q_PROPERTY(bool isTokenImmutable READ isTokenImmutable CONSTANT)
    /**
      Get Token
    */
    QString token() const
    {
      return mToken;
    }

    /**
      Is Token Immutable
    */
    bool isTokenImmutable() const
    {
      return isImmutable( QStringLiteral( "Token" ) );
    }

    /**
      Set ClientId
    */
    void setClientId( const QString & v )
    {
      if (v != mClientId && !isClientIdImmutable()) {
        mClientId = v;
        Q_EMIT ClientIdChanged();
      }
    }

    Q_PROPERTY(QString clientId READ clientId WRITE setClientId NOTIFY ClientIdChanged)
    Q_PROPERTY(bool isClientIdImmutable READ isClientIdImmutable CONSTANT)
    /**
      Get ClientId
    */
    QString clientId() const
    {
      return mClientId;
    }

    /**
      Is ClientId Immutable
    */
    bool isClientIdImmutable() const
    {
      return isImmutable( QStringLiteral( "ClientId" ) );
    }

    /**
      Set InstanceUri
    */
    void setInstanceUri( const QString & v )
    {
      if (v != mInstanceUri && !isInstanceUriImmutable()) {
        mInstanceUri = v;
        Q_EMIT InstanceUriChanged();
      }
    }

    Q_PROPERTY(QString instanceUri READ instanceUri WRITE setInstanceUri NOTIFY InstanceUriChanged)
    Q_PROPERTY(bool isInstanceUriImmutable READ isInstanceUriImmutable CONSTANT)
    /**
      Get InstanceUri
    */
    QString instanceUri() const
    {
      return mInstanceUri;
    }

    /**
      Is InstanceUri Immutable
    */
    bool isInstanceUriImmutable() const
    {
      return isImmutable( QStringLiteral( "InstanceUri" ) );
    }

    /**
      Set Name
    */
    void setName( const QString & v )
    {
      if (v != mName && !isNameImmutable()) {
        mName = v;
        Q_EMIT NameChanged();
      }
    }

    Q_PROPERTY(QString name READ name WRITE setName NOTIFY NameChanged)
    Q_PROPERTY(bool isNameImmutable READ isNameImmutable CONSTANT)
    /**
      Get Name
    */
    QString name() const
    {
      return mName;
    }

    /**
      Is Name Immutable
    */
    bool isNameImmutable() const
    {
      return isImmutable( QStringLiteral( "Name" ) );
    }

    /**
      Set lastUsedEmojis
    */
    void setLastUsedEmojis( const QStringList & v )
    {
      if (v != mLastUsedEmojis && !isLastUsedEmojisImmutable()) {
        mLastUsedEmojis = v;
        Q_EMIT lastUsedEmojisChanged();
      }
    }

    Q_PROPERTY(QStringList lastUsedEmojis READ lastUsedEmojis WRITE setLastUsedEmojis NOTIFY lastUsedEmojisChanged)
    Q_PROPERTY(bool isLastUsedEmojisImmutable READ isLastUsedEmojisImmutable CONSTANT)
    /**
      Get lastUsedEmojis
    */
    QStringList lastUsedEmojis() const
    {
      return mLastUsedEmojis;
    }

    /**
      Is lastUsedEmojis Immutable
    */
    bool isLastUsedEmojisImmutable() const
    {
      return isImmutable( QStringLiteral( "lastUsedEmojis" ) );
    }

    /**
      Set EnableNotifications
    */
    void setEnableNotifications( bool v )
    {
      if (v != mEnableNotifications && !isEnableNotificationsImmutable()) {
        mEnableNotifications = v;
        Q_EMIT EnableNotificationsChanged();
      }
    }

    Q_PROPERTY(bool enableNotifications READ enableNotifications WRITE setEnableNotifications NOTIFY EnableNotificationsChanged)
    Q_PROPERTY(bool isEnableNotificationsImmutable READ isEnableNotificationsImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnableNotificationsValue READ defaultEnableNotificationsValue CONSTANT)
    /**
      Get EnableNotifications
    */
    bool enableNotifications() const
    {
      return mEnableNotifications;
    }

    /**
      Is EnableNotifications Immutable
    */
    bool isEnableNotificationsImmutable() const
    {
      return isImmutable( QStringLiteral( "EnableNotifications" ) );
    }

    /**
      Get EnableNotifications default value
    */
    bool defaultEnableNotificationsValue() const
    {
        return defaultEnableNotificationsValue_helper();
    }

    /**
      Set NotifyMention
    */
    void setNotifyMention( bool v )
    {
      if (v != mNotifyMention && !isNotifyMentionImmutable()) {
        mNotifyMention = v;
        Q_EMIT NotifyMentionChanged();
      }
    }

    Q_PROPERTY(bool notifyMention READ notifyMention WRITE setNotifyMention NOTIFY NotifyMentionChanged)
    Q_PROPERTY(bool isNotifyMentionImmutable READ isNotifyMentionImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyMentionValue READ defaultNotifyMentionValue CONSTANT)
    /**
      Get NotifyMention
    */
    bool notifyMention() const
    {
      return mNotifyMention;
    }

    /**
      Is NotifyMention Immutable
    */
    bool isNotifyMentionImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyMention" ) );
    }

    /**
      Get NotifyMention default value
    */
    bool defaultNotifyMentionValue() const
    {
        return defaultNotifyMentionValue_helper();
    }

    /**
      Set NotifyQuote
    */
    void setNotifyQuote( bool v )
    {
      if (v != mNotifyQuote && !isNotifyQuoteImmutable()) {
        mNotifyQuote = v;
        Q_EMIT NotifyQuoteChanged();
      }
    }

    Q_PROPERTY(bool notifyQuote READ notifyQuote WRITE setNotifyQuote NOTIFY NotifyQuoteChanged)
    Q_PROPERTY(bool isNotifyQuoteImmutable READ isNotifyQuoteImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyQuoteValue READ defaultNotifyQuoteValue CONSTANT)
    /**
      Get NotifyQuote
    */
    bool notifyQuote() const
    {
      return mNotifyQuote;
    }

    /**
      Is NotifyQuote Immutable
    */
    bool isNotifyQuoteImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyQuote" ) );
    }

    /**
      Get NotifyQuote default value
    */
    bool defaultNotifyQuoteValue() const
    {
        return defaultNotifyQuoteValue_helper();
    }

    /**
      Set NotifyStatus
    */
    void setNotifyStatus( bool v )
    {
      if (v != mNotifyStatus && !isNotifyStatusImmutable()) {
        mNotifyStatus = v;
        Q_EMIT NotifyStatusChanged();
      }
    }

    Q_PROPERTY(bool notifyStatus READ notifyStatus WRITE setNotifyStatus NOTIFY NotifyStatusChanged)
    Q_PROPERTY(bool isNotifyStatusImmutable READ isNotifyStatusImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyStatusValue READ defaultNotifyStatusValue CONSTANT)
    /**
      Get NotifyStatus
    */
    bool notifyStatus() const
    {
      return mNotifyStatus;
    }

    /**
      Is NotifyStatus Immutable
    */
    bool isNotifyStatusImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyStatus" ) );
    }

    /**
      Get NotifyStatus default value
    */
    bool defaultNotifyStatusValue() const
    {
        return defaultNotifyStatusValue_helper();
    }

    /**
      Set NotifyBoost
    */
    void setNotifyBoost( bool v )
    {
      if (v != mNotifyBoost && !isNotifyBoostImmutable()) {
        mNotifyBoost = v;
        Q_EMIT NotifyBoostChanged();
      }
    }

    Q_PROPERTY(bool notifyBoost READ notifyBoost WRITE setNotifyBoost NOTIFY NotifyBoostChanged)
    Q_PROPERTY(bool isNotifyBoostImmutable READ isNotifyBoostImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyBoostValue READ defaultNotifyBoostValue CONSTANT)
    /**
      Get NotifyBoost
    */
    bool notifyBoost() const
    {
      return mNotifyBoost;
    }

    /**
      Is NotifyBoost Immutable
    */
    bool isNotifyBoostImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyBoost" ) );
    }

    /**
      Get NotifyBoost default value
    */
    bool defaultNotifyBoostValue() const
    {
        return defaultNotifyBoostValue_helper();
    }

    /**
      Set NotifyFollow
    */
    void setNotifyFollow( bool v )
    {
      if (v != mNotifyFollow && !isNotifyFollowImmutable()) {
        mNotifyFollow = v;
        Q_EMIT NotifyFollowChanged();
      }
    }

    Q_PROPERTY(bool notifyFollow READ notifyFollow WRITE setNotifyFollow NOTIFY NotifyFollowChanged)
    Q_PROPERTY(bool isNotifyFollowImmutable READ isNotifyFollowImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyFollowValue READ defaultNotifyFollowValue CONSTANT)
    /**
      Get NotifyFollow
    */
    bool notifyFollow() const
    {
      return mNotifyFollow;
    }

    /**
      Is NotifyFollow Immutable
    */
    bool isNotifyFollowImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyFollow" ) );
    }

    /**
      Get NotifyFollow default value
    */
    bool defaultNotifyFollowValue() const
    {
        return defaultNotifyFollowValue_helper();
    }

    /**
      Set NotifyFollowRequest
    */
    void setNotifyFollowRequest( bool v )
    {
      if (v != mNotifyFollowRequest && !isNotifyFollowRequestImmutable()) {
        mNotifyFollowRequest = v;
        Q_EMIT NotifyFollowRequestChanged();
      }
    }

    Q_PROPERTY(bool notifyFollowRequest READ notifyFollowRequest WRITE setNotifyFollowRequest NOTIFY NotifyFollowRequestChanged)
    Q_PROPERTY(bool isNotifyFollowRequestImmutable READ isNotifyFollowRequestImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyFollowRequestValue READ defaultNotifyFollowRequestValue CONSTANT)
    /**
      Get NotifyFollowRequest
    */
    bool notifyFollowRequest() const
    {
      return mNotifyFollowRequest;
    }

    /**
      Is NotifyFollowRequest Immutable
    */
    bool isNotifyFollowRequestImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyFollowRequest" ) );
    }

    /**
      Get NotifyFollowRequest default value
    */
    bool defaultNotifyFollowRequestValue() const
    {
        return defaultNotifyFollowRequestValue_helper();
    }

    /**
      Set NotifyFavorite
    */
    void setNotifyFavorite( bool v )
    {
      if (v != mNotifyFavorite && !isNotifyFavoriteImmutable()) {
        mNotifyFavorite = v;
        Q_EMIT NotifyFavoriteChanged();
      }
    }

    Q_PROPERTY(bool notifyFavorite READ notifyFavorite WRITE setNotifyFavorite NOTIFY NotifyFavoriteChanged)
    Q_PROPERTY(bool isNotifyFavoriteImmutable READ isNotifyFavoriteImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyFavoriteValue READ defaultNotifyFavoriteValue CONSTANT)
    /**
      Get NotifyFavorite
    */
    bool notifyFavorite() const
    {
      return mNotifyFavorite;
    }

    /**
      Is NotifyFavorite Immutable
    */
    bool isNotifyFavoriteImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyFavorite" ) );
    }

    /**
      Get NotifyFavorite default value
    */
    bool defaultNotifyFavoriteValue() const
    {
        return defaultNotifyFavoriteValue_helper();
    }

    /**
      Set NotifyPoll
    */
    void setNotifyPoll( bool v )
    {
      if (v != mNotifyPoll && !isNotifyPollImmutable()) {
        mNotifyPoll = v;
        Q_EMIT NotifyPollChanged();
      }
    }

    Q_PROPERTY(bool notifyPoll READ notifyPoll WRITE setNotifyPoll NOTIFY NotifyPollChanged)
    Q_PROPERTY(bool isNotifyPollImmutable READ isNotifyPollImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyPollValue READ defaultNotifyPollValue CONSTANT)
    /**
      Get NotifyPoll
    */
    bool notifyPoll() const
    {
      return mNotifyPoll;
    }

    /**
      Is NotifyPoll Immutable
    */
    bool isNotifyPollImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyPoll" ) );
    }

    /**
      Get NotifyPoll default value
    */
    bool defaultNotifyPollValue() const
    {
        return defaultNotifyPollValue_helper();
    }

    /**
      Set NotifyUpdate
    */
    void setNotifyUpdate( bool v )
    {
      if (v != mNotifyUpdate && !isNotifyUpdateImmutable()) {
        mNotifyUpdate = v;
        Q_EMIT NotifyUpdateChanged();
      }
    }

    Q_PROPERTY(bool notifyUpdate READ notifyUpdate WRITE setNotifyUpdate NOTIFY NotifyUpdateChanged)
    Q_PROPERTY(bool isNotifyUpdateImmutable READ isNotifyUpdateImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyUpdateValue READ defaultNotifyUpdateValue CONSTANT)
    /**
      Get NotifyUpdate
    */
    bool notifyUpdate() const
    {
      return mNotifyUpdate;
    }

    /**
      Is NotifyUpdate Immutable
    */
    bool isNotifyUpdateImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyUpdate" ) );
    }

    /**
      Get NotifyUpdate default value
    */
    bool defaultNotifyUpdateValue() const
    {
        return defaultNotifyUpdateValue_helper();
    }

    /**
      Set NotifySignup
    */
    void setNotifySignup( bool v )
    {
      if (v != mNotifySignup && !isNotifySignupImmutable()) {
        mNotifySignup = v;
        Q_EMIT NotifySignupChanged();
      }
    }

    Q_PROPERTY(bool notifySignup READ notifySignup WRITE setNotifySignup NOTIFY NotifySignupChanged)
    Q_PROPERTY(bool isNotifySignupImmutable READ isNotifySignupImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifySignupValue READ defaultNotifySignupValue CONSTANT)
    /**
      Get NotifySignup
    */
    bool notifySignup() const
    {
      return mNotifySignup;
    }

    /**
      Is NotifySignup Immutable
    */
    bool isNotifySignupImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifySignup" ) );
    }

    /**
      Get NotifySignup default value
    */
    bool defaultNotifySignupValue() const
    {
        return defaultNotifySignupValue_helper();
    }

    /**
      Set NotifyReport
    */
    void setNotifyReport( bool v )
    {
      if (v != mNotifyReport && !isNotifyReportImmutable()) {
        mNotifyReport = v;
        Q_EMIT NotifyReportChanged();
      }
    }

    Q_PROPERTY(bool notifyReport READ notifyReport WRITE setNotifyReport NOTIFY NotifyReportChanged)
    Q_PROPERTY(bool isNotifyReportImmutable READ isNotifyReportImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyReportValue READ defaultNotifyReportValue CONSTANT)
    /**
      Get NotifyReport
    */
    bool notifyReport() const
    {
      return mNotifyReport;
    }

    /**
      Is NotifyReport Immutable
    */
    bool isNotifyReportImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyReport" ) );
    }

    /**
      Get NotifyReport default value
    */
    bool defaultNotifyReportValue() const
    {
        return defaultNotifyReportValue_helper();
    }

    /**
      Set NotifyRelationships
    */
    void setNotifyRelationships( bool v )
    {
      if (v != mNotifyRelationships && !isNotifyRelationshipsImmutable()) {
        mNotifyRelationships = v;
        Q_EMIT NotifyRelationshipsChanged();
      }
    }

    Q_PROPERTY(bool notifyRelationships READ notifyRelationships WRITE setNotifyRelationships NOTIFY NotifyRelationshipsChanged)
    Q_PROPERTY(bool isNotifyRelationshipsImmutable READ isNotifyRelationshipsImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyRelationshipsValue READ defaultNotifyRelationshipsValue CONSTANT)
    /**
      Get NotifyRelationships
    */
    bool notifyRelationships() const
    {
      return mNotifyRelationships;
    }

    /**
      Is NotifyRelationships Immutable
    */
    bool isNotifyRelationshipsImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyRelationships" ) );
    }

    /**
      Get NotifyRelationships default value
    */
    bool defaultNotifyRelationshipsValue() const
    {
        return defaultNotifyRelationshipsValue_helper();
    }

    /**
      Set NotifyAnnualReport
    */
    void setNotifyAnnualReport( bool v )
    {
      if (v != mNotifyAnnualReport && !isNotifyAnnualReportImmutable()) {
        mNotifyAnnualReport = v;
        Q_EMIT NotifyAnnualReportChanged();
      }
    }

    Q_PROPERTY(bool notifyAnnualReport READ notifyAnnualReport WRITE setNotifyAnnualReport NOTIFY NotifyAnnualReportChanged)
    Q_PROPERTY(bool isNotifyAnnualReportImmutable READ isNotifyAnnualReportImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyAnnualReportValue READ defaultNotifyAnnualReportValue CONSTANT)
    /**
      Get NotifyAnnualReport
    */
    bool notifyAnnualReport() const
    {
      return mNotifyAnnualReport;
    }

    /**
      Is NotifyAnnualReport Immutable
    */
    bool isNotifyAnnualReportImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyAnnualReport" ) );
    }

    /**
      Get NotifyAnnualReport default value
    */
    bool defaultNotifyAnnualReportValue() const
    {
        return defaultNotifyAnnualReportValue_helper();
    }

    /**
      Set NotifyCollections
    */
    void setNotifyCollections( bool v )
    {
      if (v != mNotifyCollections && !isNotifyCollectionsImmutable()) {
        mNotifyCollections = v;
        Q_EMIT NotifyCollectionsChanged();
      }
    }

    Q_PROPERTY(bool notifyCollections READ notifyCollections WRITE setNotifyCollections NOTIFY NotifyCollectionsChanged)
    Q_PROPERTY(bool isNotifyCollectionsImmutable READ isNotifyCollectionsImmutable CONSTANT)
    Q_PROPERTY(bool defaultNotifyCollectionsValue READ defaultNotifyCollectionsValue CONSTANT)
    /**
      Get NotifyCollections
    */
    bool notifyCollections() const
    {
      return mNotifyCollections;
    }

    /**
      Is NotifyCollections Immutable
    */
    bool isNotifyCollectionsImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyCollections" ) );
    }

    /**
      Get NotifyCollections default value
    */
    bool defaultNotifyCollectionsValue() const
    {
        return defaultNotifyCollectionsValue_helper();
    }

    /**
      Set DisplayMention
    */
    void setDisplayMention( bool v )
    {
      if (v != mDisplayMention && !isDisplayMentionImmutable()) {
        mDisplayMention = v;
        Q_EMIT DisplayMentionChanged();
      }
    }

    Q_PROPERTY(bool displayMention READ displayMention WRITE setDisplayMention NOTIFY DisplayMentionChanged)
    Q_PROPERTY(bool isDisplayMentionImmutable READ isDisplayMentionImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayMentionValue READ defaultDisplayMentionValue CONSTANT)
    /**
      Get DisplayMention
    */
    bool displayMention() const
    {
      return mDisplayMention;
    }

    /**
      Is DisplayMention Immutable
    */
    bool isDisplayMentionImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayMention" ) );
    }

    /**
      Get DisplayMention default value
    */
    bool defaultDisplayMentionValue() const
    {
        return defaultDisplayMentionValue_helper();
    }

    /**
      Set DisplayQuote
    */
    void setDisplayQuote( bool v )
    {
      if (v != mDisplayQuote && !isDisplayQuoteImmutable()) {
        mDisplayQuote = v;
        Q_EMIT DisplayQuoteChanged();
      }
    }

    Q_PROPERTY(bool displayQuote READ displayQuote WRITE setDisplayQuote NOTIFY DisplayQuoteChanged)
    Q_PROPERTY(bool isDisplayQuoteImmutable READ isDisplayQuoteImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayQuoteValue READ defaultDisplayQuoteValue CONSTANT)
    /**
      Get DisplayQuote
    */
    bool displayQuote() const
    {
      return mDisplayQuote;
    }

    /**
      Is DisplayQuote Immutable
    */
    bool isDisplayQuoteImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayQuote" ) );
    }

    /**
      Get DisplayQuote default value
    */
    bool defaultDisplayQuoteValue() const
    {
        return defaultDisplayQuoteValue_helper();
    }

    /**
      Set DisplayStatus
    */
    void setDisplayStatus( bool v )
    {
      if (v != mDisplayStatus && !isDisplayStatusImmutable()) {
        mDisplayStatus = v;
        Q_EMIT DisplayStatusChanged();
      }
    }

    Q_PROPERTY(bool displayStatus READ displayStatus WRITE setDisplayStatus NOTIFY DisplayStatusChanged)
    Q_PROPERTY(bool isDisplayStatusImmutable READ isDisplayStatusImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayStatusValue READ defaultDisplayStatusValue CONSTANT)
    /**
      Get DisplayStatus
    */
    bool displayStatus() const
    {
      return mDisplayStatus;
    }

    /**
      Is DisplayStatus Immutable
    */
    bool isDisplayStatusImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayStatus" ) );
    }

    /**
      Get DisplayStatus default value
    */
    bool defaultDisplayStatusValue() const
    {
        return defaultDisplayStatusValue_helper();
    }

    /**
      Set DisplayBoost
    */
    void setDisplayBoost( bool v )
    {
      if (v != mDisplayBoost && !isDisplayBoostImmutable()) {
        mDisplayBoost = v;
        Q_EMIT DisplayBoostChanged();
      }
    }

    Q_PROPERTY(bool displayBoost READ displayBoost WRITE setDisplayBoost NOTIFY DisplayBoostChanged)
    Q_PROPERTY(bool isDisplayBoostImmutable READ isDisplayBoostImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayBoostValue READ defaultDisplayBoostValue CONSTANT)
    /**
      Get DisplayBoost
    */
    bool displayBoost() const
    {
      return mDisplayBoost;
    }

    /**
      Is DisplayBoost Immutable
    */
    bool isDisplayBoostImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayBoost" ) );
    }

    /**
      Get DisplayBoost default value
    */
    bool defaultDisplayBoostValue() const
    {
        return defaultDisplayBoostValue_helper();
    }

    /**
      Set DisplayFollow
    */
    void setDisplayFollow( bool v )
    {
      if (v != mDisplayFollow && !isDisplayFollowImmutable()) {
        mDisplayFollow = v;
        Q_EMIT DisplayFollowChanged();
      }
    }

    Q_PROPERTY(bool displayFollow READ displayFollow WRITE setDisplayFollow NOTIFY DisplayFollowChanged)
    Q_PROPERTY(bool isDisplayFollowImmutable READ isDisplayFollowImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayFollowValue READ defaultDisplayFollowValue CONSTANT)
    /**
      Get DisplayFollow
    */
    bool displayFollow() const
    {
      return mDisplayFollow;
    }

    /**
      Is DisplayFollow Immutable
    */
    bool isDisplayFollowImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayFollow" ) );
    }

    /**
      Get DisplayFollow default value
    */
    bool defaultDisplayFollowValue() const
    {
        return defaultDisplayFollowValue_helper();
    }

    /**
      Set DisplayFollowRequest
    */
    void setDisplayFollowRequest( bool v )
    {
      if (v != mDisplayFollowRequest && !isDisplayFollowRequestImmutable()) {
        mDisplayFollowRequest = v;
        Q_EMIT DisplayFollowRequestChanged();
      }
    }

    Q_PROPERTY(bool displayFollowRequest READ displayFollowRequest WRITE setDisplayFollowRequest NOTIFY DisplayFollowRequestChanged)
    Q_PROPERTY(bool isDisplayFollowRequestImmutable READ isDisplayFollowRequestImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayFollowRequestValue READ defaultDisplayFollowRequestValue CONSTANT)
    /**
      Get DisplayFollowRequest
    */
    bool displayFollowRequest() const
    {
      return mDisplayFollowRequest;
    }

    /**
      Is DisplayFollowRequest Immutable
    */
    bool isDisplayFollowRequestImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayFollowRequest" ) );
    }

    /**
      Get DisplayFollowRequest default value
    */
    bool defaultDisplayFollowRequestValue() const
    {
        return defaultDisplayFollowRequestValue_helper();
    }

    /**
      Set DisplayFavorite
    */
    void setDisplayFavorite( bool v )
    {
      if (v != mDisplayFavorite && !isDisplayFavoriteImmutable()) {
        mDisplayFavorite = v;
        Q_EMIT DisplayFavoriteChanged();
      }
    }

    Q_PROPERTY(bool displayFavorite READ displayFavorite WRITE setDisplayFavorite NOTIFY DisplayFavoriteChanged)
    Q_PROPERTY(bool isDisplayFavoriteImmutable READ isDisplayFavoriteImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayFavoriteValue READ defaultDisplayFavoriteValue CONSTANT)
    /**
      Get DisplayFavorite
    */
    bool displayFavorite() const
    {
      return mDisplayFavorite;
    }

    /**
      Is DisplayFavorite Immutable
    */
    bool isDisplayFavoriteImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayFavorite" ) );
    }

    /**
      Get DisplayFavorite default value
    */
    bool defaultDisplayFavoriteValue() const
    {
        return defaultDisplayFavoriteValue_helper();
    }

    /**
      Set DisplayPoll
    */
    void setDisplayPoll( bool v )
    {
      if (v != mDisplayPoll && !isDisplayPollImmutable()) {
        mDisplayPoll = v;
        Q_EMIT DisplayPollChanged();
      }
    }

    Q_PROPERTY(bool displayPoll READ displayPoll WRITE setDisplayPoll NOTIFY DisplayPollChanged)
    Q_PROPERTY(bool isDisplayPollImmutable READ isDisplayPollImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayPollValue READ defaultDisplayPollValue CONSTANT)
    /**
      Get DisplayPoll
    */
    bool displayPoll() const
    {
      return mDisplayPoll;
    }

    /**
      Is DisplayPoll Immutable
    */
    bool isDisplayPollImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayPoll" ) );
    }

    /**
      Get DisplayPoll default value
    */
    bool defaultDisplayPollValue() const
    {
        return defaultDisplayPollValue_helper();
    }

    /**
      Set DisplayUpdate
    */
    void setDisplayUpdate( bool v )
    {
      if (v != mDisplayUpdate && !isDisplayUpdateImmutable()) {
        mDisplayUpdate = v;
        Q_EMIT DisplayUpdateChanged();
      }
    }

    Q_PROPERTY(bool displayUpdate READ displayUpdate WRITE setDisplayUpdate NOTIFY DisplayUpdateChanged)
    Q_PROPERTY(bool isDisplayUpdateImmutable READ isDisplayUpdateImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayUpdateValue READ defaultDisplayUpdateValue CONSTANT)
    /**
      Get DisplayUpdate
    */
    bool displayUpdate() const
    {
      return mDisplayUpdate;
    }

    /**
      Is DisplayUpdate Immutable
    */
    bool isDisplayUpdateImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayUpdate" ) );
    }

    /**
      Get DisplayUpdate default value
    */
    bool defaultDisplayUpdateValue() const
    {
        return defaultDisplayUpdateValue_helper();
    }

    /**
      Set DisplaySignup
    */
    void setDisplaySignup( bool v )
    {
      if (v != mDisplaySignup && !isDisplaySignupImmutable()) {
        mDisplaySignup = v;
        Q_EMIT DisplaySignupChanged();
      }
    }

    Q_PROPERTY(bool displaySignup READ displaySignup WRITE setDisplaySignup NOTIFY DisplaySignupChanged)
    Q_PROPERTY(bool isDisplaySignupImmutable READ isDisplaySignupImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplaySignupValue READ defaultDisplaySignupValue CONSTANT)
    /**
      Get DisplaySignup
    */
    bool displaySignup() const
    {
      return mDisplaySignup;
    }

    /**
      Is DisplaySignup Immutable
    */
    bool isDisplaySignupImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplaySignup" ) );
    }

    /**
      Get DisplaySignup default value
    */
    bool defaultDisplaySignupValue() const
    {
        return defaultDisplaySignupValue_helper();
    }

    /**
      Set DisplayReport
    */
    void setDisplayReport( bool v )
    {
      if (v != mDisplayReport && !isDisplayReportImmutable()) {
        mDisplayReport = v;
        Q_EMIT DisplayReportChanged();
      }
    }

    Q_PROPERTY(bool displayReport READ displayReport WRITE setDisplayReport NOTIFY DisplayReportChanged)
    Q_PROPERTY(bool isDisplayReportImmutable READ isDisplayReportImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayReportValue READ defaultDisplayReportValue CONSTANT)
    /**
      Get DisplayReport
    */
    bool displayReport() const
    {
      return mDisplayReport;
    }

    /**
      Is DisplayReport Immutable
    */
    bool isDisplayReportImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayReport" ) );
    }

    /**
      Get DisplayReport default value
    */
    bool defaultDisplayReportValue() const
    {
        return defaultDisplayReportValue_helper();
    }

    /**
      Set DisplayRelationships
    */
    void setDisplayRelationships( bool v )
    {
      if (v != mDisplayRelationships && !isDisplayRelationshipsImmutable()) {
        mDisplayRelationships = v;
        Q_EMIT DisplayRelationshipsChanged();
      }
    }

    Q_PROPERTY(bool displayRelationships READ displayRelationships WRITE setDisplayRelationships NOTIFY DisplayRelationshipsChanged)
    Q_PROPERTY(bool isDisplayRelationshipsImmutable READ isDisplayRelationshipsImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayRelationshipsValue READ defaultDisplayRelationshipsValue CONSTANT)
    /**
      Get DisplayRelationships
    */
    bool displayRelationships() const
    {
      return mDisplayRelationships;
    }

    /**
      Is DisplayRelationships Immutable
    */
    bool isDisplayRelationshipsImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayRelationships" ) );
    }

    /**
      Get DisplayRelationships default value
    */
    bool defaultDisplayRelationshipsValue() const
    {
        return defaultDisplayRelationshipsValue_helper();
    }

    /**
      Set DisplayAnnualReport
    */
    void setDisplayAnnualReport( bool v )
    {
      if (v != mDisplayAnnualReport && !isDisplayAnnualReportImmutable()) {
        mDisplayAnnualReport = v;
        Q_EMIT DisplayAnnualReportChanged();
      }
    }

    Q_PROPERTY(bool displayAnnualReport READ displayAnnualReport WRITE setDisplayAnnualReport NOTIFY DisplayAnnualReportChanged)
    Q_PROPERTY(bool isDisplayAnnualReportImmutable READ isDisplayAnnualReportImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayAnnualReportValue READ defaultDisplayAnnualReportValue CONSTANT)
    /**
      Get DisplayAnnualReport
    */
    bool displayAnnualReport() const
    {
      return mDisplayAnnualReport;
    }

    /**
      Is DisplayAnnualReport Immutable
    */
    bool isDisplayAnnualReportImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayAnnualReport" ) );
    }

    /**
      Get DisplayAnnualReport default value
    */
    bool defaultDisplayAnnualReportValue() const
    {
        return defaultDisplayAnnualReportValue_helper();
    }

    /**
      Set DisplayCollections
    */
    void setDisplayCollections( bool v )
    {
      if (v != mDisplayCollections && !isDisplayCollectionsImmutable()) {
        mDisplayCollections = v;
        Q_EMIT DisplayCollectionsChanged();
      }
    }

    Q_PROPERTY(bool displayCollections READ displayCollections WRITE setDisplayCollections NOTIFY DisplayCollectionsChanged)
    Q_PROPERTY(bool isDisplayCollectionsImmutable READ isDisplayCollectionsImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayCollectionsValue READ defaultDisplayCollectionsValue CONSTANT)
    /**
      Get DisplayCollections
    */
    bool displayCollections() const
    {
      return mDisplayCollections;
    }

    /**
      Is DisplayCollections Immutable
    */
    bool isDisplayCollectionsImmutable() const
    {
      return isImmutable( QStringLiteral( "DisplayCollections" ) );
    }

    /**
      Get DisplayCollections default value
    */
    bool defaultDisplayCollectionsValue() const
    {
        return defaultDisplayCollectionsValue_helper();
    }

    /**
      Set NotifyPolicy
    */
    void setNotifyPolicy( int v )
    {
      if (v != mNotifyPolicy && !isNotifyPolicyImmutable()) {
        mNotifyPolicy = v;
        Q_EMIT NotifyPolicyChanged();
      }
    }

    Q_PROPERTY(int notifyPolicy READ notifyPolicy WRITE setNotifyPolicy NOTIFY NotifyPolicyChanged)
    Q_PROPERTY(bool isNotifyPolicyImmutable READ isNotifyPolicyImmutable CONSTANT)
    Q_PROPERTY(int defaultNotifyPolicyValue READ defaultNotifyPolicyValue CONSTANT)
    /**
      Get NotifyPolicy
    */
    int notifyPolicy() const
    {
      return mNotifyPolicy;
    }

    /**
      Is NotifyPolicy Immutable
    */
    bool isNotifyPolicyImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyPolicy" ) );
    }

    /**
      Get NotifyPolicy default value
    */
    int defaultNotifyPolicyValue() const
    {
        return defaultNotifyPolicyValue_helper();
    }

    /**
      Set LastPushNotification
    */
    void setLastPushNotification( const QString & v )
    {
      if (v != mLastPushNotification && !isLastPushNotificationImmutable()) {
        mLastPushNotification = v;
        Q_EMIT LastPushNotificationChanged();
      }
    }

    Q_PROPERTY(QString lastPushNotification READ lastPushNotification WRITE setLastPushNotification NOTIFY LastPushNotificationChanged)
    Q_PROPERTY(bool isLastPushNotificationImmutable READ isLastPushNotificationImmutable CONSTANT)
    /**
      Get LastPushNotification
    */
    QString lastPushNotification() const
    {
      return mLastPushNotification;
    }

    /**
      Is LastPushNotification Immutable
    */
    bool isLastPushNotificationImmutable() const
    {
      return isImmutable( QStringLiteral( "LastPushNotification" ) );
    }

    /**
      Set EnablePushNotifications
    */
    void setEnablePushNotifications( bool v )
    {
      if (v != mEnablePushNotifications && !isEnablePushNotificationsImmutable()) {
        mEnablePushNotifications = v;
        Q_EMIT EnablePushNotificationsChanged();
      }
    }

    Q_PROPERTY(bool enablePushNotifications READ enablePushNotifications WRITE setEnablePushNotifications NOTIFY EnablePushNotificationsChanged)
    Q_PROPERTY(bool isEnablePushNotificationsImmutable READ isEnablePushNotificationsImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnablePushNotificationsValue READ defaultEnablePushNotificationsValue CONSTANT)
    /**
      Get EnablePushNotifications
    */
    bool enablePushNotifications() const
    {
      return mEnablePushNotifications;
    }

    /**
      Is EnablePushNotifications Immutable
    */
    bool isEnablePushNotificationsImmutable() const
    {
      return isImmutable( QStringLiteral( "EnablePushNotifications" ) );
    }

    /**
      Get EnablePushNotifications default value
    */
    bool defaultEnablePushNotificationsValue() const
    {
        return defaultEnablePushNotificationsValue_helper();
    }

    /**
      Set FavoriteListIds
    */
    void setFavoriteListIds( const QStringList & v )
    {
      if (v != mFavoriteListIds && !isFavoriteListIdsImmutable()) {
        mFavoriteListIds = v;
        Q_EMIT FavoriteListIdsChanged();
      }
    }

    Q_PROPERTY(QStringList favoriteListIds READ favoriteListIds WRITE setFavoriteListIds NOTIFY FavoriteListIdsChanged)
    Q_PROPERTY(bool isFavoriteListIdsImmutable READ isFavoriteListIdsImmutable CONSTANT)
    /**
      Get FavoriteListIds
    */
    QStringList favoriteListIds() const
    {
      return mFavoriteListIds;
    }

    /**
      Is FavoriteListIds Immutable
    */
    bool isFavoriteListIdsImmutable() const
    {
      return isImmutable( QStringLiteral( "FavoriteListIds" ) );
    }


    enum {
      signalTokenChanged = 1,
      signalClientIdChanged = 2,
      signalInstanceUriChanged = 3,
      signalNameChanged = 4,
      signalLastUsedEmojisChanged = 5,
      signalEnableNotificationsChanged = 6,
      signalNotifyMentionChanged = 7,
      signalNotifyQuoteChanged = 8,
      signalNotifyStatusChanged = 9,
      signalNotifyBoostChanged = 10,
      signalNotifyFollowChanged = 11,
      signalNotifyFollowRequestChanged = 12,
      signalNotifyFavoriteChanged = 13,
      signalNotifyPollChanged = 14,
      signalNotifyUpdateChanged = 15,
      signalNotifySignupChanged = 16,
      signalNotifyReportChanged = 17,
      signalNotifyRelationshipsChanged = 18,
      signalNotifyAnnualReportChanged = 19,
      signalNotifyCollectionsChanged = 20,
      signalDisplayMentionChanged = 21,
      signalDisplayQuoteChanged = 22,
      signalDisplayStatusChanged = 23,
      signalDisplayBoostChanged = 24,
      signalDisplayFollowChanged = 25,
      signalDisplayFollowRequestChanged = 26,
      signalDisplayFavoriteChanged = 27,
      signalDisplayPollChanged = 28,
      signalDisplayUpdateChanged = 29,
      signalDisplaySignupChanged = 30,
      signalDisplayReportChanged = 31,
      signalDisplayRelationshipsChanged = 32,
      signalDisplayAnnualReportChanged = 33,
      signalDisplayCollectionsChanged = 34,
      signalNotifyPolicyChanged = 35,
      signalLastPushNotificationChanged = 36,
      signalEnablePushNotificationsChanged = 37,
      signalFavoriteListIdsChanged = 38
    };

  Q_SIGNALS:
    void TokenChanged();

    void ClientIdChanged();

    void InstanceUriChanged();

    void NameChanged();

    void lastUsedEmojisChanged();

    void EnableNotificationsChanged();

    void NotifyMentionChanged();

    void NotifyQuoteChanged();

    void NotifyStatusChanged();

    void NotifyBoostChanged();

    void NotifyFollowChanged();

    void NotifyFollowRequestChanged();

    void NotifyFavoriteChanged();

    void NotifyPollChanged();

    void NotifyUpdateChanged();

    void NotifySignupChanged();

    void NotifyReportChanged();

    void NotifyRelationshipsChanged();

    void NotifyAnnualReportChanged();

    void NotifyCollectionsChanged();

    void DisplayMentionChanged();

    void DisplayQuoteChanged();

    void DisplayStatusChanged();

    void DisplayBoostChanged();

    void DisplayFollowChanged();

    void DisplayFollowRequestChanged();

    void DisplayFavoriteChanged();

    void DisplayPollChanged();

    void DisplayUpdateChanged();

    void DisplaySignupChanged();

    void DisplayReportChanged();

    void DisplayRelationshipsChanged();

    void DisplayAnnualReportChanged();

    void DisplayCollectionsChanged();

    void NotifyPolicyChanged();

    void LastPushNotificationChanged();

    void EnablePushNotificationsChanged();

    void FavoriteListIdsChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:
    QString mParamgroupname;

    // $(groupname)
    QString mToken;
    QString defaultTokenValue_helper() const;
    QString mClientId;
    QString defaultClientIdValue_helper() const;
    QString mInstanceUri;
    QString defaultInstanceUriValue_helper() const;
    QString mName;
    QString defaultNameValue_helper() const;
    QStringList mLastUsedEmojis;
    QStringList defaultLastUsedEmojisValue_helper() const;
    bool mEnableNotifications;
    bool defaultEnableNotificationsValue_helper() const;
    bool mNotifyMention;
    bool defaultNotifyMentionValue_helper() const;
    bool mNotifyQuote;
    bool defaultNotifyQuoteValue_helper() const;
    bool mNotifyStatus;
    bool defaultNotifyStatusValue_helper() const;
    bool mNotifyBoost;
    bool defaultNotifyBoostValue_helper() const;
    bool mNotifyFollow;
    bool defaultNotifyFollowValue_helper() const;
    bool mNotifyFollowRequest;
    bool defaultNotifyFollowRequestValue_helper() const;
    bool mNotifyFavorite;
    bool defaultNotifyFavoriteValue_helper() const;
    bool mNotifyPoll;
    bool defaultNotifyPollValue_helper() const;
    bool mNotifyUpdate;
    bool defaultNotifyUpdateValue_helper() const;
    bool mNotifySignup;
    bool defaultNotifySignupValue_helper() const;
    bool mNotifyReport;
    bool defaultNotifyReportValue_helper() const;
    bool mNotifyRelationships;
    bool defaultNotifyRelationshipsValue_helper() const;
    bool mNotifyAnnualReport;
    bool defaultNotifyAnnualReportValue_helper() const;
    bool mNotifyCollections;
    bool defaultNotifyCollectionsValue_helper() const;
    bool mDisplayMention;
    bool defaultDisplayMentionValue_helper() const;
    bool mDisplayQuote;
    bool defaultDisplayQuoteValue_helper() const;
    bool mDisplayStatus;
    bool defaultDisplayStatusValue_helper() const;
    bool mDisplayBoost;
    bool defaultDisplayBoostValue_helper() const;
    bool mDisplayFollow;
    bool defaultDisplayFollowValue_helper() const;
    bool mDisplayFollowRequest;
    bool defaultDisplayFollowRequestValue_helper() const;
    bool mDisplayFavorite;
    bool defaultDisplayFavoriteValue_helper() const;
    bool mDisplayPoll;
    bool defaultDisplayPollValue_helper() const;
    bool mDisplayUpdate;
    bool defaultDisplayUpdateValue_helper() const;
    bool mDisplaySignup;
    bool defaultDisplaySignupValue_helper() const;
    bool mDisplayReport;
    bool defaultDisplayReportValue_helper() const;
    bool mDisplayRelationships;
    bool defaultDisplayRelationshipsValue_helper() const;
    bool mDisplayAnnualReport;
    bool defaultDisplayAnnualReportValue_helper() const;
    bool mDisplayCollections;
    bool defaultDisplayCollectionsValue_helper() const;
    int mNotifyPolicy;
    int defaultNotifyPolicyValue_helper() const;
    QString mLastPushNotification;
    QString defaultLastPushNotificationValue_helper() const;
    bool mEnablePushNotifications;
    bool defaultEnablePushNotificationsValue_helper() const;
    QStringList mFavoriteListIds;
    QStringList defaultFavoriteListIdsValue_helper() const;
};

#endif

