/****************************************************************************
** Meta object code from reading C++ file 'reportinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/admin/reportinfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'reportinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ReportInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto ReportInfo::qt_create_metaobjectdata<qt_meta_tag_ZN10ReportInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReportInfo",
        "actionTakenUpdated",
        "",
        "assignedModeratorUpdated",
        "assignedAccountUpdated",
        "reportInfoUpdated",
        "reportId",
        "actionTaken",
        "actionTakenAt",
        "category",
        "comment",
        "forwarded",
        "createdAt",
        "updatedAt",
        "statusCount",
        "mediaAttachmentCount",
        "filedAccount",
        "AdminAccountInfo*",
        "targetAccount",
        "assignedModerator",
        "assignedAccount",
        "actionTakenByAccount",
        "reportStatus",
        "QQmlListProperty<Post>",
        "rules",
        "QJsonArray"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'actionTakenUpdated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'assignedModeratorUpdated'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'assignedAccountUpdated'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reportInfoUpdated'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'reportId'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'actionTaken'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'actionTakenAt'
        QtMocHelpers::PropertyData<QDateTime>(8, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 3),
        // property 'category'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'comment'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'forwarded'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'createdAt'
        QtMocHelpers::PropertyData<QDateTime>(12, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 3),
        // property 'updatedAt'
        QtMocHelpers::PropertyData<QDateTime>(13, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 3),
        // property 'statusCount'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'mediaAttachmentCount'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'filedAccount'
        QtMocHelpers::PropertyData<AdminAccountInfo*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'targetAccount'
        QtMocHelpers::PropertyData<AdminAccountInfo*>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'assignedModerator'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'assignedAccount'
        QtMocHelpers::PropertyData<AdminAccountInfo*>(20, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'actionTakenByAccount'
        QtMocHelpers::PropertyData<AdminAccountInfo*>(21, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'reportStatus'
        QtMocHelpers::PropertyData<QQmlListProperty<Post>>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'rules'
        QtMocHelpers::PropertyData<QJsonArray>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReportInfo, qt_meta_tag_ZN10ReportInfoE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ReportInfo::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ReportInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ReportInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ReportInfoE_t>.metaTypes,
    nullptr
} };

void ReportInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReportInfo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->actionTakenUpdated(); break;
        case 1: _t->assignedModeratorUpdated(); break;
        case 2: _t->assignedAccountUpdated(); break;
        case 3: _t->reportInfoUpdated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReportInfo::*)()>(_a, &ReportInfo::actionTakenUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInfo::*)()>(_a, &ReportInfo::assignedModeratorUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInfo::*)()>(_a, &ReportInfo::assignedAccountUpdated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInfo::*)()>(_a, &ReportInfo::reportInfoUpdated, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->reportId(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->actionTaken(); break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->actionTakenAt(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->category(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->comment(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->forwarded(); break;
        case 6: *reinterpret_cast<QDateTime*>(_v) = _t->createdAt(); break;
        case 7: *reinterpret_cast<QDateTime*>(_v) = _t->updatedAt(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->statusCount(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->mediaAttachmentCount(); break;
        case 10: *reinterpret_cast<AdminAccountInfo**>(_v) = _t->filedAccount(); break;
        case 11: *reinterpret_cast<AdminAccountInfo**>(_v) = _t->targetAccount(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->assignedModerator(); break;
        case 13: *reinterpret_cast<AdminAccountInfo**>(_v) = _t->assignedAccount(); break;
        case 14: *reinterpret_cast<AdminAccountInfo**>(_v) = _t->actionTakenByAccount(); break;
        case 15: *reinterpret_cast<QQmlListProperty<Post>*>(_v) = _t->reportStatusList(); break;
        case 16: *reinterpret_cast<QJsonArray*>(_v) = _t->rules(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setActionTaken(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setAssignedModerator(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setAssignedAccount(*reinterpret_cast<AdminAccountInfo**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ReportInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReportInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ReportInfoE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ReportInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void ReportInfo::actionTakenUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ReportInfo::assignedModeratorUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ReportInfo::assignedAccountUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ReportInfo::reportInfoUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
