/****************************************************************************
** Meta object code from reading C++ file 'socialgraphmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/account/socialgraphmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'socialgraphmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16SocialGraphModelE_t {};
} // unnamed namespace

template <> constexpr inline auto SocialGraphModel::qt_create_metaobjectdata<qt_meta_tag_ZN16SocialGraphModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SocialGraphModel",
        "QML.Element",
        "auto",
        "loadingChanged",
        "",
        "nameChanged",
        "accountIdChanged",
        "statusIdChanged",
        "listIdChanged",
        "networkErrorOccurred",
        "message",
        "collectionIdChanged",
        "actionAllow",
        "QModelIndex",
        "index",
        "actionDeny",
        "actionUnfollow",
        "actionRemoveFollower",
        "actionRemoveFromList",
        "actionAddToList",
        "accountId",
        "actionUnblock",
        "actionUnmute",
        "actionAddToCollection",
        "loading",
        "name",
        "displayName",
        "placeholderText",
        "placeholderExplanation",
        "placeholderIconName",
        "isFollowRequest",
        "isFollowing",
        "isFollower",
        "isList",
        "isMuteList",
        "isBlockList",
        "isCollection",
        "statusId",
        "listId",
        "count",
        "collectionId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loadingChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accountIdChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusIdChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'listIdChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'networkErrorOccurred'
        QtMocHelpers::SignalData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'collectionIdChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'actionAllow'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'actionDeny'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'actionUnfollow'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'actionRemoveFollower'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'actionRemoveFromList'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'actionAddToList'
        QtMocHelpers::SlotData<void(const QString &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'actionUnblock'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'actionUnmute'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'actionAddToCollection'
        QtMocHelpers::SlotData<void(const QString &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'placeholderText'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'placeholderExplanation'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'placeholderIconName'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'isFollowRequest'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isFollowing'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isFollower'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isList'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isMuteList'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isBlockList'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isCollection'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'accountId'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'statusId'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'listId'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'count'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'collectionId'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SocialGraphModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SocialGraphModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SocialGraphModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SocialGraphModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16SocialGraphModelE_t>.metaTypes,
    nullptr
} };

void SocialGraphModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SocialGraphModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loadingChanged(); break;
        case 1: _t->nameChanged(); break;
        case 2: _t->accountIdChanged(); break;
        case 3: _t->statusIdChanged(); break;
        case 4: _t->listIdChanged(); break;
        case 5: _t->networkErrorOccurred((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->collectionIdChanged(); break;
        case 7: _t->actionAllow((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->actionDeny((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: _t->actionUnfollow((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->actionRemoveFollower((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 11: _t->actionRemoveFromList((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 12: _t->actionAddToList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->actionUnblock((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 14: _t->actionUnmute((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 15: _t->actionAddToCollection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SocialGraphModel::*)()>(_a, &SocialGraphModel::loadingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SocialGraphModel::*)()>(_a, &SocialGraphModel::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SocialGraphModel::*)()>(_a, &SocialGraphModel::accountIdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SocialGraphModel::*)()>(_a, &SocialGraphModel::statusIdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SocialGraphModel::*)()>(_a, &SocialGraphModel::listIdChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SocialGraphModel::*)(const QString & )>(_a, &SocialGraphModel::networkErrorOccurred, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SocialGraphModel::*)()>(_a, &SocialGraphModel::collectionIdChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->loading(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->placeholderText(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->placeholderExplanation(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->placeholderIconName(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isFollowRequest(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isFollowing(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isFollower(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isList(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isMuteList(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isBlockList(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isCollection(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->accountId(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->statusId(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->listId(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->collectionId(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 13: _t->setAccountId(*reinterpret_cast<QString*>(_v)); break;
        case 14: _t->setStatusId(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setListId(*reinterpret_cast<QString*>(_v)); break;
        case 16: _t->setCount(*reinterpret_cast<int*>(_v)); break;
        case 17: _t->setCollectionId(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SocialGraphModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SocialGraphModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SocialGraphModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int SocialGraphModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void SocialGraphModel::loadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SocialGraphModel::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SocialGraphModel::accountIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SocialGraphModel::statusIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SocialGraphModel::listIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SocialGraphModel::networkErrorOccurred(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void SocialGraphModel::collectionIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
