/****************************************************************************
** Meta object code from reading C++ file 'identity.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/account/identity.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identity.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8IdentityE_t {};
} // unnamed namespace

template <> constexpr inline auto Identity::qt_create_metaobjectdata<qt_meta_tag_ZN8IdentityE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Identity",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "C++ only",
        "relationshipChanged",
        "",
        "identityUpdated",
        "id",
        "displayName",
        "displayNameHtml",
        "username",
        "bio",
        "account",
        "url",
        "QUrl",
        "locked",
        "bot",
        "visibility",
        "avatarUrl",
        "backgroundUrl",
        "followersCount",
        "followingCount",
        "statusesCount",
        "permission",
        "fields",
        "QJsonArray",
        "relationship",
        "Relationship*",
        "createdAt",
        "limited",
        "moved",
        "Identity*",
        "showMedia",
        "showMediaReplies",
        "showFeatured",
        "avatarDescription",
        "headerDescription",
        "hideCollections",
        "memorial",
        "suspended",
        "roles"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'relationshipChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identityUpdated'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'displayNameHtml'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'username'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'bio'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'account'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'bot'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'visibility'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'avatarUrl'
        QtMocHelpers::PropertyData<QUrl>(21, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'backgroundUrl'
        QtMocHelpers::PropertyData<QUrl>(22, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'followersCount'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'followingCount'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'statusesCount'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'permission'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'fields'
        QtMocHelpers::PropertyData<QJsonArray>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'relationship'
        QtMocHelpers::PropertyData<Relationship*>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'createdAt'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'limited'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'moved'
        QtMocHelpers::PropertyData<Identity*>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'showMedia'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'showMediaReplies'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'showFeatured'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'avatarDescription'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'headerDescription'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'hideCollections'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'memorial'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'suspended'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'roles'
        QtMocHelpers::PropertyData<QJsonArray>(43, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Identity, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Identity::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8IdentityE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8IdentityE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8IdentityE_t>.metaTypes,
    nullptr
} };

void Identity::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Identity *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->relationshipChanged(); break;
        case 1: _t->identityUpdated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Identity::*)()>(_a, &Identity::relationshipChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Identity::*)()>(_a, &Identity::identityUpdated, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 20:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Identity* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->displayNameHtml(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->username(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->bio(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->account(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->bot(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->visibility(); break;
        case 10: *reinterpret_cast<QUrl*>(_v) = _t->avatarUrl(); break;
        case 11: *reinterpret_cast<QUrl*>(_v) = _t->backgroundUrl(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->followersCount(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->followingCount(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->statusesCount(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->permission(); break;
        case 16: *reinterpret_cast<QJsonArray*>(_v) = _t->fields(); break;
        case 17: *reinterpret_cast<Relationship**>(_v) = _t->relationship(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->createdAt(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->limited(); break;
        case 20: *reinterpret_cast<Identity**>(_v) = _t->moved(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->showMedia(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->showMediaReplies(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->showFeatured(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->avatarDescription(); break;
        case 25: *reinterpret_cast<QString*>(_v) = _t->headerDescription(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->hideCollections(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->memorial(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->suspended(); break;
        case 29: *reinterpret_cast<QJsonArray*>(_v) = _t->roles(); break;
        default: break;
        }
    }
}

const QMetaObject *Identity::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Identity::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8IdentityE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Identity::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void Identity::relationshipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Identity::identityUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
