/****************************************************************************
** Meta object code from reading C++ file 'abstractaccount.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/account/abstractaccount.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractaccount.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15AbstractAccountE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractAccount::qt_create_metaobjectdata<qt_meta_tag_ZN15AbstractAccountE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractAccount",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Abstract class",
        "authenticated",
        "",
        "successful",
        "errorMessage",
        "registered",
        "identityChanged",
        "fetchedTimeline",
        "timelineName",
        "QList<Post*>",
        "posts",
        "usernameChanged",
        "fetchedInstanceMetadata",
        "fetchedCustomEmojis",
        "notification",
        "std::shared_ptr<Notification>",
        "n",
        "errorOccured",
        "streamingEvent",
        "AbstractAccount::StreamingEventType",
        "eventType",
        "payload",
        "followRequestCountChanged",
        "unreadNotificationsCountChanged",
        "registrationError",
        "json",
        "favoriteListsChanged",
        "registerAccount",
        "username",
        "email",
        "password",
        "agreement",
        "locale",
        "dateOfBirth",
        "reason",
        "getAuthorizeUrl",
        "QUrl",
        "setToken",
        "authcode",
        "validateToken",
        "saveTimelinePosition",
        "timeline",
        "lastReadId",
        "updateNotification",
        "unknownNotification",
        "annualReportNotification",
        "statusNotification",
        "mentionNotification",
        "favoriteNotification",
        "boostNotification",
        "followNotification",
        "followRequestNotification",
        "pollNotification",
        "increaseFollowRequests",
        "decreaseFollowRequests",
        "quoteNotification",
        "quotedStatusNotification",
        "followAccount",
        "Identity*",
        "identity",
        "reblogs",
        "notify",
        "unfollowAccount",
        "removeFollower",
        "blockAccount",
        "unblockAccount",
        "muteAccount",
        "notifications",
        "duration",
        "unmuteAccount",
        "featureAccount",
        "unfeatureAccount",
        "addNote",
        "note",
        "mutateRemotePost",
        "url",
        "verb",
        "addFavoriteList",
        "id",
        "removeFavoriteList",
        "isFavoriteList",
        "supportsApiVersion",
        "api",
        "minimumVersion",
        "instanceUri",
        "maxPostLength",
        "maxPollOptions",
        "maxCharactersPerOption",
        "supportsLocalVisibility",
        "instanceName",
        "authorizeUrl",
        "preferences",
        "Preferences*",
        "followRequestCount",
        "config",
        "AccountConfig*",
        "registrationsOpen",
        "registrationMessage",
        "unreadNotificationsCount",
        "notificationFilteringPolicy",
        "NotificationFilteringPolicy*",
        "maxMediaAttachments",
        "attachmentFilterStrings",
        "mediaAttachmentDescriptionLimit",
        "maxDisplayNameLength",
        "maxNoteLength",
        "maxAvatarDescriptionLength",
        "maxHeaderDescriptionLength",
        "maxFeaturedTags",
        "maxPinnedStatuses",
        "maxProfileFields",
        "profileFieldNameLimit",
        "profileFieldValueLimit"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'authenticated'
        QtMocHelpers::SignalData<void(bool, const QString &)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'registered'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fetchedTimeline'
        QtMocHelpers::SignalData<void(const QString &, QList<Post*>)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Signal 'usernameChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fetchedInstanceMetadata'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fetchedCustomEmojis'
        QtMocHelpers::SignalData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'notification'
        QtMocHelpers::SignalData<void(std::shared_ptr<Notification>)>(20, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'errorOccured'
        QtMocHelpers::SignalData<void(const QString &)>(23, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'streamingEvent'
        QtMocHelpers::SignalData<void(AbstractAccount::StreamingEventType, const QByteArray &)>(24, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::QByteArray, 27 },
        }}),
        // Signal 'followRequestCountChanged'
        QtMocHelpers::SignalData<void()>(28, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unreadNotificationsCountChanged'
        QtMocHelpers::SignalData<void()>(29, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'registrationError'
        QtMocHelpers::SignalData<void(const QString &)>(30, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Signal 'favoriteListsChanged'
        QtMocHelpers::SignalData<void()>(32, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'registerAccount'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &, bool, const QString &, const QDate &, const QString &)>(33, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { QMetaType::QString, 35 }, { QMetaType::QString, 36 }, { QMetaType::Bool, 37 },
            { QMetaType::QString, 38 }, { QMetaType::QDate, 39 }, { QMetaType::QString, 40 },
        }}),
        // Method 'getAuthorizeUrl'
        QtMocHelpers::MethodData<QUrl() const>(41, 8, QMC::AccessPublic, 0x80000000 | 42),
        // Method 'setToken'
        QtMocHelpers::MethodData<void(const QString &)>(43, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Method 'validateToken'
        QtMocHelpers::MethodData<void()>(45, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'saveTimelinePosition'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(46, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { QMetaType::QString, 48 },
        }}),
        // Method 'updateNotification'
        QtMocHelpers::MethodData<void()>(49, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'unknownNotification'
        QtMocHelpers::MethodData<void()>(50, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'annualReportNotification'
        QtMocHelpers::MethodData<void()>(51, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'statusNotification'
        QtMocHelpers::MethodData<void()>(52, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'mentionNotification'
        QtMocHelpers::MethodData<void()>(53, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'favoriteNotification'
        QtMocHelpers::MethodData<void()>(54, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'boostNotification'
        QtMocHelpers::MethodData<void()>(55, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'followNotification'
        QtMocHelpers::MethodData<void()>(56, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'followRequestNotification'
        QtMocHelpers::MethodData<void()>(57, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'pollNotification'
        QtMocHelpers::MethodData<void()>(58, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'increaseFollowRequests'
        QtMocHelpers::MethodData<void()>(59, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'decreaseFollowRequests'
        QtMocHelpers::MethodData<void()>(60, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'quoteNotification'
        QtMocHelpers::MethodData<void()>(61, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'quotedStatusNotification'
        QtMocHelpers::MethodData<void()>(62, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'followAccount'
        QtMocHelpers::MethodData<void(Identity *, bool, bool)>(63, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 }, { QMetaType::Bool, 66 }, { QMetaType::Bool, 67 },
        }}),
        // Method 'followAccount'
        QtMocHelpers::MethodData<void(Identity *, bool)>(63, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 64, 65 }, { QMetaType::Bool, 66 },
        }}),
        // Method 'followAccount'
        QtMocHelpers::MethodData<void(Identity *)>(63, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Method 'unfollowAccount'
        QtMocHelpers::MethodData<void(Identity *)>(68, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Method 'removeFollower'
        QtMocHelpers::MethodData<void(Identity *)>(69, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Method 'blockAccount'
        QtMocHelpers::MethodData<void(Identity *)>(70, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Method 'unblockAccount'
        QtMocHelpers::MethodData<void(Identity *)>(71, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Method 'muteAccount'
        QtMocHelpers::MethodData<void(Identity *, bool, int)>(72, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 }, { QMetaType::Bool, 73 }, { QMetaType::Int, 74 },
        }}),
        // Method 'muteAccount'
        QtMocHelpers::MethodData<void(Identity *, bool)>(72, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 64, 65 }, { QMetaType::Bool, 73 },
        }}),
        // Method 'muteAccount'
        QtMocHelpers::MethodData<void(Identity *)>(72, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Method 'unmuteAccount'
        QtMocHelpers::MethodData<void(Identity *)>(75, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Method 'featureAccount'
        QtMocHelpers::MethodData<void(Identity *)>(76, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Method 'unfeatureAccount'
        QtMocHelpers::MethodData<void(Identity *)>(77, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Method 'addNote'
        QtMocHelpers::MethodData<void(Identity *, const QString &)>(78, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 }, { QMetaType::QString, 79 },
        }}),
        // Method 'mutateRemotePost'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(80, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 81 }, { QMetaType::QString, 82 },
        }}),
        // Method 'addFavoriteList'
        QtMocHelpers::MethodData<void(const QString &)>(83, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 84 },
        }}),
        // Method 'removeFavoriteList'
        QtMocHelpers::MethodData<void(const QString &)>(85, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 84 },
        }}),
        // Method 'isFavoriteList'
        QtMocHelpers::MethodData<bool(const QString &)>(86, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 84 },
        }}),
        // Method 'supportsApiVersion'
        QtMocHelpers::MethodData<bool(const QString &, int)>(87, 8, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 88 }, { QMetaType::Int, 89 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'username'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'instanceUri'
        QtMocHelpers::PropertyData<QUrl>(90, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'maxPostLength'
        QtMocHelpers::PropertyData<int>(91, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'maxPollOptions'
        QtMocHelpers::PropertyData<int>(92, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'maxCharactersPerOption'
        QtMocHelpers::PropertyData<int>(93, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'supportsLocalVisibility'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'instanceName'
        QtMocHelpers::PropertyData<QString>(95, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'authorizeUrl'
        QtMocHelpers::PropertyData<QUrl>(96, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'identity'
        QtMocHelpers::PropertyData<Identity*>(65, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'preferences'
        QtMocHelpers::PropertyData<Preferences*>(97, 0x80000000 | 98, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'followRequestCount'
        QtMocHelpers::PropertyData<int>(99, QMetaType::Int, QMC::DefaultPropertyFlags, 10),
        // property 'config'
        QtMocHelpers::PropertyData<AccountConfig*>(100, 0x80000000 | 101, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'registrationsOpen'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'registrationMessage'
        QtMocHelpers::PropertyData<QString>(103, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'unreadNotificationsCount'
        QtMocHelpers::PropertyData<int>(104, QMetaType::Int, QMC::DefaultPropertyFlags, 11),
        // property 'notificationFilteringPolicy'
        QtMocHelpers::PropertyData<NotificationFilteringPolicy*>(105, 0x80000000 | 106, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'maxMediaAttachments'
        QtMocHelpers::PropertyData<int>(107, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'attachmentFilterStrings'
        QtMocHelpers::PropertyData<QStringList>(108, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mediaAttachmentDescriptionLimit'
        QtMocHelpers::PropertyData<int>(109, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'maxDisplayNameLength'
        QtMocHelpers::PropertyData<int>(110, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'maxNoteLength'
        QtMocHelpers::PropertyData<int>(111, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'maxAvatarDescriptionLength'
        QtMocHelpers::PropertyData<int>(112, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'maxHeaderDescriptionLength'
        QtMocHelpers::PropertyData<int>(113, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'maxFeaturedTags'
        QtMocHelpers::PropertyData<int>(114, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'maxPinnedStatuses'
        QtMocHelpers::PropertyData<int>(115, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'maxProfileFields'
        QtMocHelpers::PropertyData<int>(116, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'profileFieldNameLimit'
        QtMocHelpers::PropertyData<int>(117, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'profileFieldValueLimit'
        QtMocHelpers::PropertyData<int>(118, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AbstractAccount, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AbstractAccount::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AbstractAccountE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AbstractAccountE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15AbstractAccountE_t>.metaTypes,
    nullptr
} };

void AbstractAccount::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractAccount *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->authenticated((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->registered(); break;
        case 2: _t->identityChanged(); break;
        case 3: _t->fetchedTimeline((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<Post*>>>(_a[2]))); break;
        case 4: _t->usernameChanged(); break;
        case 5: _t->fetchedInstanceMetadata(); break;
        case 6: _t->fetchedCustomEmojis(); break;
        case 7: _t->notification((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Notification>>>(_a[1]))); break;
        case 8: _t->errorOccured((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->streamingEvent((*reinterpret_cast<std::add_pointer_t<AbstractAccount::StreamingEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 10: _t->followRequestCountChanged(); break;
        case 11: _t->unreadNotificationsCountChanged(); break;
        case 12: _t->registrationError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->favoriteListsChanged(); break;
        case 14: _t->registerAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7]))); break;
        case 15: { QUrl _r = _t->getAuthorizeUrl();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setToken((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->validateToken(); break;
        case 18: _t->saveTimelinePosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->updateNotification(); break;
        case 20: _t->unknownNotification(); break;
        case 21: _t->annualReportNotification(); break;
        case 22: _t->statusNotification(); break;
        case 23: _t->mentionNotification(); break;
        case 24: _t->favoriteNotification(); break;
        case 25: _t->boostNotification(); break;
        case 26: _t->followNotification(); break;
        case 27: _t->followRequestNotification(); break;
        case 28: _t->pollNotification(); break;
        case 29: _t->increaseFollowRequests(); break;
        case 30: _t->decreaseFollowRequests(); break;
        case 31: _t->quoteNotification(); break;
        case 32: _t->quotedStatusNotification(); break;
        case 33: _t->followAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 34: _t->followAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 35: _t->followAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1]))); break;
        case 36: _t->unfollowAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1]))); break;
        case 37: _t->removeFollower((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1]))); break;
        case 38: _t->blockAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1]))); break;
        case 39: _t->unblockAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1]))); break;
        case 40: _t->muteAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 41: _t->muteAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 42: _t->muteAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1]))); break;
        case 43: _t->unmuteAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1]))); break;
        case 44: _t->featureAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1]))); break;
        case 45: _t->unfeatureAccount((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1]))); break;
        case 46: _t->addNote((*reinterpret_cast<std::add_pointer_t<Identity*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 47: _t->mutateRemotePost((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 48: _t->addFavoriteList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 49: _t->removeFavoriteList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 50: { bool _r = _t->isFavoriteList((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 51: { bool _r = _t->supportsApiVersion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Post*> >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 44:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Identity* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)(bool , const QString & )>(_a, &AbstractAccount::authenticated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)()>(_a, &AbstractAccount::registered, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)()>(_a, &AbstractAccount::identityChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)(const QString & , QList<Post*> )>(_a, &AbstractAccount::fetchedTimeline, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)()>(_a, &AbstractAccount::usernameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)()>(_a, &AbstractAccount::fetchedInstanceMetadata, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)()>(_a, &AbstractAccount::fetchedCustomEmojis, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)(std::shared_ptr<Notification> )>(_a, &AbstractAccount::notification, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)(const QString & )>(_a, &AbstractAccount::errorOccured, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)(AbstractAccount::StreamingEventType , const QByteArray & )>(_a, &AbstractAccount::streamingEvent, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)()>(_a, &AbstractAccount::followRequestCountChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)()>(_a, &AbstractAccount::unreadNotificationsCountChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)(const QString & )>(_a, &AbstractAccount::registrationError, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractAccount::*)()>(_a, &AbstractAccount::favoriteListsChanged, 13))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AccountConfig* >(); break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Identity* >(); break;
        case 15:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NotificationFilteringPolicy* >(); break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Preferences* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->username(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->instanceUri(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->maxPostLength(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->maxPollOptions(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->maxCharactersPerOption(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->supportsLocalVisibility(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->instanceName(); break;
        case 7: *reinterpret_cast<QUrl*>(_v) = _t->getAuthorizeUrl(); break;
        case 8: *reinterpret_cast<Identity**>(_v) = _t->identity(); break;
        case 9: *reinterpret_cast<Preferences**>(_v) = _t->preferences(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->followRequestCount(); break;
        case 11: *reinterpret_cast<AccountConfig**>(_v) = _t->config(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->registrationsOpen(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->registrationMessage(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->unreadNotificationsCount(); break;
        case 15: *reinterpret_cast<NotificationFilteringPolicy**>(_v) = _t->notificationFilteringPolicy(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->maxMediaAttachments(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->attachmentFilterStrings(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->mediaAttachmentDescriptionLimit(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->maxDisplayNameLength(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->maxNoteLength(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->maxAvatarDescriptionLength(); break;
        case 22: *reinterpret_cast<int*>(_v) = _t->maxHeaderDescriptionLength(); break;
        case 23: *reinterpret_cast<int*>(_v) = _t->maxFeaturedTags(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->maxPinnedStatuses(); break;
        case 25: *reinterpret_cast<int*>(_v) = _t->maxProfileFields(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->profileFieldNameLimit(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->profileFieldValueLimit(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUsername(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractAccount::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractAccount::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AbstractAccountE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractAccount::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void AbstractAccount::authenticated(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void AbstractAccount::registered()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AbstractAccount::identityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AbstractAccount::fetchedTimeline(const QString & _t1, QList<Post*> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void AbstractAccount::usernameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AbstractAccount::fetchedInstanceMetadata()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AbstractAccount::fetchedCustomEmojis()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AbstractAccount::notification(std::shared_ptr<Notification> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void AbstractAccount::errorOccured(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void AbstractAccount::streamingEvent(AbstractAccount::StreamingEventType _t1, const QByteArray & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void AbstractAccount::followRequestCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AbstractAccount::unreadNotificationsCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void AbstractAccount::registrationError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void AbstractAccount::favoriteListsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
