/****************************************************************************
** Meta object code from reading C++ file 'relationship.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/account/relationship.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'relationship.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12RelationshipE_t {};
} // unnamed namespace

template <> constexpr inline auto Relationship::qt_create_metaobjectdata<qt_meta_tag_ZN12RelationshipE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Relationship",
        "followingChanged",
        "",
        "requestedChanged",
        "endorsedChanged",
        "followedByChanged",
        "mutingChanged",
        "mutingNotificationsChanged",
        "showingReblogsChanged",
        "notifyingChanged",
        "blockingChanged",
        "domainBlockingChanged",
        "blockedByChanged",
        "noteChanged",
        "following",
        "requested",
        "endorsed",
        "followedBy",
        "muting",
        "mutingNotifications",
        "showingReblogs",
        "notifying",
        "blocking",
        "domainBlocking",
        "blockedBy",
        "note"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'followingChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestedChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endorsedChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'followedByChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mutingChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mutingNotificationsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showingReblogsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'notifyingChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blockingChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'domainBlockingChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blockedByChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'following'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'requested'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'endorsed'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'followedBy'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'muting'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'mutingNotifications'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'showingReblogs'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'notifying'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'blocking'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'domainBlocking'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'blockedBy'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'note'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Relationship, qt_meta_tag_ZN12RelationshipE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Relationship::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12RelationshipE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12RelationshipE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12RelationshipE_t>.metaTypes,
    nullptr
} };

void Relationship::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Relationship *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->followingChanged(); break;
        case 1: _t->requestedChanged(); break;
        case 2: _t->endorsedChanged(); break;
        case 3: _t->followedByChanged(); break;
        case 4: _t->mutingChanged(); break;
        case 5: _t->mutingNotificationsChanged(); break;
        case 6: _t->showingReblogsChanged(); break;
        case 7: _t->notifyingChanged(); break;
        case 8: _t->blockingChanged(); break;
        case 9: _t->domainBlockingChanged(); break;
        case 10: _t->blockedByChanged(); break;
        case 11: _t->noteChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::followingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::requestedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::endorsedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::followedByChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::mutingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::mutingNotificationsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::showingReblogsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::notifyingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::blockingChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::domainBlockingChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::blockedByChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Relationship::*)()>(_a, &Relationship::noteChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->following(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->requested(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->endorsed(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->followedBy(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->muting(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->mutingNotifications(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->showingReblogs(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->notifying(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->blocking(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->domainBlocking(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->blockedBy(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->note(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFollowing(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setRequested(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setEndorsed(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setFollowedBy(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setMuting(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setMutingNotifications(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setShowingReblogs(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setNotifying(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setBlocking(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setDomainBlocking(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setBlockedBy(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setNote(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Relationship::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Relationship::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12RelationshipE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Relationship::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Relationship::followingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Relationship::requestedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Relationship::endorsedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Relationship::followedByChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Relationship::mutingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Relationship::mutingNotificationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Relationship::showingReblogsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Relationship::notifyingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Relationship::blockingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Relationship::domainBlockingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Relationship::blockedByChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Relationship::noteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
