/****************************************************************************
** Meta object code from reading C++ file 'accountconfig.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../accountconfig.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accountconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13AccountConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto AccountConfig::qt_create_metaobjectdata<qt_meta_tag_ZN13AccountConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AccountConfig",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "TokenChanged",
        "ClientIdChanged",
        "InstanceUriChanged",
        "NameChanged",
        "lastUsedEmojisChanged",
        "EnableNotificationsChanged",
        "NotifyMentionChanged",
        "NotifyQuoteChanged",
        "NotifyStatusChanged",
        "NotifyBoostChanged",
        "NotifyFollowChanged",
        "NotifyFollowRequestChanged",
        "NotifyFavoriteChanged",
        "NotifyPollChanged",
        "NotifyUpdateChanged",
        "NotifySignupChanged",
        "NotifyReportChanged",
        "NotifyRelationshipsChanged",
        "NotifyAnnualReportChanged",
        "NotifyCollectionsChanged",
        "DisplayMentionChanged",
        "DisplayQuoteChanged",
        "DisplayStatusChanged",
        "DisplayBoostChanged",
        "DisplayFollowChanged",
        "DisplayFollowRequestChanged",
        "DisplayFavoriteChanged",
        "DisplayPollChanged",
        "DisplayUpdateChanged",
        "DisplaySignupChanged",
        "DisplayReportChanged",
        "DisplayRelationshipsChanged",
        "DisplayAnnualReportChanged",
        "DisplayCollectionsChanged",
        "NotifyPolicyChanged",
        "LastPushNotificationChanged",
        "EnablePushNotificationsChanged",
        "FavoriteListIdsChanged",
        "token",
        "isTokenImmutable",
        "clientId",
        "isClientIdImmutable",
        "instanceUri",
        "isInstanceUriImmutable",
        "name",
        "isNameImmutable",
        "lastUsedEmojis",
        "isLastUsedEmojisImmutable",
        "enableNotifications",
        "isEnableNotificationsImmutable",
        "defaultEnableNotificationsValue",
        "notifyMention",
        "isNotifyMentionImmutable",
        "defaultNotifyMentionValue",
        "notifyQuote",
        "isNotifyQuoteImmutable",
        "defaultNotifyQuoteValue",
        "notifyStatus",
        "isNotifyStatusImmutable",
        "defaultNotifyStatusValue",
        "notifyBoost",
        "isNotifyBoostImmutable",
        "defaultNotifyBoostValue",
        "notifyFollow",
        "isNotifyFollowImmutable",
        "defaultNotifyFollowValue",
        "notifyFollowRequest",
        "isNotifyFollowRequestImmutable",
        "defaultNotifyFollowRequestValue",
        "notifyFavorite",
        "isNotifyFavoriteImmutable",
        "defaultNotifyFavoriteValue",
        "notifyPoll",
        "isNotifyPollImmutable",
        "defaultNotifyPollValue",
        "notifyUpdate",
        "isNotifyUpdateImmutable",
        "defaultNotifyUpdateValue",
        "notifySignup",
        "isNotifySignupImmutable",
        "defaultNotifySignupValue",
        "notifyReport",
        "isNotifyReportImmutable",
        "defaultNotifyReportValue",
        "notifyRelationships",
        "isNotifyRelationshipsImmutable",
        "defaultNotifyRelationshipsValue",
        "notifyAnnualReport",
        "isNotifyAnnualReportImmutable",
        "defaultNotifyAnnualReportValue",
        "notifyCollections",
        "isNotifyCollectionsImmutable",
        "defaultNotifyCollectionsValue",
        "displayMention",
        "isDisplayMentionImmutable",
        "defaultDisplayMentionValue",
        "displayQuote",
        "isDisplayQuoteImmutable",
        "defaultDisplayQuoteValue",
        "displayStatus",
        "isDisplayStatusImmutable",
        "defaultDisplayStatusValue",
        "displayBoost",
        "isDisplayBoostImmutable",
        "defaultDisplayBoostValue",
        "displayFollow",
        "isDisplayFollowImmutable",
        "defaultDisplayFollowValue",
        "displayFollowRequest",
        "isDisplayFollowRequestImmutable",
        "defaultDisplayFollowRequestValue",
        "displayFavorite",
        "isDisplayFavoriteImmutable",
        "defaultDisplayFavoriteValue",
        "displayPoll",
        "isDisplayPollImmutable",
        "defaultDisplayPollValue",
        "displayUpdate",
        "isDisplayUpdateImmutable",
        "defaultDisplayUpdateValue",
        "displaySignup",
        "isDisplaySignupImmutable",
        "defaultDisplaySignupValue",
        "displayReport",
        "isDisplayReportImmutable",
        "defaultDisplayReportValue",
        "displayRelationships",
        "isDisplayRelationshipsImmutable",
        "defaultDisplayRelationshipsValue",
        "displayAnnualReport",
        "isDisplayAnnualReportImmutable",
        "defaultDisplayAnnualReportValue",
        "displayCollections",
        "isDisplayCollectionsImmutable",
        "defaultDisplayCollectionsValue",
        "notifyPolicy",
        "isNotifyPolicyImmutable",
        "defaultNotifyPolicyValue",
        "lastPushNotification",
        "isLastPushNotificationImmutable",
        "enablePushNotifications",
        "isEnablePushNotificationsImmutable",
        "defaultEnablePushNotificationsValue",
        "favoriteListIds",
        "isFavoriteListIdsImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'TokenChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ClientIdChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'InstanceUriChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NameChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastUsedEmojisChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnableNotificationsChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyMentionChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyQuoteChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyStatusChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyBoostChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyFollowChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyFollowRequestChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyFavoriteChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyPollChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyUpdateChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifySignupChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyReportChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyRelationshipsChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyAnnualReportChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyCollectionsChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayMentionChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayQuoteChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayStatusChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayBoostChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayFollowChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayFollowRequestChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayFavoriteChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayPollChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayUpdateChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplaySignupChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayReportChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayRelationshipsChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayAnnualReportChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayCollectionsChanged'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyPolicyChanged'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LastPushNotificationChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnablePushNotificationsChanged'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FavoriteListIdsChanged'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'token'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isTokenImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clientId'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isClientIdImmutable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'instanceUri'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isInstanceUriImmutable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isNameImmutable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastUsedEmojis'
        QtMocHelpers::PropertyData<QStringList>(53, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isLastUsedEmojisImmutable'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableNotifications'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isEnableNotificationsImmutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableNotificationsValue'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyMention'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isNotifyMentionImmutable'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyMentionValue'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyQuote'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isNotifyQuoteImmutable'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyQuoteValue'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyStatus'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isNotifyStatusImmutable'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyStatusValue'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyBoost'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isNotifyBoostImmutable'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyBoostValue'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyFollow'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isNotifyFollowImmutable'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyFollowValue'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyFollowRequest'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isNotifyFollowRequestImmutable'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyFollowRequestValue'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyFavorite'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isNotifyFavoriteImmutable'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyFavoriteValue'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyPoll'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isNotifyPollImmutable'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyPollValue'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyUpdate'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isNotifyUpdateImmutable'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyUpdateValue'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifySignup'
        QtMocHelpers::PropertyData<bool>(85, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isNotifySignupImmutable'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifySignupValue'
        QtMocHelpers::PropertyData<bool>(87, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyReport'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isNotifyReportImmutable'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyReportValue'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyRelationships'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isNotifyRelationshipsImmutable'
        QtMocHelpers::PropertyData<bool>(92, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyRelationshipsValue'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyAnnualReport'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isNotifyAnnualReportImmutable'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyAnnualReportValue'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyCollections'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isNotifyCollectionsImmutable'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyCollectionsValue'
        QtMocHelpers::PropertyData<bool>(99, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayMention'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isDisplayMentionImmutable'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayMentionValue'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayQuote'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isDisplayQuoteImmutable'
        QtMocHelpers::PropertyData<bool>(104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayQuoteValue'
        QtMocHelpers::PropertyData<bool>(105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayStatus'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isDisplayStatusImmutable'
        QtMocHelpers::PropertyData<bool>(107, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayStatusValue'
        QtMocHelpers::PropertyData<bool>(108, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayBoost'
        QtMocHelpers::PropertyData<bool>(109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isDisplayBoostImmutable'
        QtMocHelpers::PropertyData<bool>(110, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayBoostValue'
        QtMocHelpers::PropertyData<bool>(111, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayFollow'
        QtMocHelpers::PropertyData<bool>(112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isDisplayFollowImmutable'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayFollowValue'
        QtMocHelpers::PropertyData<bool>(114, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayFollowRequest'
        QtMocHelpers::PropertyData<bool>(115, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isDisplayFollowRequestImmutable'
        QtMocHelpers::PropertyData<bool>(116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayFollowRequestValue'
        QtMocHelpers::PropertyData<bool>(117, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayFavorite'
        QtMocHelpers::PropertyData<bool>(118, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'isDisplayFavoriteImmutable'
        QtMocHelpers::PropertyData<bool>(119, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayFavoriteValue'
        QtMocHelpers::PropertyData<bool>(120, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayPoll'
        QtMocHelpers::PropertyData<bool>(121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isDisplayPollImmutable'
        QtMocHelpers::PropertyData<bool>(122, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayPollValue'
        QtMocHelpers::PropertyData<bool>(123, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayUpdate'
        QtMocHelpers::PropertyData<bool>(124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isDisplayUpdateImmutable'
        QtMocHelpers::PropertyData<bool>(125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayUpdateValue'
        QtMocHelpers::PropertyData<bool>(126, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displaySignup'
        QtMocHelpers::PropertyData<bool>(127, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isDisplaySignupImmutable'
        QtMocHelpers::PropertyData<bool>(128, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplaySignupValue'
        QtMocHelpers::PropertyData<bool>(129, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayReport'
        QtMocHelpers::PropertyData<bool>(130, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isDisplayReportImmutable'
        QtMocHelpers::PropertyData<bool>(131, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayReportValue'
        QtMocHelpers::PropertyData<bool>(132, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayRelationships'
        QtMocHelpers::PropertyData<bool>(133, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'isDisplayRelationshipsImmutable'
        QtMocHelpers::PropertyData<bool>(134, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayRelationshipsValue'
        QtMocHelpers::PropertyData<bool>(135, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayAnnualReport'
        QtMocHelpers::PropertyData<bool>(136, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'isDisplayAnnualReportImmutable'
        QtMocHelpers::PropertyData<bool>(137, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayAnnualReportValue'
        QtMocHelpers::PropertyData<bool>(138, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayCollections'
        QtMocHelpers::PropertyData<bool>(139, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'isDisplayCollectionsImmutable'
        QtMocHelpers::PropertyData<bool>(140, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayCollectionsValue'
        QtMocHelpers::PropertyData<bool>(141, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'notifyPolicy'
        QtMocHelpers::PropertyData<int>(142, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'isNotifyPolicyImmutable'
        QtMocHelpers::PropertyData<bool>(143, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNotifyPolicyValue'
        QtMocHelpers::PropertyData<int>(144, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastPushNotification'
        QtMocHelpers::PropertyData<QString>(145, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'isLastPushNotificationImmutable'
        QtMocHelpers::PropertyData<bool>(146, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enablePushNotifications'
        QtMocHelpers::PropertyData<bool>(147, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'isEnablePushNotificationsImmutable'
        QtMocHelpers::PropertyData<bool>(148, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnablePushNotificationsValue'
        QtMocHelpers::PropertyData<bool>(149, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'favoriteListIds'
        QtMocHelpers::PropertyData<QStringList>(150, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'isFavoriteListIdsImmutable'
        QtMocHelpers::PropertyData<bool>(151, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<AccountConfig, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AccountConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AccountConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AccountConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13AccountConfigE_t>.metaTypes,
    nullptr
} };

void AccountConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->TokenChanged(); break;
        case 1: _t->ClientIdChanged(); break;
        case 2: _t->InstanceUriChanged(); break;
        case 3: _t->NameChanged(); break;
        case 4: _t->lastUsedEmojisChanged(); break;
        case 5: _t->EnableNotificationsChanged(); break;
        case 6: _t->NotifyMentionChanged(); break;
        case 7: _t->NotifyQuoteChanged(); break;
        case 8: _t->NotifyStatusChanged(); break;
        case 9: _t->NotifyBoostChanged(); break;
        case 10: _t->NotifyFollowChanged(); break;
        case 11: _t->NotifyFollowRequestChanged(); break;
        case 12: _t->NotifyFavoriteChanged(); break;
        case 13: _t->NotifyPollChanged(); break;
        case 14: _t->NotifyUpdateChanged(); break;
        case 15: _t->NotifySignupChanged(); break;
        case 16: _t->NotifyReportChanged(); break;
        case 17: _t->NotifyRelationshipsChanged(); break;
        case 18: _t->NotifyAnnualReportChanged(); break;
        case 19: _t->NotifyCollectionsChanged(); break;
        case 20: _t->DisplayMentionChanged(); break;
        case 21: _t->DisplayQuoteChanged(); break;
        case 22: _t->DisplayStatusChanged(); break;
        case 23: _t->DisplayBoostChanged(); break;
        case 24: _t->DisplayFollowChanged(); break;
        case 25: _t->DisplayFollowRequestChanged(); break;
        case 26: _t->DisplayFavoriteChanged(); break;
        case 27: _t->DisplayPollChanged(); break;
        case 28: _t->DisplayUpdateChanged(); break;
        case 29: _t->DisplaySignupChanged(); break;
        case 30: _t->DisplayReportChanged(); break;
        case 31: _t->DisplayRelationshipsChanged(); break;
        case 32: _t->DisplayAnnualReportChanged(); break;
        case 33: _t->DisplayCollectionsChanged(); break;
        case 34: _t->NotifyPolicyChanged(); break;
        case 35: _t->LastPushNotificationChanged(); break;
        case 36: _t->EnablePushNotificationsChanged(); break;
        case 37: _t->FavoriteListIdsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::TokenChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::ClientIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::InstanceUriChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::lastUsedEmojisChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::EnableNotificationsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyMentionChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyQuoteChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyStatusChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyBoostChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyFollowChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyFollowRequestChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyFavoriteChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyPollChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyUpdateChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifySignupChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyReportChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyRelationshipsChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyAnnualReportChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyCollectionsChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayMentionChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayQuoteChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayStatusChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayBoostChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayFollowChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayFollowRequestChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayFavoriteChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayPollChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayUpdateChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplaySignupChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayReportChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayRelationshipsChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayAnnualReportChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::DisplayCollectionsChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::NotifyPolicyChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::LastPushNotificationChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::EnablePushNotificationsChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountConfig::*)()>(_a, &AccountConfig::FavoriteListIdsChanged, 37))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->token(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isTokenImmutable(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->clientId(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isClientIdImmutable(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->instanceUri(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isInstanceUriImmutable(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isNameImmutable(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->lastUsedEmojis(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isLastUsedEmojisImmutable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->enableNotifications(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isEnableNotificationsImmutable(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->defaultEnableNotificationsValue(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->notifyMention(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->isNotifyMentionImmutable(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyMentionValue(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->notifyQuote(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isNotifyQuoteImmutable(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyQuoteValue(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->notifyStatus(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->isNotifyStatusImmutable(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyStatusValue(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->notifyBoost(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->isNotifyBoostImmutable(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyBoostValue(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->notifyFollow(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->isNotifyFollowImmutable(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyFollowValue(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->notifyFollowRequest(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->isNotifyFollowRequestImmutable(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyFollowRequestValue(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->notifyFavorite(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->isNotifyFavoriteImmutable(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyFavoriteValue(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->notifyPoll(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->isNotifyPollImmutable(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyPollValue(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->notifyUpdate(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->isNotifyUpdateImmutable(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyUpdateValue(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->notifySignup(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->isNotifySignupImmutable(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->defaultNotifySignupValue(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->notifyReport(); break;
        case 44: *reinterpret_cast<bool*>(_v) = _t->isNotifyReportImmutable(); break;
        case 45: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyReportValue(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->notifyRelationships(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->isNotifyRelationshipsImmutable(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyRelationshipsValue(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->notifyAnnualReport(); break;
        case 50: *reinterpret_cast<bool*>(_v) = _t->isNotifyAnnualReportImmutable(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyAnnualReportValue(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->notifyCollections(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->isNotifyCollectionsImmutable(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->defaultNotifyCollectionsValue(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->displayMention(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->isDisplayMentionImmutable(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayMentionValue(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->displayQuote(); break;
        case 59: *reinterpret_cast<bool*>(_v) = _t->isDisplayQuoteImmutable(); break;
        case 60: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayQuoteValue(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->displayStatus(); break;
        case 62: *reinterpret_cast<bool*>(_v) = _t->isDisplayStatusImmutable(); break;
        case 63: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayStatusValue(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->displayBoost(); break;
        case 65: *reinterpret_cast<bool*>(_v) = _t->isDisplayBoostImmutable(); break;
        case 66: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayBoostValue(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->displayFollow(); break;
        case 68: *reinterpret_cast<bool*>(_v) = _t->isDisplayFollowImmutable(); break;
        case 69: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayFollowValue(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->displayFollowRequest(); break;
        case 71: *reinterpret_cast<bool*>(_v) = _t->isDisplayFollowRequestImmutable(); break;
        case 72: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayFollowRequestValue(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->displayFavorite(); break;
        case 74: *reinterpret_cast<bool*>(_v) = _t->isDisplayFavoriteImmutable(); break;
        case 75: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayFavoriteValue(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->displayPoll(); break;
        case 77: *reinterpret_cast<bool*>(_v) = _t->isDisplayPollImmutable(); break;
        case 78: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayPollValue(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->displayUpdate(); break;
        case 80: *reinterpret_cast<bool*>(_v) = _t->isDisplayUpdateImmutable(); break;
        case 81: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayUpdateValue(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->displaySignup(); break;
        case 83: *reinterpret_cast<bool*>(_v) = _t->isDisplaySignupImmutable(); break;
        case 84: *reinterpret_cast<bool*>(_v) = _t->defaultDisplaySignupValue(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->displayReport(); break;
        case 86: *reinterpret_cast<bool*>(_v) = _t->isDisplayReportImmutable(); break;
        case 87: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayReportValue(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->displayRelationships(); break;
        case 89: *reinterpret_cast<bool*>(_v) = _t->isDisplayRelationshipsImmutable(); break;
        case 90: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayRelationshipsValue(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->displayAnnualReport(); break;
        case 92: *reinterpret_cast<bool*>(_v) = _t->isDisplayAnnualReportImmutable(); break;
        case 93: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayAnnualReportValue(); break;
        case 94: *reinterpret_cast<bool*>(_v) = _t->displayCollections(); break;
        case 95: *reinterpret_cast<bool*>(_v) = _t->isDisplayCollectionsImmutable(); break;
        case 96: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayCollectionsValue(); break;
        case 97: *reinterpret_cast<int*>(_v) = _t->notifyPolicy(); break;
        case 98: *reinterpret_cast<bool*>(_v) = _t->isNotifyPolicyImmutable(); break;
        case 99: *reinterpret_cast<int*>(_v) = _t->defaultNotifyPolicyValue(); break;
        case 100: *reinterpret_cast<QString*>(_v) = _t->lastPushNotification(); break;
        case 101: *reinterpret_cast<bool*>(_v) = _t->isLastPushNotificationImmutable(); break;
        case 102: *reinterpret_cast<bool*>(_v) = _t->enablePushNotifications(); break;
        case 103: *reinterpret_cast<bool*>(_v) = _t->isEnablePushNotificationsImmutable(); break;
        case 104: *reinterpret_cast<bool*>(_v) = _t->defaultEnablePushNotificationsValue(); break;
        case 105: *reinterpret_cast<QStringList*>(_v) = _t->favoriteListIds(); break;
        case 106: *reinterpret_cast<bool*>(_v) = _t->isFavoriteListIdsImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setToken(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setClientId(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setInstanceUri(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setLastUsedEmojis(*reinterpret_cast<QStringList*>(_v)); break;
        case 10: _t->setEnableNotifications(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setNotifyMention(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setNotifyQuote(*reinterpret_cast<bool*>(_v)); break;
        case 19: _t->setNotifyStatus(*reinterpret_cast<bool*>(_v)); break;
        case 22: _t->setNotifyBoost(*reinterpret_cast<bool*>(_v)); break;
        case 25: _t->setNotifyFollow(*reinterpret_cast<bool*>(_v)); break;
        case 28: _t->setNotifyFollowRequest(*reinterpret_cast<bool*>(_v)); break;
        case 31: _t->setNotifyFavorite(*reinterpret_cast<bool*>(_v)); break;
        case 34: _t->setNotifyPoll(*reinterpret_cast<bool*>(_v)); break;
        case 37: _t->setNotifyUpdate(*reinterpret_cast<bool*>(_v)); break;
        case 40: _t->setNotifySignup(*reinterpret_cast<bool*>(_v)); break;
        case 43: _t->setNotifyReport(*reinterpret_cast<bool*>(_v)); break;
        case 46: _t->setNotifyRelationships(*reinterpret_cast<bool*>(_v)); break;
        case 49: _t->setNotifyAnnualReport(*reinterpret_cast<bool*>(_v)); break;
        case 52: _t->setNotifyCollections(*reinterpret_cast<bool*>(_v)); break;
        case 55: _t->setDisplayMention(*reinterpret_cast<bool*>(_v)); break;
        case 58: _t->setDisplayQuote(*reinterpret_cast<bool*>(_v)); break;
        case 61: _t->setDisplayStatus(*reinterpret_cast<bool*>(_v)); break;
        case 64: _t->setDisplayBoost(*reinterpret_cast<bool*>(_v)); break;
        case 67: _t->setDisplayFollow(*reinterpret_cast<bool*>(_v)); break;
        case 70: _t->setDisplayFollowRequest(*reinterpret_cast<bool*>(_v)); break;
        case 73: _t->setDisplayFavorite(*reinterpret_cast<bool*>(_v)); break;
        case 76: _t->setDisplayPoll(*reinterpret_cast<bool*>(_v)); break;
        case 79: _t->setDisplayUpdate(*reinterpret_cast<bool*>(_v)); break;
        case 82: _t->setDisplaySignup(*reinterpret_cast<bool*>(_v)); break;
        case 85: _t->setDisplayReport(*reinterpret_cast<bool*>(_v)); break;
        case 88: _t->setDisplayRelationships(*reinterpret_cast<bool*>(_v)); break;
        case 91: _t->setDisplayAnnualReport(*reinterpret_cast<bool*>(_v)); break;
        case 94: _t->setDisplayCollections(*reinterpret_cast<bool*>(_v)); break;
        case 97: _t->setNotifyPolicy(*reinterpret_cast<int*>(_v)); break;
        case 100: _t->setLastPushNotification(*reinterpret_cast<QString*>(_v)); break;
        case 102: _t->setEnablePushNotifications(*reinterpret_cast<bool*>(_v)); break;
        case 105: _t->setFavoriteListIds(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AccountConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AccountConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13AccountConfigE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int AccountConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 38;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 107;
    }
    return _id;
}

// SIGNAL 0
void AccountConfig::TokenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AccountConfig::ClientIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AccountConfig::InstanceUriChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AccountConfig::NameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AccountConfig::lastUsedEmojisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AccountConfig::EnableNotificationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AccountConfig::NotifyMentionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AccountConfig::NotifyQuoteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AccountConfig::NotifyStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AccountConfig::NotifyBoostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void AccountConfig::NotifyFollowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AccountConfig::NotifyFollowRequestChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void AccountConfig::NotifyFavoriteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void AccountConfig::NotifyPollChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void AccountConfig::NotifyUpdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void AccountConfig::NotifySignupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void AccountConfig::NotifyReportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void AccountConfig::NotifyRelationshipsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void AccountConfig::NotifyAnnualReportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void AccountConfig::NotifyCollectionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void AccountConfig::DisplayMentionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void AccountConfig::DisplayQuoteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void AccountConfig::DisplayStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void AccountConfig::DisplayBoostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void AccountConfig::DisplayFollowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void AccountConfig::DisplayFollowRequestChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void AccountConfig::DisplayFavoriteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void AccountConfig::DisplayPollChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void AccountConfig::DisplayUpdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void AccountConfig::DisplaySignupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void AccountConfig::DisplayReportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void AccountConfig::DisplayRelationshipsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void AccountConfig::DisplayAnnualReportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void AccountConfig::DisplayCollectionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void AccountConfig::NotifyPolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void AccountConfig::LastPushNotificationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void AccountConfig::EnablePushNotificationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void AccountConfig::FavoriteListIdsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}
QT_WARNING_POP
