/****************************************************************************
** Meta object code from reading C++ file 'card.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.07.90/src/datatypes/card.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'card.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4CardE_t {};
} // unnamed namespace

template <> constexpr inline auto Card::qt_create_metaobjectdata<qt_meta_tag_ZN4CardE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Card",
        "authorName",
        "authorUrl",
        "authorIdentity",
        "Identity*",
        "blurhash",
        "description",
        "embedUrl",
        "width",
        "height",
        "html",
        "image",
        "providerName",
        "providerUrl",
        "title",
        "url",
        "QUrl"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'authorName'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'authorUrl'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'authorIdentity'
        QtMocHelpers::PropertyData<Identity*>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'blurhash'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'embedUrl'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'width'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'height'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'html'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'image'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'providerName'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'providerUrl'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Card, qt_meta_tag_ZN4CardE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Card::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4CardE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4CardE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4CardE_t>.metaTypes,
    nullptr
} };

void Card::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Card *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Identity* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->authorName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->authorUrl(); break;
        case 2: *reinterpret_cast<Identity**>(_v) = _t->authorIdentity(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->blurhash(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->embedUrl(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->width(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->html(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->image(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->providerName(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->providerUrl(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 13: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
